/*----------------------------------------------------------------------*\
 | Functions to retrieve a keyword's text given its symbolic name and	|
 | vice versa.															|
 |																		|
 | Peter N. Schweitzer (U.S. Geological Survey, Reston, VA 20192)		|
\*----------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <ctype.h>

#include "keyword.h"

#ifndef PRINT_NAMES
	#include "local.h"
#endif

#include "stricmp.h"

struct keyword_list {
	enum fgdc_keyword key;
	char *text;
	};

/*----------------------------------------------------------------------*\
 | English
\*----------------------------------------------------------------------*/

static struct keyword_list en_std[] = {
	{WAbscissa_Resolution,
	 "Abscissa_Resolution"},
	{WAbstract,
	 "Abstract"},
	{WAccess_Constraints,
	 "Access_Constraints"},
	{WAccess_Instructions,
	 "Access_Instructions"},
	{WAddress,
	 "Address"},
	{WAddress_Type,
	 "Address_Type"},
	{WAlbers_Conical_Equal_Area,
	 "Albers_Conical_Equal_Area"},
	{WAltitude_Datum_Name,
	 "Altitude_Datum_Name"},
	{WAltitude_Distance_Units,
	 "Altitude_Distance_Units"},
	{WAltitude_Encoding_Method,
	 "Altitude_Encoding_Method"},
	{WAltitude_Resolution,
	 "Altitude_Resolution"},
	{WAltitude_System_Definition,
	 "Altitude_System_Definition"},
	{WARC_Coordinate_System,
	 "ARC_Coordinate_System"},
	{WARC_System_Zone_Identifier,
	 "ARC_System_Zone_Identifier"},
	{WAttribute,
	 "Attribute"},
	{WAttribute_Accuracy,
	 "Attribute_Accuracy"},
	{WAttribute_Accuracy_Explanation,
	 "Attribute_Accuracy_Explanation"},
	{WAttribute_Accuracy_Report,
	 "Attribute_Accuracy_Report"},
	{WAttribute_Accuracy_Value,
	 "Attribute_Accuracy_Value"},
	{WAttribute_Definition,
	 "Attribute_Definition"},
	{WAttribute_Definition_Source,
	 "Attribute_Definition_Source"},
	{WAttribute_Domain_Values,
	 "Attribute_Domain_Values"},
	{WAttribute_Label,
	 "Attribute_Label"},
	{WAttribute_Measurement_Frequency,
	 "Attribute_Measurement_Frequency"},
	{WAttribute_Measurement_Resolution,
	 "Attribute_Measurement_Resolution"},
	{WAttribute_Units_of_Measure,
	 "Attribute_Units_of_Measure"},
	{WAttribute_Value_Accuracy,
	 "Attribute_Value_Accuracy"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Attribute_Value_Accuracy_Explanation"},
	{WAttribute_Value_Accuracy_Information,
	 "Attribute_Value_Accuracy_Information"},
	{WAvailable_Time_Period,
	 "Available_Time_Period"},
	{WAzimuthal_Angle,
	 "Azimuthal_Angle"},
	{WAzimuthal_Equidistant,
	 "Azimuthal_Equidistant"},
	{WAzimuth_Measure_Point_Longitude,
	 "Azimuth_Measure_Point_Longitude"},
	{WBearing_Reference_Direction,
	 "Bearing_Reference_Direction"},
	{WBearing_Reference_Meridian,
	 "Bearing_Reference_Meridian"},
	{WBearing_Resolution,
	 "Bearing_Resolution"},
	{WBearing_Units,
	 "Bearing_Units"},
	{WBeginning_Date,
	 "Beginning_Date"},
	{WBeginning_Date_of_Attribute_Values,
	 "Beginning_Date_of_Attribute_Values"},
	{WBeginning_Time,
	 "Beginning_Time"},
	{WBounding_Coordinates,
	 "Bounding_Coordinates"},
	{WBrowse_Graphic,
	 "Browse_Graphic"},
	{WBrowse_Graphic_File_Description,
	 "Browse_Graphic_File_Description"},
	{WBrowse_Graphic_File_Name,
	 "Browse_Graphic_File_Name"},
	{WBrowse_Graphic_File_Type,
	 "Browse_Graphic_File_Type"},
	{WCalendar_Date,
	 "Calendar_Date"},
	{WCitation,
	 "Citation"},
	{WCitation_Information,
	 "Citation_Information"},
	{WCity,
	 "City"},
	{WCloud_Cover,
	 "Cloud_Cover"},
	{WCodeset_Domain,
	 "Codeset_Domain"},
	{WCodeset_Name,
	 "Codeset_Name"},
	{WCodeset_Source,
	 "Codeset_Source"},
	{WColumn_Count,
	 "Column_Count"},
	{WCompatibility_Information,
	 "Compatibility_Information"},
	{WCompleteness_Report,
	 "Completeness_Report"},
	{WCompression_Support,
	 "Compression_Support"},
	{WComputer_Contact_Information,
	 "Computer_Contact_Information"},
	{WContact_Address,
	 "Contact_Address"},
	{WContact_Electronic_Mail_Address,
	 "Contact_Electronic_Mail_Address"},
	{WContact_Facsimile_Telephone,
	 "Contact_Facsimile_Telephone"},
	{WContact_Information,
	 "Contact_Information"},
	{WContact_Instructions,
	 "Contact_Instructions"},
	{WContact_Organization,
	 "Contact_Organization"},
	{WContact_Organization_Primary,
	 "Contact_Organization_Primary"},
	{WContact_Person,
	 "Contact_Person"},
	{WContact_Person_Primary,
	 "Contact_Person_Primary"},
	{WContact_Position,
	 "Contact_Position"},
	{WContact_TDD_TTY_Telephone,
	 "Contact_TDD/TTY_Telephone"},
	{WContact_Voice_Telephone,
	 "Contact_Voice_Telephone"},
	{WCoordinate_Representation,
	 "Coordinate_Representation"},
	{WCountry,
	 "Country"},
	{WCross_Reference,
	 "Cross_Reference"},
	{WCurrentness_Reference,
	 "Currentness_Reference"},
	{WCustom_Order_Process,
	 "Custom_Order_Process"},
	{WData_Quality_Information,
	 "Data_Quality_Information"},
	{WData_Set_Credit,
	 "Data_Set_Credit"},
	{WData_Set_G_Polygon,
	 "Data_Set_G-Polygon"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Data_Set_G-Polygon_Exclusion_G-Ring"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Data_Set_G-Polygon_Outer_G-Ring"},
	{WDenominator_of_Flattening_Ratio,
	 "Denominator_of_Flattening_Ratio"},
	{WDepth_Datum_Name,
	 "Depth_Datum_Name"},
	{WDepth_Distance_Units,
	 "Depth_Distance_Units"},
	{WDepth_Encoding_Method,
	 "Depth_Encoding_Method"},
	{WDepth_Resolution,
	 "Depth_Resolution"},
	{WDepth_System_Definition,
	 "Depth_System_Definition"},
	{WDescription,
	 "Description"},
	{WDetailed_Description,
	 "Detailed_Description"},
	{WDialup_File_Name,
	 "Dialup_File_Name"},
	{WDialup_Instructions,
	 "Dialup_Instructions"},
	{WDialup_Telephone,
	 "Dialup_Telephone"},
	{WDigital_Form,
	 "Digital_Form"},
	{WDigital_Transfer_Information,
	 "Digital_Transfer_Information"},
	{WDigital_Transfer_Option,
	 "Digital_Transfer_Option"},
	{WDirect_Spatial_Reference_Method,
	 "Direct_Spatial_Reference_Method"},
	{WDistance_and_Bearing_Representation,
	 "Distance_and_Bearing_Representation"},
	{WDistance_Resolution,
	 "Distance_Resolution"},
	{WDistribution_Information,
	 "Distribution_Information"},
	{WDistribution_Liability,
	 "Distribution_Liability"},
	{WDistributor,
	 "Distributor"},
	{WEast_Bounding_Coordinate,
	 "East_Bounding_Coordinate"},
	{WEdition,
	 "Edition"},
	{WEllipsoid_Name,
	 "Ellipsoid_Name"},
	{WEnding_Date,
	 "Ending_Date"},
	{WEnding_Date_of_Attribute_Values,
	 "Ending_Date_of_Attribute_Values"},
	{WEnding_Time,
	 "Ending_Time"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Entity_and_Attribute_Detail_Citation"},
	{WEntity_and_Attribute_Information,
	 "Entity_and_Attribute_Information"},
	{WEntity_and_Attribute_Overview,
	 "Entity_and_Attribute_Overview"},
	{WEntity_Type,
	 "Entity_Type"},
	{WEntity_Type_Definition,
	 "Entity_Type_Definition"},
	{WEntity_Type_Definition_Source,
	 "Entity_Type_Definition_Source"},
	{WEntity_Type_Label,
	 "Entity_Type_Label"},
	{WEnumerated_Domain,
	 "Enumerated_Domain"},
	{WEnumerated_Domain_Value,
	 "Enumerated_Domain_Value"},
	{WEnumerated_Domain_Value_Definition,
	 "Enumerated_Domain_Value_Definition"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Enumerated_Domain_Value_Definition_Source"},
	{WEquidistant_Conic,
	 "Equidistant_Conic"},
	{WEquirectangular,
	 "Equirectangular"},
	{WFalse_Easting,
	 "False_Easting"},
	{WFalse_Northing,
	 "False_Northing"},
	{WFees,
	 "Fees"},
	{WFile_Decompression_Technique,
	 "File_Decompression_Technique"},
	{WFormat_Information_Content,
	 "Format_Information_Content"},
	{WFormat_Name,
	 "Format_Name"},
	{WFormat_Specification,
	 "Format_Specification"},
	{WFormat_Version_Date,
	 "Format_Version_Date"},
	{WFormat_Version_Number,
	 "Format_Version_Number"},
	{WG_Ring,
	 "G-Ring"},
	{WG_Ring_Latitude,
	 "G-Ring_Latitude"},
	{WG_Ring_Longitude,
	 "G-Ring_Longitude"},
	{WG_Ring_Point,
	 "G-Ring_Point"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "General_Vertical_Near-sided_Perspective"},
	{WGeodetic_Model,
	 "Geodetic_Model"},
	{WGeographic,
	 "Geographic"},
	{WGeographic_Coordinate_Units,
	 "Geographic_Coordinate_Units"},
	{WGeospatial_Data_Presentation_Form,
	 "Geospatial_Data_Presentation_Form"},
	{WGnomonic,
	 "Gnomonic"},
	{WGrid_Coordinate_System,
	 "Grid_Coordinate_System"},
	{WGrid_Coordinate_System_Name,
	 "Grid_Coordinate_System_Name"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Height_of_Perspective_Point_Above_Surface"},
	{WHighest_BPS,
	 "Highest_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Horizontal_Coordinate_System_Definition"},
	{WHorizontal_Datum_Name,
	 "Horizontal_Datum_Name"},
	{WHorizontal_Positional_Accuracy,
	 "Horizontal_Positional_Accuracy"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Horizontal_Positional_Accuracy_Explanation"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Horizontal_Positional_Accuracy_Report"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Horizontal_Positional_Accuracy_Value"},
	{WHours_of_Service,
	 "Hours_of_Service"},
	{WIdentification_Information,
	 "Identification_Information"},
	{WIndirect_Spatial_Reference,
	 "Indirect_Spatial_Reference"},
	{WIssue_Identification,
	 "Issue_Identification"},
	{WKeywords,
	 "Keywords"},
	{WLambert_Azimuthal_Equal_Area,
	 "Lambert_Azimuthal_Equal_Area"},
	{WLambert_Conformal_Conic,
	 "Lambert_Conformal_Conic"},
	{WLandsat_Number,
	 "Landsat_Number"},
	{WLarger_Work_Citation,
	 "Larger_Work_Citation"},
	{WLatitude_of_Projection_Center,
	 "Latitude_of_Projection_Center"},
	{WLatitude_of_Projection_Origin,
	 "Latitude_of_Projection_Origin"},
	{WLatitude_Resolution,
	 "Latitude_Resolution"},
	{WLineage,
	 "Lineage"},
	{WLocal,
	 "Local"},
	{WLocal_Description,
	 "Local_Description"},
	{WLocal_Georeference_Information,
	 "Local_Georeference_Information"},
	{WLocal_Planar,
	 "Local_Planar"},
	{WLocal_Planar_Description,
	 "Local_Planar_Description"},
	{WLocal_Planar_Georeference_Information,
	 "Local_Planar_Georeference_Information"},
	{WLogical_Consistency_Report,
	 "Logical_Consistency_Report"},
	{WLongitude_of_Central_Meridian,
	 "Longitude_of_Central_Meridian"},
	{WLongitude_of_Projection_Center,
	 "Longitude_of_Projection_Center"},
	{WLongitude_Resolution,
	 "Longitude_Resolution"},
	{WLowest_BPS,
	 "Lowest_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Maintenance_and_Update_Frequency"},
	{WMap_Projection,
	 "Map_Projection"},
	{WMap_Projection_Name,
	 "Map_Projection_Name"},
	{WMap_Projection_Parameters,
	 "Map_Projection_Parameters"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadata"},
	{WMetadata_Access_Constraints,
	 "Metadata_Access_Constraints"},
	{WMetadata_Contact,
	 "Metadata_Contact"},
	{WMetadata_Date,
	 "Metadata_Date"},
	{WMetadata_Extensions,
	 "Metadata_Extensions"},
	{WMetadata_Future_Review_Date,
	 "Metadata_Future_Review_Date"},
	{WMetadata_Language,
	 "Metadata_Language"},
	{WMetadata_Reference_Information,
	 "Metadata_Reference_Information"},
	{WMetadata_Review_Date,
	 "Metadata_Review_Date"},
	{WMetadata_Security_Classification,
	 "Metadata_Security_Classification"},
	{WMetadata_Security_Classification_System,
	 "Metadata_Security_Classification_System"},
	{WMetadata_Security_Handling_Description,
	 "Metadata_Security_Handling_Description"},
	{WMetadata_Security_Information,
	 "Metadata_Security_Information"},
	{WMetadata_Standard_Name,
	 "Metadata_Standard_Name"},
	{WMetadata_Standard_Version,
	 "Metadata_Standard_Version"},
	{WMetadata_Time_Convention,
	 "Metadata_Time_Convention"},
	{WMetadata_Use_Constraints,
	 "Metadata_Use_Constraints"},
	{WMiller_Cylindrical,
	 "Miller_Cylindrical"},
	{WModified_Stereographic_for_Alaska,
	 "Modified_Stereographic_for_Alaska"},
	{WMultiple_Dates_Times,
	 "Multiple_Dates/Times"},
	{WNative_Data_Set_Environment,
	 "Native_Data_Set_Environment"},
	{WNetwork_Address,
	 "Network_Address"},
	{WNetwork_Resource_Name,
	 "Network_Resource_Name"},
	{WNon_digital_Form,
	 "Non-digital_Form"},
	{WNorth_Bounding_Coordinate,
	 "North_Bounding_Coordinate"},
	{WNumber_DataBits,
	 "Number_DataBits"},
	{WNumber_StopBits,
	 "Number_StopBits"},
	{WOblique_Line_Azimuth,
	 "Oblique_Line_Azimuth"},
	{WOblique_Line_Latitude,
	 "Oblique_Line_Latitude"},
	{WOblique_Line_Longitude,
	 "Oblique_Line_Longitude"},
	{WOblique_Line_Point,
	 "Oblique_Line_Point"},
	{WOblique_Mercator,
	 "Oblique_Mercator"},
	{WOffline_Media,
	 "Offline_Media"},
	{WOffline_Option,
	 "Offline_Option"},
	{WOnline_Computer_and_Operating_System,
	 "Online_Computer_and_Operating_System"},
	{WOnline_Linkage,
	 "Online_Linkage"},
	{WOnline_Option,
	 "Online_Option"},
	{WOrdering_Instructions,
	 "Ordering_Instructions"},
	{WOrdinate_Resolution,
	 "Ordinate_Resolution"},
	{WOriginator,
	 "Originator"},
	{WOrthographic,
	 "Orthographic"},
	{WOther_Citation_Details,
	 "Other_Citation_Details"},
	{WOther_Grid_Systems_Definition,
	 "Other_Grid_System's_Definition"},
	{WOther_Projections_Definition,
	 "Other_Projection's_Definition"},
	{WOverview_Description,
	 "Overview_Description"},
	{WParity,
	 "Parity"},
	{WPath_Number,
	 "Path_Number"},
	{WPlace,
	 "Place"},
	{WPlace_Keyword,
	 "Place_Keyword"},
	{WPlace_Keyword_Thesaurus,
	 "Place_Keyword_Thesaurus"},
	{WPlanar,
	 "Planar"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Planar_Coordinate_Encoding_Method"},
	{WPlanar_Coordinate_Information,
	 "Planar_Coordinate_Information"},
	{WPlanar_Distance_Units,
	 "Planar_Distance_Units"},
	{WPoint_and_Vector_Object_Count,
	 "Point_and_Vector_Object_Count"},
	{WPoint_and_Vector_Object_Information,
	 "Point_and_Vector_Object_Information"},
	{WPoint_of_Contact,
	 "Point_of_Contact"},
	{WPolar_Stereographic,
	 "Polar_Stereographic"},
	{WPolyconic,
	 "Polyconic"},
	{WPositional_Accuracy,
	 "Positional_Accuracy"},
	{WPostal_Code,
	 "Postal_Code"},
	{WProcess_Contact,
	 "Process_Contact"},
	{WProcess_Date,
	 "Process_Date"},
	{WProcess_Description,
	 "Process_Description"},
	{WProcess_Step,
	 "Process_Step"},
	{WProcess_Time,
	 "Process_Time"},
	{WProfile_Name,
	 "Profile_Name"},
	{WProgress,
	 "Progress"},
	{WPublication_Date,
	 "Publication_Date"},
	{WPublication_Information,
	 "Publication_Information"},
	{WPublication_Place,
	 "Publication_Place"},
	{WPublication_Time,
	 "Publication_Time"},
	{WPublisher,
	 "Publisher"},
	{WPurpose,
	 "Purpose"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Quantitative_Attribute_Accuracy_Assessment"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Quantitative_Horizontal_Positional_Accuracy_Assessment"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Quantitative_Vertical_Positional_Accuracy_Assessment"},
	{WRange_Domain,
	 "Range_Domain"},
	{WRange_Domain_Maximum,
	 "Range_Domain_Maximum"},
	{WRange_Domain_Minimum,
	 "Range_Domain_Minimum"},
	{WRange_of_Dates_Times,
	 "Range_of_Dates/Times"},
	{WRaster_Object_Information,
	 "Raster_Object_Information"},
	{WRaster_Object_Type,
	 "Raster_Object_Type"},
	{WRecording_Capacity,
	 "Recording_Capacity"},
	{WRecording_Density,
	 "Recording_Density"},
	{WRecording_Density_Units,
	 "Recording_Density_Units"},
	{WRecording_Format,
	 "Recording_Format"},
	{WResource_Description,
	 "Resource_Description"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Row_Count"},
	{WScale_Factor_at_Center_Line,
	 "Scale_Factor_at_Center_Line"},
	{WScale_Factor_at_Central_Meridian,
	 "Scale_Factor_at_Central_Meridian"},
	{WScale_Factor_at_Equator,
	 "Scale_Factor_at_Equator"},
	{WScale_Factor_at_Projection_Origin,
	 "Scale_Factor_at_Projection_Origin"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "SDTS_Point_and_Vector_Object_Type"},
	{WSDTS_Terms_Description,
	 "SDTS_Terms_Description"},
	{WSecurity_Classification,
	 "Security_Classification"},
	{WSecurity_Classification_System,
	 "Security_Classification_System"},
	{WSecurity_Handling_Description,
	 "Security_Handling_Description"},
	{WSecurity_Information,
	 "Security_Information"},
	{WSemi_major_Axis,
	 "Semi-major_Axis"},
	{WSeries_Information,
	 "Series_Information"},
	{WSeries_Name,
	 "Series_Name"},
	{WSingle_Date_Time,
	 "Single_Date/Time"},
	{WSinusoidal,
	 "Sinusoidal"},
	{WSource_Citation,
	 "Source_Citation"},
	{WSource_Citation_Abbreviation,
	 "Source_Citation_Abbreviation"},
	{WSource_Contribution,
	 "Source_Contribution"},
	{WSource_Currentness_Reference,
	 "Source_Currentness_Reference"},
	{WSource_Information,
	 "Source_Information"},
	{WSource_Produced_Citation_Abbreviation,
	 "Source_Produced_Citation_Abbreviation"},
	{WSource_Scale_Denominator,
	 "Source_Scale_Denominator"},
	{WSource_Time_Period_of_Content,
	 "Source_Time_Period_of_Content"},
	{WSource_Used_Citation_Abbreviation,
	 "Source_Used_Citation_Abbreviation"},
	{WSouth_Bounding_Coordinate,
	 "South_Bounding_Coordinate"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Space_Oblique_Mercator_(Landsat)"},
	{WSpatial_Data_Organization_Information,
	 "Spatial_Data_Organization_Information"},
	{WSpatial_Domain,
	 "Spatial_Domain"},
	{WSpatial_Reference_Information,
	 "Spatial_Reference_Information"},
	{WSPCS_Zone_Identifier,
	 "SPCS_Zone_Identifier"},
	{WStandard_Order_Process,
	 "Standard_Order_Process"},
	{WStandard_Parallel,
	 "Standard_Parallel"},
	{WState_or_Province,
	 "State_or_Province"},
	{WState_Plane_Coordinate_System,
	 "State_Plane_Coordinate_System"},
	{WStatus,
	 "Status"},
	{WStereographic,
	 "Stereographic"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Straight-Vertical_Longitude_from_Pole"},
	{WStratum,
	 "Stratum"},
	{WStratum_Keyword,
	 "Stratum_Keyword"},
	{WStratum_Keyword_Thesaurus,
	 "Stratum_Keyword_Thesaurus"},
	{WSupplemental_Information,
	 "Supplemental_Information"},
	{WTechnical_Prerequisites,
	 "Technical_Prerequisites"},
	{WTemporal,
	 "Temporal"},
	{WTemporal_Keyword,
	 "Temporal_Keyword"},
	{WTemporal_Keyword_Thesaurus,
	 "Temporal_Keyword_Thesaurus"},
	{WTheme,
	 "Theme"},
	{WTheme_Keyword,
	 "Theme_Keyword"},
	{WTheme_Keyword_Thesaurus,
	 "Theme_Keyword_Thesaurus"},
	{WTime_of_Day,
	 "Time_of_Day"},
	{WTime_Period_Information,
	 "Time_Period_Information"},
	{WTime_Period_of_Content,
	 "Time_Period_of_Content"},
	{WTitle,
	 "Title"},
	{WTransfer_Size,
	 "Transfer_Size"},
	{WTransverse_Mercator,
	 "Transverse_Mercator"},
	{WTurnaround,
	 "Turnaround"},
	{WType_of_Source_Media,
	 "Type_of_Source_Media"},
	{WUniversal_Polar_Stereographic,
	 "Universal_Polar_Stereographic"},
	{WUniversal_Transverse_Mercator,
	 "Universal_Transverse_Mercator"},
	{WUnrepresentable_Domain,
	 "Unrepresentable_Domain"},
	{WUPS_Zone_Identifier,
	 "UPS_Zone_Identifier"},
	{WUse_Constraints,
	 "Use_Constraints"},
	{WUTM_Zone_Number,
	 "UTM_Zone_Number"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Vertical_Coordinate_System_Definition"},
	{WVertical_Count,
	 "Vertical_Count"},
	{WVertical_Positional_Accuracy,
	 "Vertical_Positional_Accuracy"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Vertical_Positional_Accuracy_Explanation"},
	{WVertical_Positional_Accuracy_Report,
	 "Vertical_Positional_Accuracy_Report"},
	{WVertical_Positional_Accuracy_Value,
	 "Vertical_Positional_Accuracy_Value"},
	{WVPF_Point_and_Vector_Object_Information,
	 "VPF_Point_and_Vector_Object_Information"},
	{WVPF_Point_and_Vector_Object_Type,
	 "VPF_Point_and_Vector_Object_Type"},
	{WVPF_Terms_Description,
	 "VPF_Terms_Description"},
	{WVPF_Topology_Level,
	 "VPF_Topology_Level"},
	{WWest_Bounding_Coordinate,
	 "West_Bounding_Coordinate"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*\
 | Español																|
 |																		|
 | Spanish-language element names kindly provided by					|
 | Clearinghouse Nacional de Datos Geográficos, Uruguay					|
 | <http://www.clearinghouse.gub.uy/>									|
\*----------------------------------------------------------------------*/

static struct keyword_list es_std[] = {
	{WAbscissa_Resolution,
	 "Resolución_de_Abscisa"},
	{WAbstract,
	 "Resumen"},
	{WAccess_Constraints,
	 "Restricciones_de_Acceso"},
	{WAccess_Instructions,
	 "Instrucciones_de_Acceso"},
	{WAddress,
	 "Dirección"},
	{WAddress_Type,
	 "Tipo_de_Dirección"},
	{WAlbers_Conical_Equal_Area,
	 "Iso_Área_Azimutal_de_Albers"},
	{WAltitude_Datum_Name,
	 "Nombre_del_Datum_de_Altitud"},
	{WAltitude_Distance_Units,
	 "Unidades_de_Distancia_en_Altitud"},
	{WAltitude_Encoding_Method,
	 "Método_de_Codificación_de_Altitud"},
	{WAltitude_Resolution,
	 "Resolución_en_Altitud"},
	{WAltitude_System_Definition,
	 "Definición_del_Sistema_de_Altitud"},
	{WARC_Coordinate_System,
	 "Sistema_ARC_de_Coordenadas"},
	{WARC_System_Zone_Identifier,
	 "Identificador_de_Zona_del_Sistema_ARC"},
	{WAttribute,
	 "Atributos"},
	{WAttribute_Accuracy,
	 "Atributo_de_Precisión"},
	{WAttribute_Accuracy_Explanation,
	 "Descripción_de_la_Precisión_del_Atributo"},
	{WAttribute_Accuracy_Report,
	 "Informe_Sobre_Atributo_de_Precisión"},
	{WAttribute_Accuracy_Value,
	 "Valor_del_Atributo_de_Precisión"},
	{WAttribute_Definition,
	 "Definición_del_Atributo"},
	{WAttribute_Definition_Source,
	 "Fuente_de_Definición_de_Atributos"},
	{WAttribute_Domain_Values,
	 "Rango_de_Valores_de_Atributos"},
	{WAttribute_Label,
	 "Etiqueta_del_Atributo"},
	{WAttribute_Measurement_Frequency,
	 "Frecuencia_de_Medidas_del_Atributo"},
	{WAttribute_Measurement_Resolution,
	 "Resolución_de_Medidas_del_Atributo"},
	{WAttribute_Units_of_Measure,
	 "Unidades_de_Medida_del_Atributo"},
	{WAttribute_Value_Accuracy,
	 "Precisión_de_Valores_del_Atributo"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Explicación_de_Precisión_de_Valores_del_Atributo"},
	{WAttribute_Value_Accuracy_Information,
	 "Información_de_Precisión_de_Valores_del_Atributo"},
	{WAvailable_Time_Period,
	 "Período_Con_Datos_Disponibles"},
	{WAzimuthal_Angle,
	 "Ángulo_Azimutal"},
	{WAzimuthal_Equidistant,
	 "Equidistante_Azimutal"},
	{WAzimuth_Measure_Point_Longitude,
	 "Longitud_del_Azimut_del_Punto_de_Medida"},
	{WBearing_Reference_Direction,
	 "Dirección_del_Rumbo_de_Referencia"},
	{WBearing_Reference_Meridian,
	 "Meridiano_del_Rumbo_de_Referencia"},
	{WBearing_Resolution,
	 "Resolución_de_Rumbo"},
	{WBearing_Units,
	 "Unidades_de_Rumbo"},
	{WBeginning_Date,
	 "Fecha_de_Comienzo"},
	{WBeginning_Date_of_Attribute_Values,
	 "Fecha_Inicial_de_Valores_del_Atributo"},
	{WBeginning_Time,
	 "Hora_de_Comienzo"},
	{WBounding_Coordinates,
	 "Coordenadas_Límites"},
	{WBrowse_Graphic,
	 "Gráfico_Para_Visualizar"},
	{WBrowse_Graphic_File_Description,
	 "Descripción_del_Archivo_Gráfico_Para_Visualizar"},
	{WBrowse_Graphic_File_Name,
	 "Nombre_del_Archivo_Gráfico_Para_Visualizar"},
	{WBrowse_Graphic_File_Type,
	 "Tipo_del_Archivo_Gráfico_Para_Visualizar"},
	{WCalendar_Date,
	 "Fecha_Calendario"},
	{WCitation,
	 "Cita"},
	{WCitation_Information,
	 "Información_Para_Cita"},
	{WCity,
	 "Ciudad"},
	{WCloud_Cover,
	 "Cubrimiento_por_Nubes"},
	{WCodeset_Domain,
	 "Dominio_del_Codeset"},
	{WCodeset_Name,
	 "Nombre_del_Codeset"},
	{WCodeset_Source,
	 "Fuente_del_Codeset"},
	{WColumn_Count,
	 "Número_de_Objetos_Raster_en_Eje_X"},
	{WCompatibility_Information,
	 "Información_de_Compatibilidad"},
	{WCompleteness_Report,
	 "Informe_Sobre_Completitud"},
	{WCompression_Support,
	 "Protocolos_de_Compresión_Soportados"},
	{WComputer_Contact_Information,
	 "Información_Para_Contacto_Con_Computador"},
	{WContact_Address,
	 "Dirección_de_Contacto"},
	{WContact_Electronic_Mail_Address,
	 "Correo_Electrónico_de_Contacto"},
	{WContact_Facsimile_Telephone,
	 "Facsímil_de_Contacto"},
	{WContact_Information,
	 "Información_de_Contacto"},
	{WContact_Instructions,
	 "Instrucciones_Para_Contacto"},
	{WContact_Organization,
	 "Organización_Para_Contacto"},
	{WContact_Organization_Primary,
	 "Contacto_Preferentemente_Con_Organización"},
	{WContact_Person,
	 "Persona_Para_Contacto"},
	{WContact_Person_Primary,
	 "Contacto_Preferentemente_Con_Persona"},
	{WContact_Position,
	 "Cargo_del_Contacto"},
	{WContact_TDD_TTY_Telephone,
	 "TDD_TTY_de_Contacto"},
	{WContact_Voice_Telephone,
	 "Teléfono_de_Contacto"},
	{WCoordinate_Representation,
	 "Representación_de_Coordenadas"},
	{WCountry,
	 "País"},
	{WCross_Reference,
	 "Referencia_Cruzada"},
	{WCurrentness_Reference,
	 "Vigencia"},
	{WCustom_Order_Process,
	 "Procesamiento_Personalizado_de_Pedidos"},
	{WData_Quality_Information,
	 "Información_de_Calidad_de_Datos"},
	{WData_Set_Credit,
	 "Crédito_del_Conjunto_de_Datos"},
	{WData_Set_G_Polygon,
	 "Polígono_Límite_de_los_Datos"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Polígono_Excluído_de_los_Datos"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Polígono_Externo_de_los_Datos"},
	{WDenominator_of_Flattening_Ratio,
	 "Denominador_de_la_Razón_de_Aplastamiento"},
	{WDepth_Datum_Name,
	 "Nombre_del_Datum_de_Profundidad"},
	{WDepth_Distance_Units,
	 "Unidades_de_Distancia_en_Profundidad"},
	{WDepth_Encoding_Method,
	 "Método_de_Codificación_de_Profundidad"},
	{WDepth_Resolution,
	 "Resolución_en_Profundidad"},
	{WDepth_System_Definition,
	 "Definición_del_Sistema_de_Profundidad"},
	{WDescription,
	 "Descripción"},
	{WDetailed_Description,
	 "Descripción_Detallada"},
	{WDialup_File_Name,
	 "Nombre_de_Archivo_de_Discado_Automático"},
	{WDialup_Instructions,
	 "Instrucciones_Para_Discado_Automático"},
	{WDialup_Telephone,
	 "Número_Telefónico_Para_Discado_Automático"},
	{WDigital_Form,
	 "Formato_Digital"},
	{WDigital_Transfer_Information,
	 "Información_Sobre_Transferencia_Digital"},
	{WDigital_Transfer_Option,
	 "Opción_Sobre_Transferencia_Digital"},
	{WDirect_Spatial_Reference_Method,
	 "Método_de_Referencia_Espacial_Directa"},
	{WDistance_and_Bearing_Representation,
	 "Representación_de_Distancia_y_Rumbo"},
	{WDistance_Resolution,
	 "Resolución_de_Distancia"},
	{WDistribution_Information,
	 "Información_de_Distribución"},
	{WDistribution_Liability,
	 "Responsabilidades_del_Distribuidor"},
	{WDistributor,
	 "Distribuidor"},
	{WEast_Bounding_Coordinate,
	 "Coordenada_Límite_al_Este"},
	{WEdition,
	 "Edición"},
	{WEllipsoid_Name,
	 "Nombre_del_Elipsoide"},
	{WEnding_Date,
	 "Fecha_de_Finalización"},
	{WEnding_Date_of_Attribute_Values,
	 "Fecha_Final_de_Valores_del_Atributo"},
	{WEnding_Time,
	 "Hora_de_Finalización"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Cita_Detallada_de_Entidad_y_Atributo"},
	{WEntity_and_Attribute_Information,
	 "Información_de_Entidad_y_Atributo"},
	{WEntity_and_Attribute_Overview,
	 "Resumen_Somero_de_Entidad_y_Atributo"},
	{WEntity_Type,
	 "Tipo_de_Entidad"},
	{WEntity_Type_Definition,
	 "Definición_de_Tipo_de_Entidad"},
	{WEntity_Type_Definition_Source,
	 "Fuente_de_Definición_de_Tipo_de_Entidad"},
	{WEntity_Type_Label,
	 "Etiqueta_de_Tipo_de_Entidad"},
	{WEnumerated_Domain,
	 "Dominio_Enumerado"},
	{WEnumerated_Domain_Value,
	 "Valores_del_Dominio_Enumerado"},
	{WEnumerated_Domain_Value_Definition,
	 "Definición_del_Dominio_Enumerado"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Fuente_Para_la_Definición_del_Dominio_Enumerado"},
	{WEquidistant_Conic,
	 "Cónica_Equidistante"},
	{WEquirectangular,
	 "Equirrectangular"},
	{WFalse_Easting,
	 "Falso_Este"},
	{WFalse_Northing,
	 "Falso_Norte"},
	{WFees,
	 "Tarifas"},
	{WFile_Decompression_Technique,
	 "Técnica_de_Descompresión_de_Archivos"},
	{WFormat_Information_Content,
	 "Información_del_Formato_del_Contenido"},
	{WFormat_Name,
	 "Nombre_del_Formato"},
	{WFormat_Specification,
	 "Especificación_del_Formato"},
	{WFormat_Version_Date,
	 "Fecha_de_Versión_del_Formato"},
	{WFormat_Version_Number,
	 "Número_de_Versión_del_Formato"},
	{WG_Ring,
	 "Poligonal_Geográfica"},
	{WG_Ring_Latitude,
	 "Latitud_de_Poligonal"},
	{WG_Ring_Longitude,
	 "Longitud_de_Poligonal"},
	{WG_Ring_Point,
	 "Punto_de_Poligonal_Geográfica"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "Perspectiva_de_Costado_General_Vertical"},
	{WGeodetic_Model,
	 "Modelo_Geodético"},
	{WGeographic,
	 "Geográfico"},
	{WGeographic_Coordinate_Units,
	 "Unidades_de_las_Coordenadas_Geográficas"},
	{WGeospatial_Data_Presentation_Form,
	 "Forma_de_Presentación_Geoespacial"},
	{WGnomonic,
	 "Nomónica"},
	{WGrid_Coordinate_System,
	 "Sistema_de_Coordenadas_de_Cuadrícula"},
	{WGrid_Coordinate_System_Name,
	 "Nombre_del_Sistema_de_Coordenadas_de_Cuadrícula"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Altura_del_Punto_de_Perspectiva_Sobre_la_Superficie"},
	{WHighest_BPS,
	 "Máxima_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Definición_del_Sistema_de_Coordenadas_Horizontales"},
	{WHorizontal_Datum_Name,
	 "Nombre_del_Datum_Horizontal"},
	{WHorizontal_Positional_Accuracy,
	 "Precisión_en_la_Horizontal"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Interpretación_de_Precisión_Posicional_Horizontal"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Informe_Sobre_Precisión_en_la_Horizontal"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Valor_de_Precisión_en_la_Horizontal"},
	{WHours_of_Service,
	 "Horario_de_Atención"},
	{WIdentification_Information,
	 "Información_de_Identificación"},
	{WIndirect_Spatial_Reference,
	 "Referencia_Espacial_Indirecta"},
	{WIssue_Identification,
	 "Identificación_del_Número"},
	{WKeywords,
	 "Palabras_Clave"},
	{WLambert_Azimuthal_Equal_Area,
	 "Iso_Área_Azimutal_de_Lambert"},
	{WLambert_Conformal_Conic,
	 "Cónica_Conforme_de_Lambert"},
	{WLandsat_Number,
	 "Número_Landsat"},
	{WLarger_Work_Citation,
	 "Cita_a_Trabajo_Mayor"},
	{WLatitude_of_Projection_Center,
	 "Latitud_del_Centro_de_la_Proyección"},
	{WLatitude_of_Projection_Origin,
	 "Latitud_del_Origen_de_la_Proyección"},
	{WLatitude_Resolution,
	 "Resolución_en_Latitud"},
	{WLineage,
	 "Linaje"},
	{WLocal,
	 "Local"},
	{WLocal_Description,
	 "Descripción_Local"},
	{WLocal_Georeference_Information,
	 "Información_de_Georreferenciación_Local"},
	{WLocal_Planar,
	 "Plana_Local"},
	{WLocal_Planar_Description,
	 "Descripción_de_la_Plana_Local"},
	{WLocal_Planar_Georeference_Information,
	 "Información_de_la_Georreferencia_de_la_Plana_Local"},
	{WLogical_Consistency_Report,
	 "Informe_Sobre_Consistencia_Lógica"},
	{WLongitude_of_Central_Meridian,
	 "Longitud_del_Meridiano_Central"},
	{WLongitude_of_Projection_Center,
	 "Longitud_del_Centro_de_la_Proyección"},
	{WLongitude_Resolution,
	 "Resolución_en_Longitud"},
	{WLowest_BPS,
	 "Mínima_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Frecuencia_de_Mantenimiento_y_Actualización"},
	{WMap_Projection,
	 "Proyección_Cartográfica"},
	{WMap_Projection_Name,
	 "Nombre_de_la_Proyección_Cartográfica"},
	{WMap_Projection_Parameters,
	 "Parámetros_de_la_Proyección_Cartográfica"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadatos"},
	{WMetadata_Access_Constraints,
	 "Restricciones_al_Acceso_a_los_Metadatos"},
	{WMetadata_Contact,
	 "Contacto_Por_Metadatos"},
	{WMetadata_Date,
	 "Fecha_de_Metadatos"},
	{WMetadata_Extensions,
	 "Extensiones_al_Estándar_de_Metadatos"},
	{WMetadata_Future_Review_Date,
	 "Fecha_de_Futura_Revisión_de_Metadatos"},
	{WMetadata_Language,
	 "Lenguaje_de_Metadatos"},
	{WMetadata_Reference_Information,
	 "Información_de_Referencia_de_Metadatos"},
	{WMetadata_Review_Date,
	 "Fecha_de_Última_Revisión_de_Metadatos"},
	{WMetadata_Security_Classification,
	 "Clasificación_de_Seguridad_de_Metadatos"},
	{WMetadata_Security_Classification_System,
	 "Sistema_de_Clasificación_de_Seguridad_de_Metadatos"},
	{WMetadata_Security_Handling_Description,
	 "Descripción_de_Precauciones_de_Manejo_de_Metadatos"},
	{WMetadata_Security_Information,
	 "Información_de_Seguridad_de_Metadatos"},
	{WMetadata_Standard_Name,
	 "Nombre_del_Estándar_de_Metadatos"},
	{WMetadata_Standard_Version,
	 "Versión_del_Estándar_de_Metadatos"},
	{WMetadata_Time_Convention,
	 "Convención_de_Fechas_en_Metadatos"},
	{WMetadata_Use_Constraints,
	 "Restricciones_al_Uso_de_Metadatos"},
	{WMiller_Cylindrical,
	 "Cilíndrica_de_Miller"},
	{WModified_Stereographic_for_Alaska,
	 "Estereográfica_Modificada_Para_Alaska"},
	{WMultiple_Dates_Times,
	 "Múltiples_Fecha_y_Hora"},
	{WNative_Data_Set_Environment,
	 "Entorno_Original_de_los_Datos"},
	{WNetwork_Address,
	 "Dirección_de_la_Red"},
	{WNetwork_Resource_Name,
	 "Nombre_del_Recurso_de_Red"},
	{WNon_digital_Form,
	 "Formato_No_Digital"},
	{WNorth_Bounding_Coordinate,
	 "Coordenada_Límite_al_Norte"},
	{WNumber_DataBits,
	 "Número_de_Bits_de_Datos"},
	{WNumber_StopBits,
	 "Número_de_Bits_de_Parada"},
	{WOblique_Line_Azimuth,
	 "Azimuth_de_Línea_Oblicua"},
	{WOblique_Line_Latitude,
	 "Latitud_de_Línea_Oblicua"},
	{WOblique_Line_Longitude,
	 "Longitud_de_Línea_Oblicua"},
	{WOblique_Line_Point,
	 "Punto_de_Línea_Oblicua"},
	{WOblique_Mercator,
	 "Mercator_Oblicuo"},
	{WOffline_Media,
	 "Medio_Físico_Fuera_de_Línea"},
	{WOffline_Option,
	 "Opción_Fuera_de_Línea"},
	{WOnline_Computer_and_Operating_System,
	 "Computadora_y_Sistema_Operativo_en_Línea"},
	{WOnline_Linkage,
	 "Acceso_en_Línea"},
	{WOnline_Option,
	 "Opción_en_Línea"},
	{WOrdering_Instructions,
	 "Instrucciones_Para_el_Pedido"},
	{WOrdinate_Resolution,
	 "Resolución_de_Ordenadas"},
	{WOriginator,
	 "Productor"},
	{WOrthographic,
	 "Ortográfico"},
	{WOther_Citation_Details,
	 "Otros_Detalles_de_la_Cita"},
	{WOther_Grid_Systems_Definition,
	 "Definición_de_Otro_Sistema_de_Cuadrícula"},
	{WOther_Projections_Definition,
	 "Definición_de_Otra_Proyección"},
	{WOverview_Description,
	 "Descripción_Somera"},
	{WParity,
	 "Paridad"},
	{WPath_Number,
	 "Número_de_Camino"},
	{WPlace,
	 "Lugar"},
	{WPlace_Keyword,
	 "Palabra_Clave_de_Lugar"},
	{WPlace_Keyword_Thesaurus,
	 "Tesauro_de_Palabras_Clave_de_Lugar"},
	{WPlanar,
	 "Plano"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Método_Codificado_de_Coordenadas_Plana"},
	{WPlanar_Coordinate_Information,
	 "Información_de_Coordenadas_Plana"},
	{WPlanar_Distance_Units,
	 "Unidades_de_Distancias_Planas"},
	{WPoint_and_Vector_Object_Count,
	 "Cantidad_de_Objetos_Punto_y_Vector"},
	{WPoint_and_Vector_Object_Information,
	 "Información_de_Objetos_Punto_y_Vector"},
	{WPoint_of_Contact,
	 "Punto_de_Contacto"},
	{WPolar_Stereographic,
	 "Estereográfico_Polar"},
	{WPolyconic,
	 "Policónico"},
	{WPositional_Accuracy,
	 "Precisión_de_la_Posición"},
	{WPostal_Code,
	 "Código_Postal"},
	{WProcess_Contact,
	 "Contacto_Por_el_Proceso"},
	{WProcess_Date,
	 "Fecha_del_Proceso"},
	{WProcess_Description,
	 "Descripción_del_Proceso"},
	{WProcess_Step,
	 "Paso_del_Proceso"},
	{WProcess_Time,
	 "Hora_del_Proceso"},
	{WProfile_Name,
	 "Nombre_del_Perfil"},
	{WProgress,
	 "Avance"},
	{WPublication_Date,
	 "Fecha_de_Publicación"},
	{WPublication_Information,
	 "Información_de_la_Publicación"},
	{WPublication_Place,
	 "Lugar_de_la_Publicación"},
	{WPublication_Time,
	 "Hora_de_Publicación"},
	{WPublisher,
	 "Impresor"},
	{WPurpose,
	 "Propósito"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Determinación_Cuantitativa_Sobre_Precisión_en_Atributos"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Declaración_de_Precisión_Posicional_Horizontal"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Declaración_de_Precisión_Posicional_Vertical"},
	{WRange_Domain,
	 "Dominio_del_Rango"},
	{WRange_Domain_Maximum,
	 "Máximo_del_Dominio_del_Rango"},
	{WRange_Domain_Minimum,
	 "Mínimo_del_Dominio_del_Rango"},
	{WRange_of_Dates_Times,
	 "Rango_de_Fechas_y_Horas"},
	{WRaster_Object_Information,
	 "Información_Sobre_Objetos_Raster"},
	{WRaster_Object_Type,
	 "Tipo_de_Objetos_Raster"},
	{WRecording_Capacity,
	 "Capacidad_de_Grabación"},
	{WRecording_Density,
	 "Densidad_de_Grabación"},
	{WRecording_Density_Units,
	 "Unidades_de_Densidad_de_Grabación"},
	{WRecording_Format,
	 "Formato_de_Grabación"},
	{WResource_Description,
	 "Descripción_del_Recurso"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Número_de_Objetos_Raster_en_Eje_Y"},
	{WScale_Factor_at_Center_Line,
	 "Factor_de_Escala_en_la_Línea_Central"},
	{WScale_Factor_at_Central_Meridian,
	 "Factor_de_Escala_en_el_Meridiano_Central"},
	{WScale_Factor_at_Equator,
	 "Factor_de_Escala_en_el_Ecuador"},
	{WScale_Factor_at_Projection_Origin,
	 "Factor_de_Escala_en_el_Origen_de_la_Proyección"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "Tipo_de_Objetos_Punto_y_Vector_SDTS"},
	{WSDTS_Terms_Description,
	 "Descripción_de_Términos_SDTS"},
	{WSecurity_Classification,
	 "Clasificación_de_Seguridad"},
	{WSecurity_Classification_System,
	 "Sistema_de_Clasificación_de_Seguridad"},
	{WSecurity_Handling_Description,
	 "Descripción_del_Manejo_de_Seguridad"},
	{WSecurity_Information,
	 "Información_de_Seguridad"},
	{WSemi_major_Axis,
	 "Semi-eje_Mayor"},
	{WSeries_Information,
	 "Información_de_la_Serie"},
	{WSeries_Name,
	 "Nombre_de_la_Serie"},
	{WSingle_Date_Time,
	 "Fecha_y_Hora"},
	{WSinusoidal,
	 "Sinusoidal"},
	{WSource_Citation,
	 "Cita_de_la_Fuente"},
	{WSource_Citation_Abbreviation,
	 "Abreviación_de_Cita_de_la_Fuente"},
	{WSource_Contribution,
	 "Contribución_de_la_Fuente"},
	{WSource_Currentness_Reference,
	 "Referencia_a_Vigencia_de_la_Fuente"},
	{WSource_Information,
	 "Información_de_la_Fuente"},
	{WSource_Produced_Citation_Abbreviation,
	 "Abreviatura_de_Cita_de_la_Fuente_Producida"},
	{WSource_Scale_Denominator,
	 "Denominador_de_Escala_de_la_Fuente"},
	{WSource_Time_Period_of_Content,
	 "Período_Contenido_en_la_Fuente"},
	{WSource_Used_Citation_Abbreviation,
	 "Abreviatura_Usual_de_Cita_de_la_Fuente"},
	{WSouth_Bounding_Coordinate,
	 "Coordenada_Límite_al_Sur"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Mercator_Espacial_Oblicua_(Landsat)"},
	{WSpatial_Data_Organization_Information,
	 "Información_de_Organización_de_Datos_Espaciales"},
	{WSpatial_Domain,
	 "Dominio_Espacial"},
	{WSpatial_Reference_Information,
	 "Información_de_Referencia_Espacial"},
	{WSPCS_Zone_Identifier,
	 "Identificador_de_Zona_SPCS"},
	{WStandard_Order_Process,
	 "Procesamiento_Estándar_de_Pedidos"},
	{WStandard_Parallel,
	 "Paralelo_Estándar"},
	{WState_or_Province,
	 "Estado_O_Provincia"},
	{WState_Plane_Coordinate_System,
	 "Sistema_Estatal_de_Coordenadas_Planas"},
	{WStatus,
	 "Estatus"},
	{WStereographic,
	 "Estereográfica"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Longitud_Vertical-Recta_Desde_el_Polo"},
	{WStratum,
	 "Estrato"},
	{WStratum_Keyword,
	 "Palabra_Clave_de_Estrato"},
	{WStratum_Keyword_Thesaurus,
	 "Tesauro_de_Palabras_Clave_de_Estrato"},
	{WSupplemental_Information,
	 "Información_Suplementaria"},
	{WTechnical_Prerequisites,
	 "Prerrequisitos_Técnicos"},
	{WTemporal,
	 "Temporal"},
	{WTemporal_Keyword,
	 "Palabra_Clave_de_Tiempo"},
	{WTemporal_Keyword_Thesaurus,
	 "Tesauro_de_Palabras_Clave_de_Tiempo"},
	{WTheme,
	 "Tema"},
	{WTheme_Keyword,
	 "Palabra_Clave_de_Tema"},
	{WTheme_Keyword_Thesaurus,
	 "Tesauro_de_Palabras_Clave_de_Tema"},
	{WTime_of_Day,
	 "Hora_del_Día"},
	{WTime_Period_Information,
	 "Información_de_Período_de_Tiempo"},
	{WTime_Period_of_Content,
	 "Período_Asociado_al_Contenido"},
	{WTitle,
	 "Título"},
	{WTransfer_Size,
	 "Tamaño_de_Transferencia"},
	{WTransverse_Mercator,
	 "Mercator_Transverso"},
	{WTurnaround,
	 "Tiempo_de_Entrega"},
	{WType_of_Source_Media,
	 "Tipo_de_Medio_Físico_de_la_Fuente"},
	{WUniversal_Polar_Stereographic,
	 "Estereográfica_Polar_Universal"},
	{WUniversal_Transverse_Mercator,
	 "Mercator_Transversa_Universal"},
	{WUnrepresentable_Domain,
	 "Dominio_No_Representable"},
	{WUPS_Zone_Identifier,
	 "Identificador_de_Zona_UPS"},
	{WUse_Constraints,
	 "Restricciones_de_Uso"},
	{WUTM_Zone_Number,
	 "Número_de_Zona_UTM"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Definición_del_Sistema_de_Coordenadas_Verticales"},
	{WVertical_Count,
	 "Número_de_Objetos_Raster_en_Eje_Z"},
	{WVertical_Positional_Accuracy,
	 "Precisión_en_la_Vertical"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Interpretación_de_Precisión_Posicional_Vertical"},
	{WVertical_Positional_Accuracy_Report,
	 "Informe_Sobre_Precisión_en_la_Vertical"},
	{WVertical_Positional_Accuracy_Value,
	 "Valor_de_Precisión_en_la_Vertical"},
	{WVPF_Point_and_Vector_Object_Information,
	 "Información_de_Objetos_Punto_y_Vector_VPF"},
	{WVPF_Point_and_Vector_Object_Type,
	 "Tipo_de_Objetos_Punto_y_Vector_VPF"},
	{WVPF_Terms_Description,
	 "Descripción_de_Términos_VPF"},
	{WVPF_Topology_Level,
	 "Nivel_de_Topología_VPF"},
	{WWest_Bounding_Coordinate,
	 "Coordenada_Límite_al_Oeste"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*\
 | French
 |
 | from John Cree
\*----------------------------------------------------------------------*/

static struct keyword_list fr_std[] = {
	{WAbscissa_Resolution,
	 "Résolution_en_abscisse"},
	{WAbstract,
	 "Résumé"},
	{WAccess_Constraints,
	 "Contraintes_d'accès"},
	{WAccess_Instructions,
	 "Instructions_d'accès"},
	{WAddress,
	 "Adresse"},
	{WAddress_Type,
	 "Type_d'adresse"},
	{WAlbers_Conical_Equal_Area,
	 "Conique_équivalente_d'Albers"},
	{WAltitude_Datum_Name,
	 "Nom_du_plan_de_référence_altimétrique"},
	{WAltitude_Distance_Units,
	 "Unités_de_distance_de_l'altitude"},
	{WAltitude_Encoding_Method,
	 "Méthode_de_codage_de_l'altitude"},
	{WAltitude_Resolution,
	 "Résolution_en_altitude"},
	{WAltitude_System_Definition,
	 "Définition_du_système_altimétrique"},
	{WARC_Coordinate_System,
	 "Système_de_coordonnées_ARC"},
	{WARC_System_Zone_Identifier,
	 "Identifiant_de_zone_du_système_ARC"},
	{WAttribute,
	 "Attribut"},
	{WAttribute_Accuracy,
	 "Précision_d'attribut"},
	{WAttribute_Accuracy_Explanation,
	 "Explication_de_la_précision_d'attribut"},
	{WAttribute_Accuracy_Report,
	 "Rapport_sur_la_précision_d'attribut"},
	{WAttribute_Accuracy_Value,
	 "Valeur_de_la_précision_d'attribut"},
	{WAttribute_Definition,
	 "Définition_de_l'attribut"},
	{WAttribute_Definition_Source,
	 "Source_de_définition_de_l'attribut"},
	{WAttribute_Domain_Values,
	 "Valeurs_du_domaine_de_l'attribut"},
	{WAttribute_Label,
	 "Annotation_d'attribut"},
	{WAttribute_Measurement_Frequency,
	 "Fréquence_de_mesure_de_l'attribut"},
	{WAttribute_Measurement_Resolution,
	 "Résolution_de_la_mesure_d'attribut"},
	{WAttribute_Units_of_Measure,
	 "Unités_de_mesure_de_l'attribut"},
	{WAttribute_Value_Accuracy,
	 "Précision_des_valeurs_d'attribut"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Explication_de_la_précision_des_valeurs_d'attribut"},
	{WAttribute_Value_Accuracy_Information,
	 "Information_sur_la_précision_des_valeurs_d'attribut"},
	{WAvailable_Time_Period,
	 "Période_de_temps_de_disponibilité"},
	{WAzimuthal_Angle,
	 "Angle_azimutal"},
	{WAzimuthal_Equidistant,
	 "Azimutale_équidistante"},
	{WAzimuth_Measure_Point_Longitude,
	 "Longitude_du_point_de_mesure_de_l'azimut"},
	{WBearing_Reference_Direction,
	 "Direction_de_référence_pour_les_angles_de_relèvement"},
	{WBearing_Reference_Meridian,
	 "Méridien_de_référence_pour_les_angles_de_relèvement"},
	{WBearing_Resolution,
	 "Résolution_en_angle_de_relèvement"},
	{WBearing_Units,
	 "Unités_d'angle_de_relèvement"},
	{WBeginning_Date,
	 "Date_de_début"},
	{WBeginning_Date_of_Attribute_Values,
	 "Date_de_début_des_valeurs_d'attribut"},
	{WBeginning_Time,
	 "Temps_de_début"},
	{WBounding_Coordinates,
	 "Coordonnées_de_délimitation"},
	{WBrowse_Graphic,
	 "Aperçu_graphique"},
	{WBrowse_Graphic_File_Description,
	 "Description_de_l'aperçu_graphique"},
	{WBrowse_Graphic_File_Name,
	 "Nom_d'aperçu_graphique"},
	{WBrowse_Graphic_File_Type,
	 "Type_d'aperçu_graphique"},
	{WCalendar_Date,
	 "Date_du_calendrier"},
	{WCitation,
	 "Citation"},
	{WCitation_Information,
	 "Information_de_citation"},
	{WCity,
	 "Ville"},
	{WCloud_Cover,
	 "Couverture_nuageuse"},
	{WCodeset_Domain,
	 "Domaine_de_l'ensemble_de_code"},
	{WCodeset_Name,
	 "Nom_du_domaine_de_l'ensemble_de_code"},
	{WCodeset_Source,
	 "Source_de_l'ensemble_de_code"},
	{WColumn_Count,
	 "Nombre_de_colonnes"},
	{WCompatibility_Information,
	 "Information_sur_la_compatibilité"},
	{WCompleteness_Report,
	 "Rapport_de_complétude"},
	{WCompression_Support,
	 "Support_de_compression"},
	{WComputer_Contact_Information,
	 "Information_sur_l'ordinateur_du_contact"},
	{WContact_Address,
	 "Adresse_du_contact"},
	{WContact_Electronic_Mail_Address,
	 "Courriel_du_contact"},
	{WContact_Facsimile_Telephone,
	 "Télécopieur_du_contact"},
	{WContact_Information,
	 "Information_sur_le_contact"},
	{WContact_Instructions,
	 "Instructions_sur_le_contact"},
	{WContact_Organization,
	 "Organisation_contact"},
	{WContact_Organization_Primary,
	 "Organisation_contact_primaire"},
	{WContact_Person,
	 "Personne_contact"},
	{WContact_Person_Primary,
	 "Personne_contact_primaire"},
	{WContact_Position,
	 "Position_du_contact"},
	{WContact_TDD_TTY_Telephone,
	 "Numéro_de_téléphone_ATME_du_contact"},
	{WContact_Voice_Telephone,
	 "Numéro_de_téléphone_du_contact"},
	{WCoordinate_Representation,
	 "Représentation_par_coordonnées"},
	{WCountry,
	 "Pays"},
	{WCross_Reference,
	 "Renvoi"},
	{WCurrentness_Reference,
	 "Référence_à_l'actualité"},
	{WCustom_Order_Process,
	 "Processus_de_commande_spéciale"},
	{WData_Quality_Information,
	 "Information_sur_la_qualité_des_données"},
	{WData_Set_Credit,
	 "Crédit_pour_l'ensemble_des_données"},
	{WData_Set_G_Polygon,
	 "Polygone-G_de_l'ensemble_de_données"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Cercle-G_d'exclusion_du_polygone-G_de_l'ensemble_de_données"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Cercle-G_extérieur_du_polygone-G_de_l'ensemble_de_données"},
	{WDenominator_of_Flattening_Ratio,
	 "Dénominateur_du_rapport_d'aplatissement"},
	{WDepth_Datum_Name,
	 "Nom_du_plan_de_référence_des_profondeurs"},
	{WDepth_Distance_Units,
	 "Unités_de_distance_en_profondeur"},
	{WDepth_Encoding_Method,
	 "Méthode_de_codage_de_la_profondeur"},
	{WDepth_Resolution,
	 "Résolution_en_profondeur"},
	{WDepth_System_Definition,
	 "Définition_du_système_de_la_profondeur"},
	{WDescription,
	 "Description"},
	{WDetailed_Description,
	 "Description_détaillée"},
	{WDialup_File_Name,
	 "Nom_du_fichier_d'accès_commuté"},
	{WDialup_Instructions,
	 "Instructions_d'accès_commuté"},
	{WDialup_Telephone,
	 "Numéro_de_téléphone_d'accès_commuté"},
	{WDigital_Form,
	 "Forme_numérique"},
	{WDigital_Transfer_Information,
	 "Information_de_transfert_numérique"},
	{WDigital_Transfer_Option,
	 "Option_de_transfert_numérique"},
	{WDirect_Spatial_Reference_Method,
	 "Méthode_de_référence_spatiale_directe"},
	{WDistance_and_Bearing_Representation,
	 "Représentation_par_distance_et_par_angle_de_relèvement"},
	{WDistance_Resolution,
	 "Résolution_en_distance"},
	{WDistribution_Information,
	 "Information_de_distribution"},
	{WDistribution_Liability,
	 "Responsabilité_de_distribution"},
	{WDistributor,
	 "Distributeur"},
	{WEast_Bounding_Coordinate,
	 "Coordonnée_de_délimitation_Est"},
	{WEdition,
	 "Édition"},
	{WEllipsoid_Name,
	 "Nom_de_l'ellipsoïde"},
	{WEnding_Date,
	 "Date_de_fin"},
	{WEnding_Date_of_Attribute_Values,
	 "Date_de_fin_des_valeurs_d'attribut"},
	{WEnding_Time,
	 "Temps_de_fin"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Citation_détaillée_sur_l'entité_et_l'attribut"},
	{WEntity_and_Attribute_Information,
	 "Information_sur_l'entité_et_l'attribut"},
	{WEntity_and_Attribute_Overview,
	 "Sommaire_des_entités_et_des_attributs"},
	{WEntity_Type,
	 "Type_d'entité"},
	{WEntity_Type_Definition,
	 "Définition_de_type_d'entité"},
	{WEntity_Type_Definition_Source,
	 "Source_de_la_définition_de_type_d'entité"},
	{WEntity_Type_Label,
	 "Annotation_du_type_d'entité"},
	{WEnumerated_Domain,
	 "Domaine_d'énumérations"},
	{WEnumerated_Domain_Value,
	 "Valeur_du_domaine_d'énumérations"},
	{WEnumerated_Domain_Value_Definition,
	 "Définition_du_domaine_d'énumérations"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Source_de_définition_du_domaine_d'énumérations"},
	{WEquidistant_Conic,
	 "Conique_équidistante"},
	{WEquirectangular,
	 "Équirectangulaire"},
	{WFalse_Easting,
	 "Abscisse_fictive"},
	{WFalse_Northing,
	 "Ordonnée_fictive"},
	{WFees,
	 "Frais"},
	{WFile_Decompression_Technique,
	 "Technique_de_décompression_des_fichiers"},
	{WFormat_Information_Content,
	 "Contenu_informationnel_du_format"},
	{WFormat_Name,
	 "Nom_du_format"},
	{WFormat_Specification,
	 "Spécification_de_la_version_du_format"},
	{WFormat_Version_Date,
	 "Date_de_version_du_format"},
	{WFormat_Version_Number,
	 "Numéro_de_version_de_format"},
	{WG_Ring,
	 "Cercle-G"},
	{WG_Ring_Latitude,
	 "Latitude_du_cercle-G"},
	{WG_Ring_Longitude,
	 "Longitude_du_cercle-G"},
	{WG_Ring_Point,
	 "Point_du_cercle-G"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "Perspective_verticale_générale_proximale"},
	{WGeodetic_Model,
	 "Modèle_géodésique"},
	{WGeographic,
	 "Géographique"},
	{WGeographic_Coordinate_Units,
	 "Unités_des_coordonnées_géographiques"},
	{WGeospatial_Data_Presentation_Form,
	 "Forme_de_présentation_de_données_géospatiales"},
	{WGnomonic,
	 "Gnomonique"},
	{WGrid_Coordinate_System,
	 "Système_de_coordonnées_cartésiennes_orthogonales"},
	{WGrid_Coordinate_System_Name,
	 "Nom_du_système_de_coordonnées_cartésiennes_orthogonales"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Hauteur_du_point_de_perspective_au-dessus_de_la_surface"},
	{WHighest_BPS,
	 "Débit_maximal_en_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Définition_du_système_de_coordonnées_horizontales"},
	{WHorizontal_Datum_Name,
	 "Nom_du_système_de_référence"},
	{WHorizontal_Positional_Accuracy,
	 "Précision_d'alignement_horizontal"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Explication_de_la_précision_d'alignement_horizontal"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Rapport_sur_la_précision_d'alignement_horizontal"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Valeur_de_précision_d'alignement_horizontal"},
	{WHours_of_Service,
	 "Heures_de_service"},
	{WIdentification_Information,
	 "Information_d'identification"},
	{WIndirect_Spatial_Reference,
	 "Référence_spatiale_indirecte"},
	{WIssue_Identification,
	 "Identification_du_numéro"},
	{WKeywords,
	 "Mots-clés"},
	{WLambert_Azimuthal_Equal_Area,
	 "Azimutale_équivalente_de_Lambert"},
	{WLambert_Conformal_Conic,
	 "Conique_conforme_de_Lambert"},
	{WLandsat_Number,
	 "Numéro_du_satellite_Landsat"},
	{WLarger_Work_Citation,
	 "Citation_d'un_ouvrage_plus_grand"},
	{WLatitude_of_Projection_Center,
	 "Latitude_du_centre_de_la_projection"},
	{WLatitude_of_Projection_Origin,
	 "Latitude_de_l'origine_de_la_projection"},
	{WLatitude_Resolution,
	 "Résolution_en_latitude"},
	{WLineage,
	 "Lignage"},
	{WLocal,
	 "Système_de_coordonnées_local"},
	{WLocal_Description,
	 "Description_du_système_local_de_coordonnées"},
	{WLocal_Georeference_Information,
	 "Information_géoréférencée_du_système_local"},
	{WLocal_Planar,
	 "Système_local_de_coordonnées_planes"},
	{WLocal_Planar_Description,
	 "Description_du_système_local_de_coordonnées_planes"},
	{WLocal_Planar_Georeference_Information,
	 "Information_géoréférencée_sur_le_système_local_de_coordonnées_planes"},
	{WLogical_Consistency_Report,
	 "Rapport_de_cohérence_logique"},
	{WLongitude_of_Central_Meridian,
	 "Longitude_du_méridien_central"},
	{WLongitude_of_Projection_Center,
	 "Longitude_du_centre_de_la_projection"},
	{WLongitude_Resolution,
	 "Résolution_en_longitude"},
	{WLowest_BPS,
	 "Débit_minimal_en_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Fréquence_de_mise_à_jour_et_d'actualisation"},
	{WMap_Projection,
	 "Projection_cartographique"},
	{WMap_Projection_Name,
	 "Nom_de_la_projection_cartographique"},
	{WMap_Projection_Parameters,
	 "Paramètres_de_la_projection_cartographique"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Métadonnées"},
	{WMetadata_Access_Constraints,
	 "Contraintes_d'accès_aux_métadonnées"},
	{WMetadata_Contact,
	 "Contact_pour_les_métadonnées"},
	{WMetadata_Date,
	 "Date_des_métadonnées"},
	{WMetadata_Extensions,
	 "Extensions_des_métadonnées"},
	{WMetadata_Future_Review_Date,
	 "Date_de_la_prochaine_révision_des_métadonnées"},
	{WMetadata_Language,
	 "Langue_d'utilisation_pour_les_metadonnees"},
	{WMetadata_Reference_Information,
	 "Information_de_référence_sur_les_métadonnées"},
	{WMetadata_Review_Date,
	 "Date_de_révision_des_métadonnées"},
	{WMetadata_Security_Classification,
	 "Classification_de_sécurité_des_métadonnées"},
	{WMetadata_Security_Classification_System,
	 "Système_de_classification_de_la_sécurité_des_métadonnées"},
	{WMetadata_Security_Handling_Description,
	 "Description_des_consignes_de_sécurité_pour_les_métadonnées"},
	{WMetadata_Security_Information,
	 "Information_sur_la_sécurité_des_métadonnées"},
	{WMetadata_Standard_Name,
	 "Nom_des_normes_utilisées_pour_les_métadonnées"},
	{WMetadata_Standard_Version,
	 "Version_des_normes_des_métadonnées"},
	{WMetadata_Time_Convention,
	 "Convention_de_temps_pour_les_métadonnées"},
	{WMetadata_Use_Constraints,
	 "Contraintes_d'utilisation_des_métadonnées"},
	{WMiller_Cylindrical,
	 "Cylindrique_de_Miller"},
	{WModified_Stereographic_for_Alaska,
	 "Stéréographique_modifiée_pour_l'Alaska"},
	{WMultiple_Dates_Times,
	 "Variété_de_dates_et_temps"},
	{WNative_Data_Set_Environment,
	 "Environnement_natif_de_l'ensemble_de_données"},
	{WNetwork_Address,
	 "Adresse_réseau"},
	{WNetwork_Resource_Name,
	 "Nom_de_la_ressource_réseau_(URL)"},
	{WNon_digital_Form,
	 "Forme_non_numérique"},
	{WNorth_Bounding_Coordinate,
	 "Coordonnée_de_délimitation_Nord"},
	{WNumber_DataBits,
	 "Nombre_de_bits_de_données"},
	{WNumber_StopBits,
	 "Nombre_de_bits_d'arrêt"},
	{WOblique_Line_Azimuth,
	 "Azimut_de_ligne_oblique"},
	{WOblique_Line_Latitude,
	 "Latitude_de_définition_de_l'oblique"},
	{WOblique_Line_Longitude,
	 "Longitude_de_définition_de_l'oblique"},
	{WOblique_Line_Point,
	 "Point_de_l'oblique"},
	{WOblique_Mercator,
	 "Mercator_oblique"},
	{WOffline_Media,
	 "Média_hors_ligne"},
	{WOffline_Option,
	 "Option_hors_ligne"},
	{WOnline_Computer_and_Operating_System,
	 "Ordinateur_en_ligne_et_système_d'exploitation"},
	{WOnline_Linkage,
	 "Lien_en_direct"},
	{WOnline_Option,
	 "Option_en_ligne"},
	{WOrdering_Instructions,
	 "Instructions_pour_commander"},
	{WOrdinate_Resolution,
	 "Résolution_en_ordonnée"},
	{WOriginator,
	 "Créateur"},
	{WOrthographic,
	 "Orthographique"},
	{WOther_Citation_Details,
	 "Autres_détails_de_citation"},
	{WOther_Grid_Systems_Definition,
	 "Autre_définition_de_systèmes_de_quadrillage"},
	{WOther_Projections_Definition,
	 "Définition_d'autre_projection"},
	{WOverview_Description,
	 "Description_sommaire"},
	{WParity,
	 "Parité"},
	{WPath_Number,
	 "Numéro_de_trajectoire"},
	{WPlace,
	 "Lieu"},
	{WPlace_Keyword,
	 "Mot-clé_de_lieu"},
	{WPlace_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_de_lieu"},
	{WPlanar,
	 "Planair"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Méthode_de_codage_des_coordonnées_planes"},
	{WPlanar_Coordinate_Information,
	 "Information_sur_les_coordonnées_planes"},
	{WPlanar_Distance_Units,
	 "Unités_de_distance_en_coordonnées_planes"},
	{WPoint_and_Vector_Object_Count,
	 "Nombre_d'objets_ponctuels_et_vectoriels"},
	{WPoint_and_Vector_Object_Information,
	 "Information_sur_l'objet_ponctuel_et_vectoriel"},
	{WPoint_of_Contact,
	 "Contact"},
	{WPolar_Stereographic,
	 "Stéréographique_polaire"},
	{WPolyconic,
	 "Polyconique"},
	{WPositional_Accuracy,
	 "Précision_d'alignement"},
	{WPostal_Code,
	 "Code_postal"},
	{WProcess_Contact,
	 "Contact_du_processus"},
	{WProcess_Date,
	 "Date_du_processus"},
	{WProcess_Description,
	 "Description_du_processus"},
	{WProcess_Step,
	 "Étape_du_processus"},
	{WProcess_Time,
	 "Temps_du_processus"},
	{WProfile_Name,
	 "Nom_du_profil"},
	{WProgress,
	 "Progrès"},
	{WPublication_Date,
	 "Date_de_publication"},
	{WPublication_Information,
	 "Information_de_publication"},
	{WPublication_Place,
	 "Lieu_de_publication"},
	{WPublication_Time,
	 "Temps_de_publication"},
	{WPublisher,
	 "Éditeur"},
	{WPurpose,
	 "But"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Évaluation_quantitative_de_la_précision_d'attribut"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Évaluation_quantitative_de_la_précision_d'alignement_horizontal"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Évaluation_quantitative_de_la_précision_d'alignement_vertical"},
	{WRange_Domain,
	 "Domaine_des_limites"},
	{WRange_Domain_Maximum,
	 "Maximum_du_domaine_de_limites"},
	{WRange_Domain_Minimum,
	 "Minimum_du_domaine_de_limites"},
	{WRange_of_Dates_Times,
	 "Plusieurs_dates_et_temps"},
	{WRaster_Object_Information,
	 "Information_sur_les_objets_matriciels"},
	{WRaster_Object_Type,
	 "Type_d'objet_matriciel"},
	{WRecording_Capacity,
	 "Capacité_d'enregistrement"},
	{WRecording_Density,
	 "Densité_d'enregistrement"},
	{WRecording_Density_Units,
	 "Unités_de_densité_d'enregistrement"},
	{WRecording_Format,
	 "Format_d'enregistrement"},
	{WResource_Description,
	 "Description_de_la_ressource"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Nombre_de_rangées"},
	{WScale_Factor_at_Center_Line,
	 "Facteur_d'échelle_à_la_ligne_centrale"},
	{WScale_Factor_at_Central_Meridian,
	 "Facteur_d'échelle_au_méridien_central"},
	{WScale_Factor_at_Equator,
	 "Facteur_d'échelle_à_l'équateur"},
	{WScale_Factor_at_Projection_Origin,
	 "Facteur_d'échelle_à_l'origine_de_la_projection"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "Type_d'objet_vectoriel_et_ponctuel_SDTS"},
	{WSDTS_Terms_Description,
	 "Description_des_termes_SDTS"},
	{WSecurity_Classification,
	 "Sécurité_de_la_classification"},
	{WSecurity_Classification_System,
	 "Système_de_sécurité_de_la_classification"},
	{WSecurity_Handling_Description,
	 "Description_des_consignes_de_sécurité"},
	{WSecurity_Information,
	 "Information_sur_la_sécurité"},
	{WSemi_major_Axis,
	 "Demi-grand_axe"},
	{WSeries_Information,
	 "Information_sur_la_série"},
	{WSeries_Name,
	 "Nom_de_la_série"},
	{WSingle_Date_Time,
	 "Date/temps_unique"},
	{WSinusoidal,
	 "Sinusoïdale"},
	{WSource_Citation,
	 "Citation_de_la_source"},
	{WSource_Citation_Abbreviation,
	 "Citation_abrégée_de_la_source"},
	{WSource_Contribution,
	 "Contribution_de_la_source"},
	{WSource_Currentness_Reference,
	 "Référence_à_l'actualité_de_la_source"},
	{WSource_Information,
	 "Information_sur_la_source"},
	{WSource_Produced_Citation_Abbreviation,
	 "Citation_abrégée_produite_par_la_source"},
	{WSource_Scale_Denominator,
	 "Dénominateur_de_l'échelle_de_la_source"},
	{WSource_Time_Period_of_Content,
	 "Période_de_temps_du_contenu_de_la_source"},
	{WSource_Used_Citation_Abbreviation,
	 "Citation_abrégée_utilisée_par_la_source"},
	{WSouth_Bounding_Coordinate,
	 "Coordonnée_de_délimitation_Sud"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Mercator_oblique_spatiale_(Landsat)"},
	{WSpatial_Data_Organization_Information,
	 "Information_sur_l'organisation_des_données_spatiales"},
	{WSpatial_Domain,
	 "Domaine_spatial"},
	{WSpatial_Reference_Information,
	 "Information_de_référence_spatiale"},
	{WSPCS_Zone_Identifier,
	 "Identifiant_de_zone_SPCE"},
	{WStandard_Order_Process,
	 "Processus_de_commande_standard"},
	{WStandard_Parallel,
	 "Parallèle_standard"},
	{WState_or_Province,
	 "État_ou_province"},
	{WState_Plane_Coordinate_System,
	 "Système_de_coordonnées_planes_d'État_(SCPE)_(State_Plane_Coordinate_System_-_SPCS)"},
	{WStatus,
	 "État"},
	{WStereographic,
	 "Stéréographique"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Longitude_rectiligne_verticale_à_partir_du_pôle"},
	{WStratum,
	 "Strate"},
	{WStratum_Keyword,
	 "Mot-clé_de_strate"},
	{WStratum_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_de_strate"},
	{WSupplemental_Information,
	 "Information_supplémentaire"},
	{WTechnical_Prerequisites,
	 "Exigences_techniques"},
	{WTemporal,
	 "Temporel"},
	{WTemporal_Keyword,
	 "Mot-clé_temporel"},
	{WTemporal_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_temporels"},
	{WTheme,
	 "Thème"},
	{WTheme_Keyword,
	 "Mot-clé_du_thème"},
	{WTheme_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_du_thème"},
	{WTime_of_Day,
	 "Temps_du_jour"},
	{WTime_Period_Information,
	 "Information_sur_la_période_de_temps"},
	{WTime_Period_of_Content,
	 "Période_de_temps_du_contenu"},
	{WTitle,
	 "Titre"},
	{WTransfer_Size,
	 "Taille_du_transfert"},
	{WTransverse_Mercator,
	 "Mercator_transverse"},
	{WTurnaround,
	 "Temps_de_réponse"},
	{WType_of_Source_Media,
	 "Type_de_média_de_la_source"},
	{WUniversal_Polar_Stereographic,
	 "Stéréographique_polaire_universel_(SPU)"},
	{WUniversal_Transverse_Mercator,
	 "Universelle_transverse_de_Mercator_(UTM)"},
	{WUnrepresentable_Domain,
	 "Domaine_non_représentable"},
	{WUPS_Zone_Identifier,
	 "Identifiant_de_zone_SPU"},
	{WUse_Constraints,
	 "Contraintes_d'utilisation"},
	{WUTM_Zone_Number,
	 "Numéro_de_zone_UTM"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Définition_du_système_de_coordonnées_verticales"},
	{WVertical_Count,
	 "Nombre_à_la_verticale"},
	{WVertical_Positional_Accuracy,
	 "Précision_d'alignement_vertical"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Explication_de_la_précision_d'alignement_vertical"},
	{WVertical_Positional_Accuracy_Report,
	 "Rapport_sur_la_précision_d'alignement_vertical"},
	{WVertical_Positional_Accuracy_Value,
	 "Valeur_de_la_précision_d'alignement_vertical"},
	{WVPF_Point_and_Vector_Object_Information,
	 "Information_sur_les_objets_ponctuels_et_vectoriels_VPF"},
	{WVPF_Point_and_Vector_Object_Type,
	 "Type_d'objet_ponctuel_et_vectoriel_VPF"},
	{WVPF_Terms_Description,
	 "Description_des_termes_VPF"},
	{WVPF_Topology_Level,
	 "Niveau_topologique_VPF"},
	{WWest_Bounding_Coordinate,
	 "Coordonnée_de_délimitation_Ouest"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
	 "Description_de_l'étendue_géographique"},
	{WBounding_Altitudes,
	 "Altitudes_de_délimitation"},
	{WAltitude_Minimum,
	 "Altitude_Minimum"},
	{WAltitude_Maximum,
	 "Altitude_Maximum"},
	{WTaxonomy,
	 "Taxonomie"},
	{WKeywords_Taxon,
	 "Mots-clés/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_taxonomiques"},
	{WTaxonomic_Keywords,
	 "Mots-clés_taxonomiques"},
	{WTaxonomic_System,
	 "Système_taxonomique"},
	{WClassification_System_Authority,
	 "Système/Autorité_de_classification"},
	{WClassification_System_Citation,
	 "Citation_du_système_de_classification"},
	{WClassification_System_Modifications,
	 "Modifications_au_système_de_classification"},
	{WIdentification_Reference,
	 "Référence_d'identification"},
	{WIdentifier,
	 "Identifiant"},
	{WTaxonomic_Procedures,
	 "Procédures_taxonomiques"},
	{WTaxonomic_Completeness,
	 "Complétude_taxonomique"},
	{WVouchers,
	 "Spécimens_témoins"},
	{WSpecimen,
	 "Spécimen"},
	{WRepository,
	 "Dépôt"},
	{WGeneral_Taxonomic_Coverage,
	 "Couverture_taxonomique_générale"},
	{WTaxonomic_Classification,
	 "Classification_taxonomique"},
	{WTaxon_Rank_Name,
	 "Nom_du_rang_du_taxon"},
	{WTaxon_Rank_Value,
	 "Valeur_du_rang_du_taxon"},
	{WApplicable_Common_Name,
	 "Nom_commun_pertinent"},
	{WAnalytical_Tool,
	 "Outil_analytique"},
	{WAnalytical_Tool_Description,
	 "Description_de_l'outil_analytique"},
	{WTool_Access_Information,
	 "Information_sur_l'accès_à_l'outil"},
	{WTool_Contact,
	 "Contact_pour_l'outil"},
	{WTool_Citation,
	 "Citations_sur_l'outil"},
	{WTool_Access_Instructions,
	 "Instructions_d'accès_à_l'outil"},
	{WTool_Computer_and_Operating_System,
	 "Ordinateur_et_système_d'exploitation_utilisés_pour_l'outil"},
	{WMethodology,
	 "Méthodologie"},
	{WMethodology_Type,
	 "Type_de_méthodologie"},
	{WMethodology_Identifier,
	 "Identifiant_de_méthodologie"},
	{WMethodology_Keyword_Thesaurus,
	 "Thésaurus_de_mots-clés_méthodologiques"},
	{WMethodology_Keyword,
	 "Mots-clés_méthodologiques"},
	{WMethodology_Description,
	 "Description_de_la_méthodologie"},
	{WMethodology_Citation,
	 "Citation_de_méthodologie"},
	{WASCII_File_Structure,
	 "Structure_des_fichiers_ASCII"},
	{WRecord_Delimiter,
	 "Délimiteur_d'enregistrement"},
	{WNumber_Header_Lines,
	 "Nombre_de_lignes_de_l'en-tête"},
	{WDescription_of_Header_Content,
	 "Description_de_l'en-tête"},
	{WOrientation,
	 "Orientation"},
	{WCase_Sensitive,
	 "Sensibilité_à_la_casse"},
	{WAuthentication,
	 "Authentification"},
	{WQuote_Character,
	 "Guillemets"},
	{WData_Field,
	 "Champ_de_donnes"},
	{WData_Field_Name,
	 "Nom_du_champ_de_données"},
	{WMissing_Value_Code,
	 "Code_de_valeur_manquante"},
	{WData_Field_Width_Delimiter,
	 "Délimiteur_de_la_largeur_des_champs_de_données"},
	{WData_Field_Width,
	 "Largeur_du_champ_de_donnees"},
	{WBeginning_Geologic_Age,
	 "Âge_géologique_de_début"},
	{WEnding_Geologic_Age,
	 "Âge_géologique_de_fin"},
	{WGeologic_Age,
	 "Âge_géologique"},
	{WGeologic_Time_Scale,
	 "Échelle_de_temps_géologique"},
	{WGeologic_Age_Estimate,
	 "Estimation_de_l'âge_géologique"},
	{WGeologic_Age_Uncertainty,
	 "Incertitude_de_l'âge_géologique"},
	{WGeologic_Age_Explanation,
	 "Explication_de_l'âge_géologique"},
	{WGeologic_Citation,
	 "Informations_bibliographiques_géologiques"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*\
 | Indonesian															|
 |																		|
 | Indonesian-language element names kindly provided by the Indonesian	|
 | National Coordination Agency for Surveys and Mapping BAKOSURTANAL	|
\*----------------------------------------------------------------------*/

static struct keyword_list id_std[] = {
	{WAbscissa_Resolution,
	 "Resolusi_Abscissa"},
	{WAbstract,
	 "Abstrak"},
	{WAccess_Constraints,
	 "Batasan_Akses_ke_Data"},
	{WAccess_Instructions,
	 "Akses_Instruksi"},
	{WAddress,
	 "Alamat"},
	{WAddress_Type,
	 "Tipe_Alamat"},
	{WAlbers_Conical_Equal_Area,
	 "Albers_Conical_Equal_Area"},
	{WAltitude_Datum_Name,
	 "Altitude_Datum_Name"},
	{WAltitude_Distance_Units,
	 "Altitude_Distance_Units"},
	{WAltitude_Encoding_Method,
	 "Altitude_Encoding_Method"},
	{WAltitude_Resolution,
	 "Altitude_Resolution"},
	{WAltitude_System_Definition,
	 "Altitude_System_Definition"},
	{WARC_Coordinate_System,
	 "ARC_Coordinate_System"},
	{WARC_System_Zone_Identifier,
	 "ARC_System_Zone_Identifier"},
	{WAttribute,
	 "Atribut"},
	{WAttribute_Accuracy,
	 "Ketelitian_Atribut"},
	{WAttribute_Accuracy_Explanation,
	 "Keterangan_Ketelitian_Atribut"},
	{WAttribute_Accuracy_Report,
	 "Laporan_Ketelitian_Atribut"},
	{WAttribute_Accuracy_Value,
	 "Nilai_Ketelitian_Atribut"},
	{WAttribute_Definition,
	 "Definisi_Atribut"},
	{WAttribute_Definition_Source,
	 "Sumber_Definisi_Atribut"},
	{WAttribute_Domain_Values,
	 "Nilai_Atribut"},
	{WAttribute_Label,
	 "Label_Atribut"},
	{WAttribute_Measurement_Frequency,
	 "Frekuensi_Ukuran_Atribut"},
	{WAttribute_Measurement_Resolution,
	 "Resolusi_Ukuran_Atribut"},
	{WAttribute_Units_of_Measure,
	 "Satuan_Atribut"},
	{WAttribute_Value_Accuracy,
	 "Ketelitian_Nilai_Atribut"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Keterangan_Ketelitian_Nilai_Atribut"},
	{WAttribute_Value_Accuracy_Information,
	 "Informasi_Ketelitian_Nilai_Atribut"},
	{WAvailable_Time_Period,
	 "Waktu_Yang_Tersedia"},
	{WAzimuthal_Angle,
	 "Sudut_Azimut"},
	{WAzimuthal_Equidistant,
	 "Jarak_Azimut"},
	{WAzimuth_Measure_Point_Longitude,
	 "Azimuth_Measure_Point_Longitude"},
	{WBearing_Reference_Direction,
	 "Bearing_Reference_Direction"},
	{WBearing_Reference_Meridian,
	 "Bearing_Reference_Meridian"},
	{WBearing_Resolution,
	 "Bearing_Resolution"},
	{WBearing_Units,
	 "Bearing_Units"},
	{WBeginning_Date,
	 "Tanggal_Mulai"},
	{WBeginning_Date_of_Attribute_Values,
	 "Tanggal_Mulai_Penilaian_Atribut"},
	{WBeginning_Time,
	 "Waktu_Mulai"},
	{WBounding_Coordinates,
	 "Batas_Koordinat"},
	{WBrowse_Graphic,
	 "Gambaran_Data"},
	{WBrowse_Graphic_File_Description,
	 "Deskripsi_File_Gambaran_Data"},
	{WBrowse_Graphic_File_Name,
	 "Nama_File_Gambaran_Data"},
	{WBrowse_Graphic_File_Type,
	 "Tipe_File_Gambaran_Data"},
	{WCalendar_Date,
	 "Tanggal"},
	{WCitation,
	 "Sitasi"},
	{WCitation_Information,
	 "Informasi_Sitasi"},
	{WCity,
	 "Kota"},
	{WCloud_Cover,
	 "Tutupan_Awan"},
	{WCodeset_Domain,
	 "Kode_Letak"},
	{WCodeset_Name,
	 "Kode_Nama"},
	{WCodeset_Source,
	 "Kode_Sumber"},
	{WColumn_Count,
	 "Jumlah_Kolom"},
	{WCompatibility_Information,
	 "Informasi_Kesesuaian"},
	{WCompleteness_Report,
	 "Kelengkapan_Laporan"},
	{WCompression_Support,
	 "Compression_Support"},
	{WComputer_Contact_Information,
	 "Kontak_Informasi_Komputer"},
	{WContact_Address,
	 "Kontak_Alamat"},
	{WContact_Electronic_Mail_Address,
	 "E-mail"},
	{WContact_Facsimile_Telephone,
	 "Faksimili"},
	{WContact_Information,
	 "Informasi_Kontak"},
	{WContact_Instructions,
	 "Kontak_Instruksi"},
	{WContact_Organization,
	 "Kontak_Organisasi"},
	{WContact_Organization_Primary,
	 "Kontak_Organisasi_Utama"},
	{WContact_Person,
	 "Kontak_Personil"},
	{WContact_Person_Primary,
	 "Kontak_Personil_Utama"},
	{WContact_Position,
	 "Kontak_Jabatan"},
	{WContact_TDD_TTY_Telephone,
	 "Contact_TDD/TTY_Telephone"},
	{WContact_Voice_Telephone,
	 "Telepon"},
	{WCoordinate_Representation,
	 "Koordinat_Yang_Mewakili"},
	{WCountry,
	 "Negara"},
	{WCross_Reference,
	 "Acuan_Lain"},
	{WCurrentness_Reference,
	 "Acuan_Terbaru"},
	{WCustom_Order_Process,
	 "Tatacara_Pemesanan"},
	{WData_Quality_Information,
	 "Informasi_Kualitas_Data"},
	{WData_Set_Credit,
	 "Penghargaan_Data"},
	{WData_Set_G_Polygon,
	 "Data_Set_G-Polygon"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Data_Set_G-Polygon_Exclusion_G-Ring"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Data_Set_G-Polygon_Outer_G-Ring"},
	{WDenominator_of_Flattening_Ratio,
	 "Denominator_of_Flattening_Ratio"},
	{WDepth_Datum_Name,
	 "Nama_Detil_Datum"},
	{WDepth_Distance_Units,
	 "Satuan_Detil_Jarak"},
	{WDepth_Encoding_Method,
	 "Metode_Detil_Kodifikasi"},
	{WDepth_Resolution,
	 "Resolusi_Detil"},
	{WDepth_System_Definition,
	 "Detil_Definisi_Sistim"},
	{WDescription,
	 "Diskripsi"},
	{WDetailed_Description,
	 "Diskripsi_Detil"},
	{WDialup_File_Name,
	 "Dialup_File_Name"},
	{WDialup_Instructions,
	 "Instruksi_Dialup"},
	{WDialup_Telephone,
	 "Telephone_Dialup"},
	{WDigital_Form,
	 "Bentuk_Dijital"},
	{WDigital_Transfer_Information,
	 "Informasi_Transfer_Dijital"},
	{WDigital_Transfer_Option,
	 "Pilihan_Transfer_Dijital"},
	{WDirect_Spatial_Reference_Method,
	 "Metode_Referensi_Spasial_Langsung"},
	{WDistance_and_Bearing_Representation,
	 "Distance_and_Bearing_Representation"},
	{WDistance_Resolution,
	 "Resolusi_Jarak"},
	{WDistribution_Information,
	 "Informasi_Distribusi"},
	{WDistribution_Liability,
	 "Jaminan_Distribusi"},
	{WDistributor,
	 "Distribusi"},
	{WEast_Bounding_Coordinate,
	 "Koordinat_Batas_Timur"},
	{WEdition,
	 "Edisi"},
	{WEllipsoid_Name,
	 "Nama_Elipsoid"},
	{WEnding_Date,
	 "Tanggal_Akhir"},
	{WEnding_Date_of_Attribute_Values,
	 "Tanggal_Akhir_Nilai_Atribut"},
	{WEnding_Time,
	 "Waktu_Akhir"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Sitasi_Detil_Entitas_dan_Atribut"},
	{WEntity_and_Attribute_Information,
	 "Informasi_Entitas_dan_Atribut"},
	{WEntity_and_Attribute_Overview,
	 "Gambaran_Umum_Entitas_dan_Atribut"},
	{WEntity_Type,
	 "Tipe_Entitas"},
	{WEntity_Type_Definition,
	 "Definisi_Tipe_Entitas"},
	{WEntity_Type_Definition_Source,
	 "Sumber_Definisi_Tipe_Entitas"},
	{WEntity_Type_Label,
	 "Label_Tipe_Entitas"},
	{WEnumerated_Domain,
	 "Daftar_Kategori"},
	{WEnumerated_Domain_Value,
	 "Label_Kategori"},
	{WEnumerated_Domain_Value_Definition,
	 "Definisi_Label_Kategori"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Sumber_Definisi_Label_Kategori"},
	{WEquidistant_Conic,
	 "Equidistant_Conic"},
	{WEquirectangular,
	 "Equirectangular"},
	{WFalse_Easting,
	 "False_Easting"},
	{WFalse_Northing,
	 "False_Northing"},
	{WFees,
	 "Biaya"},
	{WFile_Decompression_Technique,
	 "Tehnik_Pengkompresan_File"},
	{WFormat_Information_Content,
	 "Isi_Informasi_Format"},
	{WFormat_Name,
	 "Nama_Format"},
	{WFormat_Specification,
	 "Spesifikasi_Format"},
	{WFormat_Version_Date,
	 "Tanggal_Versi_Format"},
	{WFormat_Version_Number,
	 "Nomor_Versi_Format"},
	{WG_Ring,
	 "G-Ring"},
	{WG_Ring_Latitude,
	 "G-Ring_Latitude"},
	{WG_Ring_Longitude,
	 "G-Ring_Longitude"},
	{WG_Ring_Point,
	 "G-Ring_Point"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "General_Vertical_Near-sided_Perspective"},
	{WGeodetic_Model,
	 "Model_Geodetik"},
	{WGeographic,
	 "Geografi"},
	{WGeographic_Coordinate_Units,
	 "Unit_Koordinat_Geografi"},
	{WGeospatial_Data_Presentation_Form,
	 "Bentuk_Tampilan_Data_Geospasial"},
	{WGnomonic,
	 "Gnomonic"},
	{WGrid_Coordinate_System,
	 "Sistim_Koordinat_Grid"},
	{WGrid_Coordinate_System_Name,
	 "Nama_Sistim_Koordinat_Grid"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Height_of_Perspective_Point_Above_Surface"},
	{WHighest_BPS,
	 "Highest_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Definisi_Sistim_Koordinat_Horizontal"},
	{WHorizontal_Datum_Name,
	 "Nama_Datum_Horizontal"},
	{WHorizontal_Positional_Accuracy,
	 "Ketelitian_Posisi_Horizontal"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Keterangan_Ketelitian_Posisi_Horizontal"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Laporan_Ketelitian_Posisi_Horizontal"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Nilai_Ketelitian_Posisi_Horizontal"},
	{WHours_of_Service,
	 "Waktu_Pelayanan"},
	{WIdentification_Information,
	 "Informasi_Identifikasi"},
	{WIndirect_Spatial_Reference,
	 "Acuan_Spasial_Tidak_Langsung"},
	{WIssue_Identification,
	 "Identitas_Terbitan"},
	{WKeywords,
	 "Kata_Kunci"},
	{WLambert_Azimuthal_Equal_Area,
	 "Lambert_Azimuthal_Equal_Area"},
	{WLambert_Conformal_Conic,
	 "Lambert_Conformal_Conic"},
	{WLandsat_Number,
	 "Nomor_Landsat"},
	{WLarger_Work_Citation,
	 "Larger_Work_Citation"},
	{WLatitude_of_Projection_Center,
	 "Lintang_Titik_Pusat_Proyeksi"},
	{WLatitude_of_Projection_Origin,
	 "Lintang_Proyeksi_Asli"},
	{WLatitude_Resolution,
	 "Resolusi_Lintang"},
	{WLineage,
	 "Silsilah"},
	{WLocal,
	 "Lokal"},
	{WLocal_Description,
	 "Diskripsi_Lokal"},
	{WLocal_Georeference_Information,
	 "Informasi_Georeferensi_Lokal"},
	{WLocal_Planar,
	 "Planar_Lokal"},
	{WLocal_Planar_Description,
	 "Diskripsi_Planar_Lokal"},
	{WLocal_Planar_Georeference_Information,
	 "Informasi_Georeferensi_Planar_Lokal"},
	{WLogical_Consistency_Report,
	 "Keterangan_Konsistensi_Data"},
	{WLongitude_of_Central_Meridian,
	 "Bujur_dari_Titik_Pusat_Meridian"},
	{WLongitude_of_Projection_Center,
	 "Bujur_dari_Titik_Pusat_Proyeksi"},
	{WLongitude_Resolution,
	 "Resolusi_Bujur"},
	{WLowest_BPS,
	 "BPS_Terendah"},
	{WMaintenance_and_Update_Frequency,
	 "Frekuensi_Perubahan_dan_Penambahan_Data"},
	{WMap_Projection,
	 "Proyeksi_Peta"},
	{WMap_Projection_Name,
	 "Nama_Proyeksi_Peta"},
	{WMap_Projection_Parameters,
	 "Map_Projection_Parameters"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadata"},
	{WMetadata_Access_Constraints,
	 "Batasan_Akses_ke_Metadata"},
	{WMetadata_Contact,
	 "Kontak_Metadata"},
	{WMetadata_Date,
	 "Tanggal_Metadata"},
	{WMetadata_Extensions,
	 "Metadata_Extensions"},
	{WMetadata_Future_Review_Date,
	 "Tanggal_Pembaharuan_Ulang_Metadata"},
	{WMetadata_Language,
	 "Metadata_Language"},
	{WMetadata_Reference_Information,
	 "Informasi_Acuan_Metadata"},
	{WMetadata_Review_Date,
	 "Tanggal_Pembaharuan_Metadata"},
	{WMetadata_Security_Classification,
	 "Klasifikasi_Keamanan_Metadata"},
	{WMetadata_Security_Classification_System,
	 "Sistim_Klasifikasi_Keamanan_Metadata"},
	{WMetadata_Security_Handling_Description,
	 "Diskripsi_Penanganan_Keamanan_Metadata"},
	{WMetadata_Security_Information,
	 "Informasi_Keamanan_Metadata"},
	{WMetadata_Standard_Name,
	 "Nama_Standar_Metadata"},
	{WMetadata_Standard_Version,
	 "Versi_Standar_Metadata"},
	{WMetadata_Time_Convention,
	 "Waktu_Ketentuan_Metadata"},
	{WMetadata_Use_Constraints,
	 "Batasan_Penggunaan_Metadata"},
	{WMiller_Cylindrical,
	 "Miller_Cylindrical"},
	{WModified_Stereographic_for_Alaska,
	 "Modified_Stereographic_for_Alaska"},
	{WMultiple_Dates_Times,
	 "Multi_Waktu"},
	{WNative_Data_Set_Environment,
	 "Lingkup_Pengolahan_Data"},
	{WNetwork_Address,
	 "Alamat_Network"},
	{WNetwork_Resource_Name,
	 "Nama_Sumber_Network"},
	{WNon_digital_Form,
	 "Bentuk_Non_Dijital"},
	{WNorth_Bounding_Coordinate,
	 "Koordinat_Batas_Utara"},
	{WNumber_DataBits,
	 "Number_DataBits"},
	{WNumber_StopBits,
	 "Number_StopBits"},
	{WOblique_Line_Azimuth,
	 "Oblique_Line_Azimuth"},
	{WOblique_Line_Latitude,
	 "Oblique_Line_Latitude"},
	{WOblique_Line_Longitude,
	 "Oblique_Line_Longitude"},
	{WOblique_Line_Point,
	 "Oblique_Line_Point"},
	{WOblique_Mercator,
	 "Oblique_Mercator"},
	{WOffline_Media,
	 "Media_Offline"},
	{WOffline_Option,
	 "Pilihan_Offline"},
	{WOnline_Computer_and_Operating_System,
	 "Online_Komputer_dan_Sistim_Operasi"},
	{WOnline_Linkage,
	 "Jaringan_Online"},
	{WOnline_Option,
	 "Pilihan_Online"},
	{WOrdering_Instructions,
	 "Instruksi_Pemesanan"},
	{WOrdinate_Resolution,
	 "Resolusi_Ordinat"},
	{WOriginator,
	 "Pemilik_Data"},
	{WOrthographic,
	 "Orthographi"},
	{WOther_Citation_Details,
	 "Detil_Sitasi_Lainnya"},
	{WOther_Grid_Systems_Definition,
	 "Definisi_Sistim_Grid_Lainnya"},
	{WOther_Projections_Definition,
	 "Definisi_Proyeksi_Lainnya"},
	{WOverview_Description,
	 "Diskripsi_Gambaran_Umum"},
	{WParity,
	 "Parity"},
	{WPath_Number,
	 "Nomor_Path"},
	{WPlace,
	 "Tempat"},
	{WPlace_Keyword,
	 "Kata_Kunci_Tempat"},
	{WPlace_Keyword_Thesaurus,
	 "Kata_Kunci_Tempat_Thesaurus"},
	{WPlanar,
	 "Planar"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Metode_Pengkodean_Koordinat_Planar"},
	{WPlanar_Coordinate_Information,
	 "Informasi_Koordinat_Planar"},
	{WPlanar_Distance_Units,
	 "Satuan_Jarak_Planar"},
	{WPoint_and_Vector_Object_Count,
	 "Jumlah_Obyek_Titik_dan_Vektor"},
	{WPoint_and_Vector_Object_Information,
	 "Informasi_Obyek_Titik_dan_Vektor"},
	{WPoint_of_Contact,
	 "Titik_Kontak"},
	{WPolar_Stereographic,
	 "Stereografi_Polar"},
	{WPolyconic,
	 "Polyconic"},
	{WPositional_Accuracy,
	 "Ketelitian_Posisi"},
	{WPostal_Code,
	 "Kode_Pos"},
	{WProcess_Contact,
	 "Kontak_Proses"},
	{WProcess_Date,
	 "Tanggal_Proses"},
	{WProcess_Description,
	 "Diskripsi_Kegiatan"},
	{WProcess_Step,
	 "Tahap_Kegiatan"},
	{WProcess_Time,
	 "Waktu_Kegiatan"},
	{WProfile_Name,
	 "Profile_Name"},
	{WProgress,
	 "Kemajuan_Data"},
	{WPublication_Date,
	 "Tanggal_Penerbitan"},
	{WPublication_Information,
	 "Informasi_Penerbitan"},
	{WPublication_Place,
	 "Tempat_Penerbitan"},
	{WPublication_Time,
	 "Waktu_Penerbitan"},
	{WPublisher,
	 "Penerbit"},
	{WPurpose,
	 "Tujuan"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Kajian_Kuantitatif_Ketelitian_Atribut"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Kajian_Kuantitatif_Ketelitian_Posisi_Horizontal"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Kajian_Kuantitatif_Ketelitian_Posisi_Vertikal"},
	{WRange_Domain,
	 "Interval"},
	{WRange_Domain_Maximum,
	 "Kisaran_Maximum"},
	{WRange_Domain_Minimum,
	 "Kisaran_Minimum"},
	{WRange_of_Dates_Times,
	 "Kisaran_Waktu"},
	{WRaster_Object_Information,
	 "Informasi_Obyek_Raster"},
	{WRaster_Object_Type,
	 "Tipe_Obyek_Raster"},
	{WRecording_Capacity,
	 "Kapasitas_Rekaman"},
	{WRecording_Density,
	 "Kepadatan_Rekaman"},
	{WRecording_Density_Units,
	 "Satuan_Kepadatan_Rekaman"},
	{WRecording_Format,
	 "Format_Rekaman"},
	{WResource_Description,
	 "Diskripsi_Sumber"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Jumlah_Baris"},
	{WScale_Factor_at_Center_Line,
	 "Faktor_Skala_pada_Garis_Pusat"},
	{WScale_Factor_at_Central_Meridian,
	 "Faktor_Skala_pada_Pusat_Meridian"},
	{WScale_Factor_at_Equator,
	 "Faktor_Skala_di_Ekuator"},
	{WScale_Factor_at_Projection_Origin,
	 "Faktor_Skala_Pada_Proyeksi_Asli"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "SDTS_Point_and_Vector_Object_Type"},
	{WSDTS_Terms_Description,
	 "SDTS_Terms_Description"},
	{WSecurity_Classification,
	 "Klasifikasi_Keamanan"},
	{WSecurity_Classification_System,
	 "Sistim_Klasifikasi_Keamanan"},
	{WSecurity_Handling_Description,
	 "Diskripsi_Penanganan_Keamanan"},
	{WSecurity_Information,
	 "Informasi_Keamanan"},
	{WSemi_major_Axis,
	 "Sumbu_Semi_Mayor"},
	{WSeries_Information,
	 "Informasi_Serial"},
	{WSeries_Name,
	 "Nama_Serial"},
	{WSingle_Date_Time,
	 "Tanggal/Waktu_Tunggal"},
	{WSinusoidal,
	 "Sinusoidal"},
	{WSource_Citation,
	 "Sumber_Sitasi"},
	{WSource_Citation_Abbreviation,
	 "Singkatan_Sumber_Sitasi"},
	{WSource_Contribution,
	 "Kontribusi_Sumber"},
	{WSource_Currentness_Reference,
	 "Sumber_Acuan_Terbaru"},
	{WSource_Information,
	 "Informasi_Sumber"},
	{WSource_Produced_Citation_Abbreviation,
	 "Singkatan_Sumber_Produk_Sitasi"},
	{WSource_Scale_Denominator,
	 "Skala_Sumber_Data"},
	{WSource_Time_Period_of_Content,
	 "Periode_Waktu_Pengambilan_Data_Sumber"},
	{WSource_Used_Citation_Abbreviation,
	 "Singkatan_Sumber_Sitasi_yang_Digunakan"},
	{WSouth_Bounding_Coordinate,
	 "Koordinat_Batas_Selatan"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Space_Oblique_Mercator_Landsat"},
	{WSpatial_Data_Organization_Information,
	 "Informasi_Organisasi_Data_Spasial"},
	{WSpatial_Domain,
	 "Letak_Geografis"},
	{WSpatial_Reference_Information,
	 "Informasi_Acuan_Spasial"},
	{WSPCS_Zone_Identifier,
	 "Identitas_Zone_SPCS"},
	{WStandard_Order_Process,
	 "Standar_Proses_Pemesanan"},
	{WStandard_Parallel,
	 "Standard_Paralel"},
	{WState_or_Province,
	 "Propinsi"},
	{WState_Plane_Coordinate_System,
	 "Sistim_Koordinat_State_Plane"},
	{WStatus,
	 "Status"},
	{WStereographic,
	 "Stereografi"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Straight-Vertical_Longitude_from_Pole"},
	{WStratum,
	 "Strata"},
	{WStratum_Keyword,
	 "Kata_Kunci_Strata"},
	{WStratum_Keyword_Thesaurus,
	 "Kata_Kunci_Strata_Thesaurus"},
	{WSupplemental_Information,
	 "Informasi_Tambahan"},
	{WTechnical_Prerequisites,
	 "Persyaratan_Teknis"},
	{WTemporal,
	 "Waktu"},
	{WTemporal_Keyword,
	 "Kata_Kunci_Waktu"},
	{WTemporal_Keyword_Thesaurus,
	 "Kata_Kunci_Waktu_Thesaurus"},
	{WTheme,
	 "Tema"},
	{WTheme_Keyword,
	 "Kata_Kunci_Tema"},
	{WTheme_Keyword_Thesaurus,
	 "Kata_Kunci_Tema_Thesaurus"},
	{WTime_of_Day,
	 "Hari"},
	{WTime_Period_Information,
	 "Informasi_Waktu"},
	{WTime_Period_of_Content,
	 "Waktu_Pengambilan_Data"},
	{WTitle,
	 "Judul"},
	{WTransfer_Size,
	 "Ukuran_Transfer"},
	{WTransverse_Mercator,
	 "Transverse_Mercator"},
	{WTurnaround,
	 "Turnaround"},
	{WType_of_Source_Media,
	 "Media_Sumber_Data"},
	{WUniversal_Polar_Stereographic,
	 "Universal_Polar_Stereographic"},
	{WUniversal_Transverse_Mercator,
	 "Universal_Transverse_Mercator"},
	{WUnrepresentable_Domain,
	 "Unrepresentable_Domain"},
	{WUPS_Zone_Identifier,
	 "Identitas_Zone_UPS"},
	{WUse_Constraints,
	 "Batasan_Penggunaan_Data"},
	{WUTM_Zone_Number,
	 "Nomor_Zone_UTM"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Definisi_Sistim_Koordinat_Vertikal"},
	{WVertical_Count,
	 "Jumlah_Vertikal"},
	{WVertical_Positional_Accuracy,
	 "Ketelitian_Posisi_Vertikal"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Keterangan_Ketelitian_Posisi_Vertikal"},
	{WVertical_Positional_Accuracy_Report,
	 "Laporan_Ketelitian_Posisi_Vertikal"},
	{WVertical_Positional_Accuracy_Value,
	 "Nilai_Ketelitian_Posisi_Vertikal"},
	{WVPF_Point_and_Vector_Object_Information,
	 "VPF_Point_and_Vector_Object_Information"},
	{WVPF_Point_and_Vector_Object_Type,
	 "Tipe_Obyek_Vektor_dan_Titik_VPF"},
	{WVPF_Terms_Description,
	 "VPF_Terms_Description"},
	{WVPF_Topology_Level,
	 "Tingkat_Topologi_VPF"},
	{WWest_Bounding_Coordinate,
	 "Koordinat_Batas_Barat"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*\
 | Catalán																|
 |																		|
 | Catalán-language element names kindly provided by					|
 | Clearinghouse Nacional de Datos Geográficos, Uruguay					|
 | <http://www.clearinghouse.gub.uy/>									|
\*----------------------------------------------------------------------*/

static struct keyword_list ca_std[] = {
	{WAbscissa_Resolution,
	 "Resolució_d'Abscisa"},
	{WAbstract,
	 "Resum"},
	{WAccess_Constraints,
	 "Restriccions_d'Accés"},
	{WAccess_Instructions,
	 "Instruccions_d'Accés"},
	{WAddress,
	 "Direcció"},
	{WAddress_Type,
	 "Tipologia_de_Direcció"},
	{WAlbers_Conical_Equal_Area,
	 "Iso_Àrea_Azimutal_d'Albers"},
	{WAltitude_Datum_Name,
	 "Nom_del_Dàtum_d'Altitud"},
	{WAltitude_Distance_Units,
	 "Unitats_de_Distància_de_l'Altitud"},
	{WAltitude_Encoding_Method,
	 "Mètode_de_Codificació_de_l'Altitud"},
	{WAltitude_Resolution,
	 "Resolució_de_l'Altitud"},
	{WAltitude_System_Definition,
	 "Definició_del_Sistema_d'Altitud"},
	{WARC_Coordinate_System,
	 "Sistema_ARC_de_Coordenades"},
	{WARC_System_Zone_Identifier,
	 "Identificador_de_Zona_del_Sistema_ARC"},
	{WAttribute,
	 "Atributs"},
	{WAttribute_Accuracy,
	 "Atribut_de_Precisió"},
	{WAttribute_Accuracy_Explanation,
	 "Descripció_de_la_Precisió_de_l'Atribut"},
	{WAttribute_Accuracy_Report,
	 "Informe_Sobre_Atribut_de_Precisió"},
	{WAttribute_Accuracy_Value,
	 "Valor_de_l'Atribut_de_Precisió"},
	{WAttribute_Definition,
	 "Definició_de_l'Atribut"},
	{WAttribute_Definition_Source,
	 "Font_de_Definició_d'Atributs"},
	{WAttribute_Domain_Values,
	 "Rang_de_Valors_d'Atributs"},
	{WAttribute_Label,
	 "Etiqueta_de_l'Atribut"},
	{WAttribute_Measurement_Frequency,
	 "Freqüència_de_Mesures_de_l'Atribut"},
	{WAttribute_Measurement_Resolution,
	 "Resolució_de_Mesures_de_l'Atribut"},
	{WAttribute_Units_of_Measure,
	 "Unitats_de_Mesura_de_l'Atribut"},
	{WAttribute_Value_Accuracy,
	 "Precisió_de_Valors_de_l'Atribut"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Explicació_de_Precisió_de_Valors_de_l'Atribut"},
	{WAttribute_Value_Accuracy_Information,
	 "Informació_de_Precisió_de_Valors_de_l'Atribut"},
	{WAvailable_Time_Period,
	 "Període_Amb_Dades_Disponibles"},
	{WAzimuthal_Angle,
	 "Angle_Azimutal"},
	{WAzimuthal_Equidistant,
	 "Equidistant_Azimutal"},
	{WAzimuth_Measure_Point_Longitude,
	 "Longitud_de_l'Azimut_del_Punt_de_Mesura"},
	{WBearing_Reference_Direction,
	 "Direcció_del_Rumb_de_Referència"},
	{WBearing_Reference_Meridian,
	 "Meridià_del_Rumb_de_Referència"},
	{WBearing_Resolution,
	 "Resolució_de_Rumb"},
	{WBearing_Units,
	 "Unitats_de_Rumb"},
	{WBeginning_Date,
	 "Data_de_Començament"},
	{WBeginning_Date_of_Attribute_Values,
	 "Data_Inicial_de_Valors_de_l'Atribut"},
	{WBeginning_Time,
	 "Hora_de_Començament"},
	{WBounding_Coordinates,
	 "Coordenades_Límits"},
	{WBrowse_Graphic,
	 "Gràfic_Per_a_Visualitzar"},
	{WBrowse_Graphic_File_Description,
	 "Descripció_de_l'Arxiu_Gràfic_Per_a_Visualitzar"},
	{WBrowse_Graphic_File_Name,
	 "Nom_de_l'Arxiu_Gràfic_Per_a_Visualitzar"},
	{WBrowse_Graphic_File_Type,
	 "Tipus_d'Arxiu_Gràfic_Per_a_Visualitzar"},
	{WCalendar_Date,
	 "Data_Calendari"},
	{WCitation,
	 "Cita"},
	{WCitation_Information,
	 "Informació_Per_a_la_Cita"},
	{WCity,
	 "Ciutat"},
	{WCloud_Cover,
	 "Cobriment_per_Núvols"},
	{WCodeset_Domain,
	 "Domini_del_Codeset"},
	{WCodeset_Name,
	 "Nom_del_Codeset"},
	{WCodeset_Source,
	 "Font_del_Codeset"},
	{WColumn_Count,
	 "Número_d'Objectes_Raster_a_l'Eix_X"},
	{WCompatibility_Information,
	 "Informació_de_Compatibilitat"},
	{WCompleteness_Report,
	 "Informe_Sobre_Completesa"},
	{WCompression_Support,
	 "Protocols_de_Compressió_Soportats"},
	{WComputer_Contact_Information,
	 "Informació_Per_a_Contacte_Amb_Computadora"},
	{WContact_Address,
	 "Direcció_del_Contacte"},
	{WContact_Electronic_Mail_Address,
	 "Correu_Electrònic_de_Contacte"},
	{WContact_Facsimile_Telephone,
	 "Facsímil_de_Contacte"},
	{WContact_Information,
	 "Informació_de_Contacte"},
	{WContact_Instructions,
	 "Instruccions_Per_a_Contacte"},
	{WContact_Organization,
	 "Organizació_Per_a_Contacte"},
	{WContact_Organization_Primary,
	 "Contacte_Preferentement_Amb_Organizació"},
	{WContact_Person,
	 "Persona_Per_a_Contacte"},
	{WContact_Person_Primary,
	 "Contacte_Preferentment_Amb_Persona"},
	{WContact_Position,
	 "Càrrec_del_Contacte"},
	{WContact_TDD_TTY_Telephone,
	 "TDD_TTY_de_Contacte"},
	{WContact_Voice_Telephone,
	 "Telèfon_de_Contacte"},
	{WCoordinate_Representation,
	 "Representació_de_Coordenades"},
	{WCountry,
	 "País"},
	{WCross_Reference,
	 "Referencia_Creuada"},
	{WCurrentness_Reference,
	 "Vigència"},
	{WCustom_Order_Process,
	 "Processament_Personalitzat_de_Comandes"},
	{WData_Quality_Information,
	 "Informació_de_Qualitat_de_les_Dades"},
	{WData_Set_Credit,
	 "Crèdit_del_Conjunt_de_Dades"},
	{WData_Set_G_Polygon,
	 "Polígon_Límit_de_les_Dades"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Polígon_Exclòs_de_les_Dades"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Polígon_Extern_de_les_Dades"},
	{WDenominator_of_Flattening_Ratio,
	 "Denominador_de_la_Raó_d'Aixafament"},
	{WDepth_Datum_Name,
	 "Nom_del_Dàtum_de_Profunditat"},
	{WDepth_Distance_Units,
	 "Unitats_de_Distància_de_Profunditat"},
	{WDepth_Encoding_Method,
	 "Mètode_de_Codificació_de_Profunditat"},
	{WDepth_Resolution,
	 "Resolució_de_Profunditat"},
	{WDepth_System_Definition,
	 "Definició_del_Sistema_de_Profunditat"},
	{WDescription,
	 "Descripció"},
	{WDetailed_Description,
	 "Descripció_Detallada"},
	{WDialup_File_Name,
	 "Nom_d'Arxiu_de_Discat_Automàtic"},
	{WDialup_Instructions,
	 "Instruccions_Per_a_Discat_Automàtic"},
	{WDialup_Telephone,
	 "Número_Telefònic_Per_a_Discat_Automàtic"},
	{WDigital_Form,
	 "Format_Digital"},
	{WDigital_Transfer_Information,
	 "Informació_Sobre_Transferència_Digital"},
	{WDigital_Transfer_Option,
	 "Opció_Sobre_Transferència_Digital"},
	{WDirect_Spatial_Reference_Method,
	 "Mètode_de_Referència_Espacial_Directa"},
	{WDistance_and_Bearing_Representation,
	 "Representació_de_Distància_i_Rumb"},
	{WDistance_Resolution,
	 "Resolució_de_Distància"},
	{WDistribution_Information,
	 "Informació_de_Distribució"},
	{WDistribution_Liability,
	 "Responsabilitats_del_Distribuidor"},
	{WDistributor,
	 "Distribuidor"},
	{WEast_Bounding_Coordinate,
	 "Coordenada_Límit_a_l'Est"},
	{WEdition,
	 "Edició"},
	{WEllipsoid_Name,
	 "Nom_de_l'Ellipsoide"},
	{WEnding_Date,
	 "Data_de_Finalització"},
	{WEnding_Date_of_Attribute_Values,
	 "Data_Final_de_Valors_de_l'Atribut"},
	{WEnding_Time,
	 "Hora_de_Finalització"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Cita_Detallada_d'Entidad_i_Atribut"},
	{WEntity_and_Attribute_Information,
	 "Informació_d'Entitat_i_Atribut"},
	{WEntity_and_Attribute_Overview,
	 "Resum_General_d'Entitat_i_Atribut"},
	{WEntity_Type,
	 "Tipus_d'Entitat"},
	{WEntity_Type_Definition,
	 "Definició_de_Tipus_d'Entitat"},
	{WEntity_Type_Definition_Source,
	 "Font_de_Definició_de_Tipus_d'Entitat"},
	{WEntity_Type_Label,
	 "Etiqueta_de_Tipus_d'Entitat"},
	{WEnumerated_Domain,
	 "Domini_Enumerat"},
	{WEnumerated_Domain_Value,
	 "Valors_del_Domini_Enumerat"},
	{WEnumerated_Domain_Value_Definition,
	 "Definició_del_Domini_Enumerat"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Font_Per_a_la_Definició_del_Domini_Enumerat"},
	{WEquidistant_Conic,
	 "Cònica_Equidistant"},
	{WEquirectangular,
	 "Equirrectangular"},
	{WFalse_Easting,
	 "Fals_Est"},
	{WFalse_Northing,
	 "Fals_Nord"},
	{WFees,
	 "Tarifes"},
	{WFile_Decompression_Technique,
	 "Tècnica_de_Descompressió_d'Arxius"},
	{WFormat_Information_Content,
	 "Informació_del_Format_del_Contingut"},
	{WFormat_Name,
	 "Nom_del_Format"},
	{WFormat_Specification,
	 "Especificació_del_Format"},
	{WFormat_Version_Date,
	 "Data_de_Versió_del_Format"},
	{WFormat_Version_Number,
	 "Número_de_Versió_del_Format"},
	{WG_Ring,
	 "Poligonal_Geogràfica"},
	{WG_Ring_Latitude,
	 "Latitud_de_Poligonal"},
	{WG_Ring_Longitude,
	 "Longitud_de_Poligonal"},
	{WG_Ring_Point,
	 "Punt_de_Poligonal_Geogràfica"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "Perspectiva_de_Costat_General_Vertical"},
	{WGeodetic_Model,
	 "Model_Geodèsic"},
	{WGeographic,
	 "Geogràfic"},
	{WGeographic_Coordinate_Units,
	 "Unitats_de_les_Coordenades_Geogràfiques"},
	{WGeospatial_Data_Presentation_Form,
	 "Forma_de_Presentació_Geoespacial"},
	{WGnomonic,
	 "Nomònica"},
	{WGrid_Coordinate_System,
	 "Sistema_de_Coordenades_de_Quadrícula"},
	{WGrid_Coordinate_System_Name,
	 "Nom_del_Sistema_de_Coordenades_de_Quadrícula"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Altura_del_Punt_de_Perspectiva_Sobre_la_Superfície"},
	{WHighest_BPS,
	 "Màxima_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Definició_del_Sistema_de_Coordenades_Horitzontals"},
	{WHorizontal_Datum_Name,
	 "Nom_del_Dàtum_Horitzontal"},
	{WHorizontal_Positional_Accuracy,
	 "Precisió_a_la_Horitzontal"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Interpretació_de_Precisió_Posicional_Horitzontal"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Informe_Sobre_Precisió_a_la_Horitzontal"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Valor_de_Precisió_a_la_Horitzontal"},
	{WHours_of_Service,
	 "Horari_d'Atenció"},
	{WIdentification_Information,
	 "Informació_de_Identificació"},
	{WIndirect_Spatial_Reference,
	 "Referència_Espacial_Indirecta"},
	{WIssue_Identification,
	 "Identificació_del_Número"},
	{WKeywords,
	 "Paraules_Clau"},
	{WLambert_Azimuthal_Equal_Area,
	 "Iso_Àrea_Azimutal_de_Lambert"},
	{WLambert_Conformal_Conic,
	 "Cònica_Conforme_de_Lambert"},
	{WLandsat_Number,
	 "Número_Landsat"},
	{WLarger_Work_Citation,
	 "Cita_a_Treball_Major"},
	{WLatitude_of_Projection_Center,
	 "Latitud_del_Centre_de_la_Projecció"},
	{WLatitude_of_Projection_Origin,
	 "Latitud_de_l'Origen_de_la_Projecció"},
	{WLatitude_Resolution,
	 "Resolució_de_Latitud"},
	{WLineage,
	 "Llinatge"},
	{WLocal,
	 "Local"},
	{WLocal_Description,
	 "Descripció_Local"},
	{WLocal_Georeference_Information,
	 "Informació_de_Georreferenciació_Local"},
	{WLocal_Planar,
	 "Plana_Local"},
	{WLocal_Planar_Description,
	 "Descripció_de_la_Plana_Local"},
	{WLocal_Planar_Georeference_Information,
	 "Informació_de_la_Georreferència_de_la_Plana_Local"},
	{WLogical_Consistency_Report,
	 "Informe_Sobre_Consistència_Lògica"},
	{WLongitude_of_Central_Meridian,
	 "Longitud_del_Meridià_Central"},
	{WLongitude_of_Projection_Center,
	 "Longitud_del_Centre_de_la_Projecció"},
	{WLongitude_Resolution,
	 "Resolució_de_Longitud"},
	{WLowest_BPS,
	 "Mínima_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Freqüència_de_Manteniment_i_Actualització"},
	{WMap_Projection,
	 "Projecció_Cartogràfica"},
	{WMap_Projection_Name,
	 "Nom_de_la_Projecció_Cartogràfica"},
	{WMap_Projection_Parameters,
	 "Paràmetres_de_la_Projecció_Cartogràfica"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadades"},
	{WMetadata_Access_Constraints,
	 "Restriccions_d'Accés_a_les_Metadades"},
	{WMetadata_Contact,
	 "Contacte_Per_a_Metadades"},
	{WMetadata_Date,
	 "Data_de_les_Metadades"},
	{WMetadata_Extensions,
	 "Extensions_a_l'Estàndard_de_Metadades"},
	{WMetadata_Future_Review_Date,
	 "Data_de_la_Futura_Revisió_de_Metadades"},
	{WMetadata_Language,
	 "Metadata_Language"},
	{WMetadata_Reference_Information,
	 "Informació_de_Referència_de_Metadades"},
	{WMetadata_Review_Date,
	 "Data_de_l'Última_Revisió_de_Metadades"},
	{WMetadata_Security_Classification,
	 "Classificació_de_Seguretat_de_Metadades"},
	{WMetadata_Security_Classification_System,
	 "Sistema_de_Classificació_de_Seguretat_de_Metadades"},
	{WMetadata_Security_Handling_Description,
	 "Descripció_de_Precaucions_de_Gestió_de_Metadades"},
	{WMetadata_Security_Information,
	 "Informació_de_Seguretat_de_Metadades"},
	{WMetadata_Standard_Name,
	 "Nom_de_l'Estàndard_de_Metadades"},
	{WMetadata_Standard_Version,
	 "Versió_de_l'Estàndard_de_Metadades"},
	{WMetadata_Time_Convention,
	 "Convenció_de_Dates_de_Metadades"},
	{WMetadata_Use_Constraints,
	 "Restriccions_a_l'Ús_de_Metadades"},
	{WMiller_Cylindrical,
	 "Cilíndrica_de_Miller"},
	{WModified_Stereographic_for_Alaska,
	 "Estereogràfica_Modificada_Per_a_Alaska"},
	{WMultiple_Dates_Times,
	 "Múltiples_Dates/Hores"},
	{WNative_Data_Set_Environment,
	 "Entorn_Original_de_les_Dades"},
	{WNetwork_Address,
	 "Direcció_de_la_Xarxa"},
	{WNetwork_Resource_Name,
	 "Nom_del_Recurs_de_la_Xarxa"},
	{WNon_digital_Form,
	 "Format_No_Digital"},
	{WNorth_Bounding_Coordinate,
	 "Coordenada_Límit_al_Nord"},
	{WNumber_DataBits,
	 "Número_de_Bits_de_Dades"},
	{WNumber_StopBits,
	 "Número_de_Bits_de_Parada"},
	{WOblique_Line_Azimuth,
	 "Azimut_de_Línia_Obliqua"},
	{WOblique_Line_Latitude,
	 "Latitud_de_Línia_Obliqua"},
	{WOblique_Line_Longitude,
	 "Longitud_de_Línia_Obliqua"},
	{WOblique_Line_Point,
	 "Punt_de_Línia_Obliqua"},
	{WOblique_Mercator,
	 "Mercator_Oblic"},
	{WOffline_Media,
	 "Medi_Físic_Fora_de_Línia"},
	{WOffline_Option,
	 "Opció_Fora_de_Línia"},
	{WOnline_Computer_and_Operating_System,
	 "Computadora_i_Sistema_Operatiu_en_Línia"},
	{WOnline_Linkage,
	 "Accés_en_Línia"},
	{WOnline_Option,
	 "Opció_en_Línia"},
	{WOrdering_Instructions,
	 "Instruccions_Per_a_la_Comanda"},
	{WOrdinate_Resolution,
	 "Resolució_de_les_Ordenades"},
	{WOriginator,
	 "Productor"},
	{WOrthographic,
	 "Ortogràfic"},
	{WOther_Citation_Details,
	 "Altres_Detalls_de_la_Cita"},
	{WOther_Grid_Systems_Definition,
	 "Definició_d'un_Altre_Sistema_de_Quadrícula"},
	{WOther_Projections_Definition,
	 "Definició_d'una_Altra_Projecció"},
	{WOverview_Description,
	 "Descripció_General"},
	{WParity,
	 "Paritat"},
	{WPath_Number,
	 "Número_de_Camí"},
	{WPlace,
	 "Lloc"},
	{WPlace_Keyword,
	 "Paraules_Clau_de_Lloc"},
	{WPlace_Keyword_Thesaurus,
	 "Tesaure_de_Paraules_Clau_de_Lloc"},
	{WPlanar,
	 "Pla"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Mètode_Codificat_de_Coordenades_Planes"},
	{WPlanar_Coordinate_Information,
	 "Informació_de_Coordenades_Planes"},
	{WPlanar_Distance_Units,
	 "Unitats_de_Distància_Planes"},
	{WPoint_and_Vector_Object_Count,
	 "Quantitat_d'Objectes_Punt_i_Vector"},
	{WPoint_and_Vector_Object_Information,
	 "Informació_d'Objectes_Punt_i_Vector"},
	{WPoint_of_Contact,
	 "Punt_de_Contacte"},
	{WPolar_Stereographic,
	 "Estereogràfic_Polar"},
	{WPolyconic,
	 "Policònic"},
	{WPositional_Accuracy,
	 "Precisió_de_la_Posició"},
	{WPostal_Code,
	 "Codi_Postal"},
	{WProcess_Contact,
	 "Contacte_del_Procés"},
	{WProcess_Date,
	 "Data_del_Procés"},
	{WProcess_Description,
	 "Descripció_del_Procés"},
	{WProcess_Step,
	 "Pas_del_Procés"},
	{WProcess_Time,
	 "Hora_del_Procés"},
	{WProfile_Name,
	 "Nom_del_Perfil"},
	{WProgress,
	 "Avenç"},
	{WPublication_Date,
	 "Data_de_Publicació"},
	{WPublication_Information,
	 "Informació_sobre_la_Publicació"},
	{WPublication_Place,
	 "Lloc_de_Publicació"},
	{WPublication_Time,
	 "Hora_de_Publicació"},
	{WPublisher,
	 "Impresor"},
	{WPurpose,
	 "Propòsit"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Determinació_Quantitativa_Sobre_Precisió_d'Atributs"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Declaració_de_Precisió_Posicional_Horitzontal"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Declaració_de_Precisió_Posicional_Vertical"},
	{WRange_Domain,
	 "Domini_del_Rang"},
	{WRange_Domain_Maximum,
	 "Màxim_del_Domini_del_Rang"},
	{WRange_Domain_Minimum,
	 "Mínim_del_Domini_del_Rang"},
	{WRange_of_Dates_Times,
	 "Rang_de_Dates/Hores"},
	{WRaster_Object_Information,
	 "Informació_Sobre_Objectes_Raster"},
	{WRaster_Object_Type,
	 "Tipologia_d'Objectes_Raster"},
	{WRecording_Capacity,
	 "Capacitat_de_Gravació"},
	{WRecording_Density,
	 "Densitat_de_Gravació"},
	{WRecording_Density_Units,
	 "Unitats_de_Densitat_de_Grabació"},
	{WRecording_Format,
	 "Format_de_Gravació"},
	{WResource_Description,
	 "Descripció_del_Recurs"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Número_d'Objectes_Raster_a_l'Eix_Y"},
	{WScale_Factor_at_Center_Line,
	 "Factor_d'Escala_a_la_Línia_Central"},
	{WScale_Factor_at_Central_Meridian,
	 "Factor_d'Escala_al_Meridià_Central"},
	{WScale_Factor_at_Equator,
	 "Factor_d'Escala_a_l'Ecuador"},
	{WScale_Factor_at_Projection_Origin,
	 "Factor_d'Escala_a_l'Origen_de_la_Projecció"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "Tipologia_d'Objectes_Punt_i_Vector_SDTS"},
	{WSDTS_Terms_Description,
	 "Descripció_de_Termes_SDTS"},
	{WSecurity_Classification,
	 "Classificació_de_la_Seguretat"},
	{WSecurity_Classification_System,
	 "Sistema_de_Classificació_de_la_Seguretat"},
	{WSecurity_Handling_Description,
	 "Descripció_de_Gestió_de_la_Seguretat"},
	{WSecurity_Information,
	 "Informació_de_la_Seguretat"},
	{WSemi_major_Axis,
	 "Semieix_Major"},
	{WSeries_Information,
	 "Informació_de_la_Sèrie"},
	{WSeries_Name,
	 "Nom_de_la_Sèrie"},
	{WSingle_Date_Time,
	 "Data_i_Hora"},
	{WSinusoidal,
	 "Sinusoidal"},
	{WSource_Citation,
	 "Cita_de_la_Font"},
	{WSource_Citation_Abbreviation,
	 "Abreviació_de_la_Cita_de_la_Font"},
	{WSource_Contribution,
	 "Contribució_de_la_Font"},
	{WSource_Currentness_Reference,
	 "Referència_sobre_la_Vigència_de_la_Font"},
	{WSource_Information,
	 "Informació_de_la_Font"},
	{WSource_Produced_Citation_Abbreviation,
	 "Abreviatura_de_la_Cita_de_la_Font_Produïda"},
	{WSource_Scale_Denominator,
	 "Denominador_d'Escala_de_la_Font"},
	{WSource_Time_Period_of_Content,
	 "Període_Comprès_a_la_Font"},
	{WSource_Used_Citation_Abbreviation,
	 "Abreviatura_Usual_de_la_Cita_de_la_Font"},
	{WSouth_Bounding_Coordinate,
	 "Coordenada_Límit_al_Sud"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Mercator_Espacial_Obliqua_(Landsat)"},
	{WSpatial_Data_Organization_Information,
	 "Informació_d'Organització_de_Dades_Espacials"},
	{WSpatial_Domain,
	 "Domini_Espacial"},
	{WSpatial_Reference_Information,
	 "Informació_de_Referència_Espacial"},
	{WSPCS_Zone_Identifier,
	 "Identificador_de_Zona_SPCS"},
	{WStandard_Order_Process,
	 "Processament_Estàndard_de_Comandes"},
	{WStandard_Parallel,
	 "Paral·lel_Estàndard"},
	{WState_or_Province,
	 "Estat_o_Província"},
	{WState_Plane_Coordinate_System,
	 "Sistema_Estatal_de_Coordenades_Planes"},
	{WStatus,
	 "Estatus"},
	{WStereographic,
	 "Estereogràfica"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Longitud_Vertical-Recta_Des_del_Pol"},
	{WStratum,
	 "Estrat"},
	{WStratum_Keyword,
	 "Paraula_Clau_d'Estrat"},
	{WStratum_Keyword_Thesaurus,
	 "Tesaure_de_Paraules_Clau_d'Estrat"},
	{WSupplemental_Information,
	 "Informació_Suplementària"},
	{WTechnical_Prerequisites,
	 "Prerrequisits_Tècnics"},
	{WTemporal,
	 "Temporal"},
	{WTemporal_Keyword,
	 "Paraules_Clau_de_Temps"},
	{WTemporal_Keyword_Thesaurus,
	 "Tesaure_de_Paraules_Clau_de_Temps"},
	{WTheme,
	 "Tema"},
	{WTheme_Keyword,
	 "Paraula_Clau_de_Tema"},
	{WTheme_Keyword_Thesaurus,
	 "Tesaure_de_Paraules_Clau_de_Tema"},
	{WTime_of_Day,
	 "Hora_del_Dia"},
	{WTime_Period_Information,
	 "Informació_del_Període_de_Temps"},
	{WTime_Period_of_Content,
	 "Període_Asociat_al_Contingut"},
	{WTitle,
	 "Títol"},
	{WTransfer_Size,
	 "Grandària_de_la_Transfèrencia"},
	{WTransverse_Mercator,
	 "Transversal_Mercator"},
	{WTurnaround,
	 "Temps_de_Lliurement"},
	{WType_of_Source_Media,
	 "Tipologia_del_Medi_Físic_de_la_Font"},
	{WUniversal_Polar_Stereographic,
	 "Estereogràfica_Polar_Universal"},
	{WUniversal_Transverse_Mercator,
	 "Transversal_Universal_Mercator"},
	{WUnrepresentable_Domain,
	 "Domini_No_Representable"},
	{WUPS_Zone_Identifier,
	 "Identificador_de_Zona_UPS"},
	{WUse_Constraints,
	 "Restriccions_d'Ús"},
	{WUTM_Zone_Number,
	 "Número_de_Zona_UTM"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Definició_del_Sistema_de_Coordenades_Verticals"},
	{WVertical_Count,
	 "Número_d'Objectes_Raster_a_l'Eix_Z"},
	{WVertical_Positional_Accuracy,
	 "Precisió_a_la_Vertical"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Interpretació_de_la_Precisió_Posicional_Vertical"},
	{WVertical_Positional_Accuracy_Report,
	 "Informe_Sobre_Precisió_a_la_Vertical"},
	{WVertical_Positional_Accuracy_Value,
	 "Valor_de_Precisió_a_la_Vertical"},
	{WVPF_Point_and_Vector_Object_Information,
	 "Informació_d'Objectes_Punt_i_Vector_VPF"},
	{WVPF_Point_and_Vector_Object_Type,
	 "Tipologia_d'Objectes_Punt_i_Vector_VPF"},
	{WVPF_Terms_Description,
	 "Descripció_de_Termes_VPF"},
	{WVPF_Topology_Level,
	 "Nivell_de_Topologia_VPF"},
	{WWest_Bounding_Coordinate,
	 "Coordenada_Límit_a_l'Oest"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

static struct keyword_list de_std[] = {
	{WAbscissa_Resolution,
	 "Abszisse_Auflösung"},
	{WAbstract,
	 "Zusammenfassung"},
	{WAccess_Constraints,
	 "Zugriffs_Beschränkungen"},
	{WAccess_Instructions,
	 "Zugriffs_Anweisungen"},
	{WAddress,
	 "Adresse"},
	{WAddress_Type,
	 "Adressentyp"},
	{WAlbers_Conical_Equal_Area,
	 "Albers_Konisch_Flächentreu"},
	{WAltitude_Datum_Name,
	 "Höhen_Datum_Name"},
	{WAltitude_Distance_Units,
	 "Höhen_Abstands_Einheit"},
	{WAltitude_Encoding_Method,
	 "Höhen_Kodierung_Methode"},
	{WAltitude_Resolution,
	 "Höhen_Auflösung"},
	{WAltitude_System_Definition,
	 "Höhen_System_Definition"},
	{WARC_Coordinate_System,
	 "ARC_Koordinatensystem"},
	{WARC_System_Zone_Identifier,
	 "ARC_System_Zonenidentifikator"},
	{WAttribute,
	 "Attribute"},
	{WAttribute_Accuracy,
	 "Attribut_Genauigkeit"},
	{WAttribute_Accuracy_Explanation,
	 "Attribut_Genauigkeit_Erklärung"},
	{WAttribute_Accuracy_Report,
	 "Attribut_Genauigkeits_Bericht"},
	{WAttribute_Accuracy_Value,
	 "Attribut_Genauigkeits_Wert"},
	{WAttribute_Definition,
	 "Attribut_Definition"},
	{WAttribute_Definition_Source,
	 "Attribut_Definition_Quelle"},
	{WAttribute_Domain_Values,
	 "Attribute_Domäne_Werte"},
	{WAttribute_Label,
	 "Attribut_Bezeichnung"},
	{WAttribute_Measurement_Frequency,
	 "Attribut_Messungs_Frequenz"},
	{WAttribute_Measurement_Resolution,
	 "Attribut_Messung_Genauigkeit"},
	{WAttribute_Units_of_Measure,
	 "Attribut_MessEinheiten"},
	{WAttribute_Value_Accuracy,
	 "Attribut_Wert_Genauigkeit"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Attribut_Wert_Genauigkeits_Beschreibung"},
	{WAttribute_Value_Accuracy_Information,
	 "Attribut_Werte_Genauigkeit_Information"},
	{WAvailable_Time_Period,
	 "Verfügbarkeit_Zeit_Periode"},
	{WAzimuthal_Angle,
	 "Azimuthal_Winkel"},
	{WAzimuthal_Equidistant,
	 "Azimuthal_Äquidistant"},
	{WAzimuth_Measure_Point_Longitude,
	 "Azimuth_Meßpunkt_Längengrad"},
	{WBearing_Reference_Direction,
	 "Winkel_Bezug_Richtung"},
	{WBearing_Reference_Meridian,
	 "Winkel_Bezug_Meridian"},
	{WBearing_Resolution,
	 "Winkel_Auflösung"},
	{WBearing_Units,
	 "Winkel_Einheit"},
	{WBeginning_Date,
	 "Anfangsdatum"},
	{WBeginning_Date_of_Attribute_Values,
	 "AnfangsDatum_für_Attribut_Werte"},
	{WBeginning_Time,
	 "Anfangszeit"},
	{WBounding_Coordinates,
	 "Begrenzungskoordinaten"},
	{WBrowse_Graphic,
	 "Vorschau_Graphik"},
	{WBrowse_Graphic_File_Description,
	 "Vorschau_Graphik_Datei_Beschreibung"},
	{WBrowse_Graphic_File_Name,
	 "Vorschau_Graphik_Datei_Name"},
	{WBrowse_Graphic_File_Type,
	 "Vorschau_Graphik_Datei_Typ"},
	{WCalendar_Date,
	 "Kalender_Datum"},
	{WCitation,
	 "Zitatangaben"},
	{WCitation_Information,
	 "Zitat_Information"},
	{WCity,
	 "Stadt"},
	{WCloud_Cover,
	 "Wolkenbedeckung"},
	{WCodeset_Domain,
	 "Codeset_Domain"},
	{WCodeset_Name,
	 "Codeset_Name"},
	{WCodeset_Source,
	 "Codeset_Quelle"},
	{WColumn_Count,
	 "Spalten_Anzahl"},
	{WCompatibility_Information,
	 "Kompatibilitäts_Information"},
	{WCompleteness_Report,
	 "VollstänigkeitsBericht"},
	{WCompression_Support,
	 "VerdichtungsHilfe"},
	{WComputer_Contact_Information,
	 "Computer_Kontakt_Information"},
	{WContact_Address,
	 "Kontaktadresse"},
	{WContact_Electronic_Mail_Address,
	 "KontaktEmailAdresse"},
	{WContact_Facsimile_Telephone,
	 "Contact_FAX"},
	{WContact_Information,
	 "Kontakt_Information"},
	{WContact_Instructions,
	 "Kontaktanweisungen"},
	{WContact_Organization,
	 "Kontakt_Organisation"},
	{WContact_Organization_Primary,
	 "Kontakt_Organisation_primär"},
	{WContact_Person,
	 "Kontakt_Person"},
	{WContact_Person_Primary,
	 "Kontakt_Person_Primär"},
	{WContact_Position,
	 "Kontaktstellung"},
	{WContact_TDD_TTY_Telephone,
	 "Kontakt_TDD/TTY_Telefon"},
	{WContact_Voice_Telephone,
	 "Contact_Mitsprache_Telefon"},
	{WCoordinate_Representation,
	 "Koordinaten_Representation"},
	{WCountry,
	 "Land"},
	{WCross_Reference,
	 "Kreuz_Verweis"},
	{WCurrentness_Reference,
	 "Aktualität_Referenz"},
	{WCustom_Order_Process,
	 "Kunden_Bestellung_Prozess"},
	{WData_Quality_Information,
	 "Daten_Qualität_Information"},
	{WData_Set_Credit,
	 "Datensatz_Danksagung"},
	{WData_Set_G_Polygon,
	 "Datensatz_G-Polygon"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Datensatz_G-Polygon_Ausschließender_G-Ring"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Datensatz_G-Polygon_Äußerer_G-Ring"},
	{WDenominator_of_Flattening_Ratio,
	 "Nenner_der_Abplattung"},
	{WDepth_Datum_Name,
	 "Tiefen_Datum_Name"},
	{WDepth_Distance_Units,
	 "Tiefen_Abstands_Einheit"},
	{WDepth_Encoding_Method,
	 "Tiefen_Kodierungs_Methode"},
	{WDepth_Resolution,
	 "Tiefen_Auflösung"},
	{WDepth_System_Definition,
	 "Tiefen_System_Definition"},
	{WDescription,
	 "Beschreibung"},
	{WDetailed_Description,
	 "Detaillierte_Beschreibung"},
	{WDialup_File_Name,
	 "Wahl_File_Name"},
	{WDialup_Instructions,
	 "Einwahl_Anweisungen"},
	{WDialup_Telephone,
	 "Einwahl_Telephon"},
	{WDigital_Form,
	 "Digitale_Form"},
	{WDigital_Transfer_Information,
	 "Digitale_Austausch_Information"},
	{WDigital_Transfer_Option,
	 "Digitale_Austausch_Optionen"},
	{WDirect_Spatial_Reference_Method,
	 "Direkte_Räumliche_Referenz_Methode"},
	{WDistance_and_Bearing_Representation,
	 "Entfernung_und_Winkel_Darstellung"},
	{WDistance_Resolution,
	 "Abstands_Auflösung"},
	{WDistribution_Information,
	 "Verteilung_Information"},
	{WDistribution_Liability,
	 "Verteiler_Haftungserklärung"},
	{WDistributor,
	 "Verteiler"},
	{WEast_Bounding_Coordinate,
	 "Ost_Begrenzungs_Koordinate"},
	{WEdition,
	 "Version"},
	{WEllipsoid_Name,
	 "Ellipsoid_Name"},
	{WEnding_Date,
	 "Enddatum"},
	{WEnding_Date_of_Attribute_Values,
	 "EndDatum_für_Attribut_Werte"},
	{WEnding_Time,
	 "Endzeit"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Entity_und_Attribut_Detail_Zitierung"},
	{WEntity_and_Attribute_Information,
	 "Entity_und_Attribut_Information"},
	{WEntity_and_Attribute_Overview,
	 "Entity_und_Attribut_Übersicht"},
	{WEntity_Type,
	 "Entity_Typ"},
	{WEntity_Type_Definition,
	 "Entity_Typ_Definition"},
	{WEntity_Type_Definition_Source,
	 "Entity_Typ_Definition_Quelle"},
	{WEntity_Type_Label,
	 "Entity_Typ_Bezeichnung"},
	{WEnumerated_Domain,
	 "Aufgezählte"},
	{WEnumerated_Domain_Value,
	 "Aufgezählter_Funktionswert"},
	{WEnumerated_Domain_Value_Definition,
	 "Aufgezählter_Funktionswert_Definition"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Aufgezählter_Funktionswert_Definitionsquelle"},
	{WEquidistant_Conic,
	 "Äquidistant_Konisch"},
	{WEquirectangular,
	 "Equirectangular"},
	{WFalse_Easting,
	 "Addition_Rechtswert"},
	{WFalse_Northing,
	 "Addition_Hochwert"},
	{WFees,
	 "Gebühren"},
	{WFile_Decompression_Technique,
	 "Datei_Dekompressions_Technik"},
	{WFormat_Information_Content,
	 "Format_InformationsGehalt"},
	{WFormat_Name,
	 "Format_Name"},
	{WFormat_Specification,
	 "Format_Spezifizierung"},
	{WFormat_Version_Date,
	 "Format_Versions_Datum"},
	{WFormat_Version_Number,
	 "Format_Versions_Nummer"},
	{WG_Ring,
	 "G-Ring"},
	{WG_Ring_Latitude,
	 "G-Ring_Länge"},
	{WG_Ring_Longitude,
	 "G-Ring_Breite"},
	{WG_Ring_Point,
	 "G-Ring_Punkt"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "Allgemeine_Vertikale_Ortsnahe_ Perspektive"},
	{WGeodetic_Model,
	 "Geodätisches_Modell"},
	{WGeographic,
	 "Geographisch"},
	{WGeographic_Coordinate_Units,
	 "Geographische_KoordinatenEinheiten"},
	{WGeospatial_Data_Presentation_Form,
	 "Georäumliche_Daten_Darstellung_Form"},
	{WGnomonic,
	 "Gnomoic"},
	{WGrid_Coordinate_System,
	 "Raster_Koordinatensystem"},
	{WGrid_Coordinate_System_Name,
	 "Raster_Koordinatensystem_Name"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Höhe_des_Blickpunktes_über_Oberfläche"},
	{WHighest_BPS,
	 "Höchste_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Horizontales_Koordinatensystem_Definition"},
	{WHorizontal_Datum_Name,
	 "Horizontales_Datum_Name"},
	{WHorizontal_Positional_Accuracy,
	 "Horizontale_Position_Genauigkeit"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Horizontale_Position_Genauigkeit_Erklärung"},
	{WHorizontal_Positional_Accuracy_Report,
	 "Horizontale_Position_Genauigkeit_Bericht"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Horizontale_Position_Genauigkeit_Wert"},
	{WHours_of_Service,
	 "Sprechstunden"},
	{WIdentification_Information,
	 "Identifikation_Information"},
	{WIndirect_Spatial_Reference,
	 "Indirekte_Räumliche_Referenzen"},
	{WIssue_Identification,
	 "Themen_Identifikation"},
	{WKeywords,
	 "Schlagworte"},
	{WLambert_Azimuthal_Equal_Area,
	 "Lambert_Azimuthal_Flächentreu"},
	{WLambert_Conformal_Conic,
	 "Lambert_Konform_Konisch"},
	{WLandsat_Number,
	 "Landsat_Nummer"},
	{WLarger_Work_Citation,
	 "Übergeordnete_Arbeit_Quelle"},
	{WLatitude_of_Projection_Center,
	 "Breitengrad_des_Projektionszentrums"},
	{WLatitude_of_Projection_Origin,
	 "Breite_Projektion_Ursprung"},
	{WLatitude_Resolution,
	 "Breitengrad_Auflösung"},
	{WLineage,
	 "Abstammung"},
	{WLocal,
	 "Lokal"},
	{WLocal_Description,
	 "Lokal_Beschreibung"},
	{WLocal_Georeference_Information,
	 "Lokal_Georeferenzierung_Information"},
	{WLocal_Planar,
	 "Lokal_Planar"},
	{WLocal_Planar_Description,
	 "Lokal_Planar_Beschreibung"},
	{WLocal_Planar_Georeference_Information,
	 "Lokale_Planare_Georeferenz_Information"},
	{WLogical_Consistency_Report,
	 "Logischer_Konsistenz_Report"},
	{WLongitude_of_Central_Meridian,
	 "Längengrad_des_Zentralen_Meridians"},
	{WLongitude_of_Projection_Center,
	 "Längengrad_des_Projektionszentrums"},
	{WLongitude_Resolution,
	 "Längengrad_Auflösung"},
	{WLowest_BPS,
	 "Geringste_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Instandhaltungs_und_AktualisierungsFrequenz"},
	{WMap_Projection,
	 "KartenProjektion"},
	{WMap_Projection_Name,
	 "KartenProjektionsName"},
	{WMap_Projection_Parameters,
	 "Karten_Projektion_Parameter"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadaten"},
	{WMetadata_Access_Constraints,
	 "Metadaten_Zugriffs_Bedingungen"},
	{WMetadata_Contact,
	 "Metadaten_Kontakt"},
	{WMetadata_Date,
	 "Metadata_Datum"},
	{WMetadata_Extensions,
	 "Metadaten_Erweiterung"},
	{WMetadata_Future_Review_Date,
	 "Metadata_Nächstes_Prüfung_Datum"},
	{WMetadata_Language,
	 "Metadata_Sprache"},
	{WMetadata_Reference_Information,
	 "Metadata_Referenz_Information"},
	{WMetadata_Review_Date,
	 "Metadata_Prüfung_Datum"},
	{WMetadata_Security_Classification,
	 "Metadaten_Sicherheit_Klassifikation"},
	{WMetadata_Security_Classification_System,
	 "Metadaten_Sicherheit_Klassifikation_System"},
	{WMetadata_Security_Handling_Description,
	 "Metadaten_Sicherheit_Handhabung_Beschreibung"},
	{WMetadata_Security_Information,
	 "Metadaten_Sicherheits_Informationen"},
	{WMetadata_Standard_Name,
	 "Metadaten_Standard_Name"},
	{WMetadata_Standard_Version,
	 "Metadaten_Standard_Version"},
	{WMetadata_Time_Convention,
	 "Metadaten_Zeit_Konvention"},
	{WMetadata_Use_Constraints,
	 "Metadaten_Nutzungs_Einschränkungen"},
	{WMiller_Cylindrical,
	 "Miller_Zylindrisch"},
	{WModified_Stereographic_for_Alaska,
	 "Modifiziert_Stereographisch_für_Alaska"},
	{WMultiple_Dates_Times,
	 "Mehrfaches_Datum/Zeit"},
	{WNative_Data_Set_Environment,
	 "Gewöhnliche_Datensatz_Umgebung"},
	{WNetwork_Address,
	 "Netzwerk_Adresse"},
	{WNetwork_Resource_Name,
	 "NetzwerkQuelle_Name"},
	{WNon_digital_Form,
	 "Nicht-Digitale_Form"},
	{WNorth_Bounding_Coordinate,
	 "Nord_Begrenzungs_Koordinate"},
	{WNumber_DataBits,
	 "Anzahl_DatenStücke"},
	{WNumber_StopBits,
	 "Anzahl_Stopstücke"},
	{WOblique_Line_Azimuth,
	 "Schiefe_Linie_Azimuth"},
	{WOblique_Line_Latitude,
	 "Schiefe_Linie_Breite"},
	{WOblique_Line_Longitude,
	 "Schiefe_Linie_Länge"},
	{WOblique_Line_Point,
	 "Schiefe_Linie_Punkt"},
	{WOblique_Mercator,
	 "Schiefe_Mercator"},
	{WOffline_Media,
	 "Offline_Medium"},
	{WOffline_Option,
	 "Offline_Option"},
	{WOnline_Computer_and_Operating_System,
	 "Online_Computer_und_Betriebssystem"},
	{WOnline_Linkage,
	 "Online_Verlinkung"},
	{WOnline_Option,
	 "Online_Option"},
	{WOrdering_Instructions,
	 "Bestell_Anleitung"},
	{WOrdinate_Resolution,
	 "Ordinate_Auflösung"},
	{WOriginator,
	 "Urheber"},
	{WOrthographic,
	 "Orthographisch"},
	{WOther_Citation_Details,
	 "Andere_Zitat_Details"},
	{WOther_Grid_Systems_Definition,
	 "Definition_Anderer_Rastersysteme"},
	{WOther_Projections_Definition,
	 "Other_Projection's_Definition"},
	{WOverview_Description,
	 "Überblick_Beschreibung"},
	{WParity,
	 "Parität"},
	{WPath_Number,
	 "Bahn_Nummer"},
	{WPlace,
	 "Ort"},
	{WPlace_Keyword,
	 "Ort_Schlagwort"},
	{WPlace_Keyword_Thesaurus,
	 "Ort_Schlagwort_Thesaurus"},
	{WPlanar,
	 "Eben"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Planar_Koordinate_Verschlüsselung_Methode"},
	{WPlanar_Coordinate_Information,
	 "Planar_Koordinate_Information"},
	{WPlanar_Distance_Units,
	 "Planar_Entfernung"},
	{WPoint_and_Vector_Object_Count,
	 "Punkt_und_Vektor_Objekt_Anzahl"},
	{WPoint_and_Vector_Object_Information,
	 "Punkt_und_Vektor_Objekt_Information"},
	{WPoint_of_Contact,
	 "Kontakt_Punkt"},
	{WPolar_Stereographic,
	 "Polar_Stereographisch"},
	{WPolyconic,
	 "Polykonisch"},
	{WPositional_Accuracy,
	 "Position_Genauigkeit"},
	{WPostal_Code,
	 "Postleitzahl"},
	{WProcess_Contact,
	 "Prozess_Kontakt"},
	{WProcess_Date,
	 "Prozess_Datum"},
	{WProcess_Description,
	 "Prozess_Beschreibung"},
	{WProcess_Step,
	 "Prozess_Schritt"},
	{WProcess_Time,
	 "Prozess_Zeit"},
	{WProfile_Name,
	 "Profil_Name"},
	{WProgress,
	 "Fortschritt"},
	{WPublication_Date,
	 "Herausgabe_Datum"},
	{WPublication_Information,
	 "Herausgabe_Information"},
	{WPublication_Place,
	 "Publikation_Ort"},
	{WPublication_Time,
	 "Herausgabe_Zeit"},
	{WPublisher,
	 "Herausgeber"},
	{WPurpose,
	 "Zweck"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Quantitative_Attribut_Genauigkeit_Abschätzung"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Quantitative_Horizontale_Position_Genauigkeit"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Quantitative_Vertical_Positional_Genauigkeit_Einschätzung"},
	{WRange_Domain,
	 "Funktionsbereich"},
	{WRange_Domain_Maximum,
	 "FunktionsBereich_Maximum"},
	{WRange_Domain_Minimum,
	 "FunktionsBereich_Minimum"},
	{WRange_of_Dates_Times,
	 "Daten/Zeit_Spanne"},
	{WRaster_Object_Information,
	 "Raster_Objekt_Information"},
	{WRaster_Object_Type,
	 "Raster_Objekt_Typ"},
	{WRecording_Capacity,
	 "Speicher_Kapazität"},
	{WRecording_Density,
	 "Aufnahme_Dichte"},
	{WRecording_Density_Units,
	 "Aufnahme_Einheiten_Dichte"},
	{WRecording_Format,
	 "Aufnahme_Format"},
	{WResource_Description,
	 "Quellenbeschreibung"},
	{WRobinson,
	 "Robinson"},
	{WRow_Count,
	 "Reihen_Anzahl"},
	{WScale_Factor_at_Center_Line,
	 "Maßstabsfaktor_an_Mittellinie"},
	{WScale_Factor_at_Central_Meridian,
	 "Maßstabsfaktor_Am_Mittleren_Meridian"},
	{WScale_Factor_at_Equator,
	 "Maßstabsfaktor_Am_Äquator"},
	{WScale_Factor_at_Projection_Origin,
	 "Maßstabsfaktor_Am_Projektionsursprung"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "SDTS_Punkt_und_Vektor_ObjektTyp"},
	{WSDTS_Terms_Description,
	 "SDTS_Termini_Erläuterung"},
	{WSecurity_Classification,
	 "Sicherheits_Klassifizierung"},
	{WSecurity_Classification_System,
	 "Sicherheits_Klassiefizierungs_System"},
	{WSecurity_Handling_Description,
	 "Sicherheit_Beschränkung_Beschreibung"},
	{WSecurity_Information,
	 "Sicherheits_Informationen"},
	{WSemi_major_Axis,
	 "Große_Halbachse"},
	{WSeries_Information,
	 "Serien_Information"},
	{WSeries_Name,
	 "Serien_Name"},
	{WSingle_Date_Time,
	 "Einzeln_Datum/Zeit"},
	{WSinusoidal,
	 "Sinusförmig"},
	{WSource_Citation,
	 "Quellen_Zitatangaben"},
	{WSource_Citation_Abbreviation,
	 "Abkürzung_Quelle"},
	{WSource_Contribution,
	 "Quellen_Beitrag"},
	{WSource_Currentness_Reference,
	 "Quellen_Aktualität_Referenz"},
	{WSource_Information,
	 "Quellen_Information"},
	{WSource_Produced_Citation_Abbreviation,
	 "Abkürzung_Produzierte_Quelle"},
	{WSource_Scale_Denominator,
	 "Quellen_Masstab_Nenner"},
	{WSource_Time_Period_of_Content,
	 "Quelle_Zeitspanne_des_Inhaltes"},
	{WSource_Used_Citation_Abbreviation,
	 "Abkürzung_Genutzte_Quelle"},
	{WSouth_Bounding_Coordinate,
	 "Süd_Begrenzungs_Koordinate"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Raumabhängiger_Mercator_(Landsat)"},
	{WSpatial_Data_Organization_Information,
	 "Räumliche_Daten_Organisation_Information"},
	{WSpatial_Domain,
	 "Räumliche_Ausdehnung"},
	{WSpatial_Reference_Information,
	 "Räumliche_Referenz_Information"},
	{WSPCS_Zone_Identifier,
	 "SPCS_Zonen_Identifikator"},
	{WStandard_Order_Process,
	 "Standard_Bestell_Prozess"},
	{WStandard_Parallel,
	 "Standard_Parallel"},
	{WState_or_Province,
	 "Bundesland_oder_Region"},
	{WState_Plane_Coordinate_System,
	 "State_Plane_Coordinate_System_(SPCS)"},
	{WStatus,
	 "Status"},
	{WStereographic,
	 "Stereographisch"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Gerader_Vertikaler_Längengrad_Vom_Pol"},
	{WStratum,
	 "Ebene"},
	{WStratum_Keyword,
	 "Ebene_Schlagwort"},
	{WStratum_Keyword_Thesaurus,
	 "Ebene_Schlagwort_Thesaurus"},
	{WSupplemental_Information,
	 "Ergänzende_Information"},
	{WTechnical_Prerequisites,
	 "Technische_Grundvoraussetungen"},
	{WTemporal,
	 "Zeitlich"},
	{WTemporal_Keyword,
	 "Zeitliches_Schlagwort"},
	{WTemporal_Keyword_Thesaurus,
	 "Zeitlicher_Schlagwort_Thesaurus"},
	{WTheme,
	 "Thema"},
	{WTheme_Keyword,
	 "Thema_Schlagwort"},
	{WTheme_Keyword_Thesaurus,
	 "Thema_Schlagwort_Thesaurus"},
	{WTime_of_Day,
	 "Zeit_des_Tages"},
	{WTime_Period_Information,
	 "Zeit_Periode_Information"},
	{WTime_Period_of_Content,
	 "Zeit_Periode_des_Inhalts"},
	{WTitle,
	 "Titel"},
	{WTransfer_Size,
	 "Transfer_Groesse"},
	{WTransverse_Mercator,
	 "Transversaler_Mercator"},
	{WTurnaround,
	 "Bearbeitungszeit"},
	{WType_of_Source_Media,
	 "Quellen_Medium_Typ"},
	{WUniversal_Polar_Stereographic,
	 "Universal_Polar_Stereographisch_(UPS)"},
	{WUniversal_Transverse_Mercator,
	 "Universal_Transversaler_Mercator_(UTM)"},
	{WUnrepresentable_Domain,
	 "Nicht_Darzustellende_Funktion"},
	{WUPS_Zone_Identifier,
	 "UPS_Zonen_Identifikator"},
	{WUse_Constraints,
	 "Nutzungs_Beschränkungen"},
	{WUTM_Zone_Number,
	 "UTM_Zonen_Nummer"},
	{Wvan_der_Grinten,
	 "van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Vertikale_Koordinatensystem_Definition"},
	{WVertical_Count,
	 "Vertikal_Anzahl"},
	{WVertical_Positional_Accuracy,
	 "Vertikale_Position_Genauigkeit"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Vertikale_Position_Genauigkeit_Erklärung"},
	{WVertical_Positional_Accuracy_Report,
	 "Vertikale_Positions_Genauigkeit_Bericht"},
	{WVertical_Positional_Accuracy_Value,
	 "Vertikale_Position_Genauigkeit_Wert"},
	{WVPF_Point_and_Vector_Object_Information,
	 "VPF_Punkt_und_Vektor_Objekt_Information"},
	{WVPF_Point_and_Vector_Object_Type,
	 "VPF_Punkt_und_Vektor_Objekt_Typ"},
	{WVPF_Terms_Description,
	 "VPF_Werte_Beschreibung"},
	{WVPF_Topology_Level,
	 "VPF_Struktur_Level"},
	{WWest_Bounding_Coordinate,
	 "West_Begrenzungs_Koordinate"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*\
 | Portuguese
\*----------------------------------------------------------------------*/

static struct keyword_list pt_std[] = {
	{WAbscissa_Resolution,
	 "Resolução_de_Abscissa"},
	{WAbstract,
	 "Resumo"},
	{WAccess_Constraints,
	 "Restrições_de_Acesso"},
	{WAccess_Instructions,
	 "Instruções_de_Acesso"},
	{WAddress,
	 "Endereço"},
	{WAddress_Type,
	 "Tipo_de_Endereço"},
	{WAlbers_Conical_Equal_Area,
	 "Projeção_Equivalente_de_Albers "},
	{WAltitude_Datum_Name,
	 "Nome_do_Datum_Altimétrico"},
	{WAltitude_Distance_Units,
	 "Unidades_de_Distância_Altiméticas"},
	{WAltitude_Encoding_Method,
	 "Métodos_de_Codificação_da_Altitude"},
	{WAltitude_Resolution,
	 "Resolução_Altimétrica"},
	{WAltitude_System_Definition,
	 "Definição_do_Sistema_de_Altitude"},
	{WARC_Coordinate_System,
	 "Sistema_Arc_de_Coordenadas"},
	{WARC_System_Zone_Identifier,
	 "Identificador_de_Zona_do_Sistema_Arc"},
	{WAttribute,
	 "Artibutos"},
	{WAttribute_Accuracy,
	 "Atributo_de_Precisão"},
	{WAttribute_Accuracy_Explanation,
	 "Descrição_da_Precisão_da_Altitude"},
	{WAttribute_Accuracy_Report,
	 "Informe_sobre_Precisão_de_Altitude"},
	{WAttribute_Accuracy_Value,
	 "Valor_do_Atributo_de_Precisão"},
	{WAttribute_Definition,
	 "Definição_do_Atributo"},
	{WAttribute_Definition_Source,
	 "Fonte_de_Definição_de_Atributos"},
	{WAttribute_Domain_Values,
	 "Valores_válidos_de_atributo"},
	{WAttribute_Label,
	 "Rótulo_de_Atributo"},
	{WAttribute_Measurement_Frequency,
	 "Frequencia_de_Medidas_do_Atributo"},
	{WAttribute_Measurement_Resolution,
	 "Resolução_de_Medidas_do_Atributo"},
	{WAttribute_Units_of_Measure,
	 "Unidades_de_Medida_do_Atributo"},
	{WAttribute_Value_Accuracy,
	 "Valor_da_Acurácia_do_Atributo"},
	{WAttribute_Value_Accuracy_Explanation,
	 "Explicação_do_Valor_da_Acurácia_do_Atributo"},
	{WAttribute_Value_Accuracy_Information,
	 "Informação_do_Valor_da_Acurácia_do_Atributo"},
	{WAvailable_Time_Period,
	 "Período_com_dados_disponíveis"},
	{WAzimuthal_Angle,
	 "Ângulo_Azimutal"},
	{WAzimuthal_Equidistant,
	 "Equidistante_Azimutal"},
	{WAzimuth_Measure_Point_Longitude,
	 "Longitude_do_Azimute_do_Ponto_de_Medida"},
	{WBearing_Reference_Direction,
	 "Direção_do_Rumo_de_Referência"},
	{WBearing_Reference_Meridian,
	 "Meridiano_do_Rumo_de_Referência"},
	{WBearing_Resolution,
	 "Resolução_do_Rumo"},
	{WBearing_Units,
	 "Unidades_de_Rumo"},
	{WBeginning_Date,
	 "Data_de_Início"},
	{WBeginning_Date_of_Attribute_Values,
	 "Data_de_Início_dos_Valores_de_Atributo"},
	{WBeginning_Time,
	 "Hora_de_Início"},
	{WBounding_Coordinates,
	 "Coordenadas_Limites"},
	{WBrowse_Graphic,
	 "Gráfico_de_Visualização"},
	{WBrowse_Graphic_File_Description,
	 "Descrição_do_Gráfico_de_Visualização"},
	{WBrowse_Graphic_File_Name,
	 "Nome_do_Arquivo_Gráfico_para_Visualização"},
	{WBrowse_Graphic_File_Type,
	 "Formato_do_Arquivo_Gráfico_para_Visualização"},
	{WCalendar_Date,
	 "Data_Calendário"},
	{WCitation,
	 "Citação"},
	{WCitation_Information,
	 "Informação_de_Citação"},
	{WCity,
	 "Cidade"},
	{WCloud_Cover,
	 "Cobertura_de_Nuvens"},
	{WCodeset_Domain,
	 "Codeset_Domain"},
	{WCodeset_Name,
	 "Codeset_Name"},
	{WCodeset_Source,
	 "Codeset_Source"},
	{WColumn_Count,
	 "Número_de_Objetos_Raster_no_Eixo_X"},
	{WCompatibility_Information,
	 "Informação_de_Compatibilidade"},
	{WCompleteness_Report,
	 "Relatório_de_Completitude"},
	{WCompression_Support,
	 "Protocolos_de_Compressão"},
	{WComputer_Contact_Information,
	 "Informacão_de_Contato_com_Computador"},
	{WContact_Address,
	 "Endereço_de_Contato"},
	{WContact_Electronic_Mail_Address,
	 "Endereço_Eletrônico_do__Contato"},
	{WContact_Facsimile_Telephone,
	 "Número_de_Fax_do_Contato"},
	{WContact_Information,
	 "Informação_do_Contato"},
	{WContact_Instructions,
	 "Instruções_para_Contato"},
	{WContact_Organization,
	 "Organização_para_Contato"},
	{WContact_Organization_Primary,
	 "Organização_de_Preferência_para_Contato"},
	{WContact_Person,
	 "Pessoa_de_Contato"},
	{WContact_Person_Primary,
	 "Pessoa_Preferencial_para_Contato"},
	{WContact_Position,
	 "Cargo_da_Pessoa_de_Contato"},
	{WContact_TDD_TTY_Telephone,
	 "Telefone_da_TDD/TTY_de_Contato"},
	{WContact_Voice_Telephone,
	 "Telefone_da_Pessoa_de_Contato"},
	{WCoordinate_Representation,
	 "Representaçao_de_Coordenadas"},
	{WCountry,
	 "País"},
	{WCross_Reference,
	 "Referência_Cruzada"},
	{WCurrentness_Reference,
	 "Vigência"},
	{WCustom_Order_Process,
	 "Processamento_Personalizado_de_Produtos"},
	{WData_Quality_Information,
	 "Informação_sobre_qualidade_de_dados"},
	{WData_Set_Credit,
	 "Crédito_do_Conjunto_de_Dados"},
	{WData_Set_G_Polygon,
	 "Polígono_Limite_dos_dados"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
	 "Polígono_Excluso_dos_Dados"},
	{WData_Set_G_Polygon_Outer_G_Ring,
	 "Polígono_Externo_aos_Dados"},
	{WDenominator_of_Flattening_Ratio,
	 "Denominador_da_Razão_de_Achatamento"},
	{WDepth_Datum_Name,
	 "Nome_do_Datum_de_Profundidade"},
	{WDepth_Distance_Units,
	 "Unidades_de_Distância_de_Profundidade"},
	{WDepth_Encoding_Method,
	 "Método_de_Codificação_de_Profundidade"},
	{WDepth_Resolution,
	 "Resolução_da_Profundidade"},
	{WDepth_System_Definition,
	 "Definição_do_Sistema_de_Profundidade"},
	{WDescription,
	 "Descrição "},
	{WDetailed_Description,
	 "Descrição_Detalhada"},
	{WDialup_File_Name,
	 "Nome_de_Arquivo_Discado_Automático"},
	{WDialup_Instructions,
	 "Instrução_para_Arquivo_Discado_Automático"},
	{WDialup_Telephone,
	 "Número_para_Arquivo_Discado_Automático"},
	{WDigital_Form,
	 "Formato_Digital"},
	{WDigital_Transfer_Information,
	 "Informação_sobre_Transferência_Digital"},
	{WDigital_Transfer_Option,
	 "Opção_de_Transferência_Digital"},
	{WDirect_Spatial_Reference_Method,
	 "Método_de_Referencia_Espacial_Direta"},
	{WDistance_and_Bearing_Representation,
	 "Representacão_de_Distancia_y_Rumo"},
	{WDistance_Resolution,
	 "Resolução_de_Distância"},
	{WDistribution_Information,
	 "Informação_sobre_Distribuição"},
	{WDistribution_Liability,
	 "Responsabilidades_do_Distibuidor"},
	{WDistributor,
	 "Distribuidor"},
	{WEast_Bounding_Coordinate,
	 "Coordenada_Limite_Leste"},
	{WEdition,
	 "Edição"},
	{WEllipsoid_Name,
	 "Nome_do_Elipsóide"},
	{WEnding_Date,
	 "Data_de_Término"},
	{WEnding_Date_of_Attribute_Values,
	 "Data_de_Término_dos_Valores_de_Atributo"},
	{WEnding_Time,
	 "Data_de_Finalização"},
	{WEntity_and_Attribute_Detail_Citation,
	 "Citação_Detalhada_de_Entidade_e_Atributo"},
	{WEntity_and_Attribute_Information,
	 "Informação_de_Entidades_e_Atributos"},
	{WEntity_and_Attribute_Overview,
	 "Resumo_de_Entidades_e_Atributos"},
	{WEntity_Type,
	 "Tipo_de_Entidade"},
	{WEntity_Type_Definition,
	 "Definição_do_Tipo_de_Entidades"},
	{WEntity_Type_Definition_Source,
	 "Fonte_de_Definição_do_Tipo_de_Entidade"},
	{WEntity_Type_Label,
	 "Rótulo_de_Tipo_de_Entidade"},
	{WEnumerated_Domain,
	 "Valores_Válidos_de_Campo_Numérico"},
	{WEnumerated_Domain_Value,
	 "Valores_Válidos_de_Campo_Numérico"},
	{WEnumerated_Domain_Value_Definition,
	 "Definição_Valores_Válidos_de_Campo_Numérico"},
	{WEnumerated_Domain_Value_Definition_Source,
	 "Fonte_Definição_Valores_Válidos_de_Campo_Numérico"},
	{WEquidistant_Conic,
	 "Cônica_Equidistante"},
	{WEquirectangular,
	 "Equirretangular"},
	{WFalse_Easting,
	 "Falso_leste"},
	{WFalse_Northing,
	 "Falso_norte"},
	{WFees,
	 "Tarifas"},
	{WFile_Decompression_Technique,
	 "Técnica_de_descompressão_de_arquivos"},
	{WFormat_Information_Content,
	 "Informação_de_Formato_de_Conteúdo"},
	{WFormat_Name,
	 "Nome_do_Formato"},
	{WFormat_Specification,
	 "Especificação_do_Formato"},
	{WFormat_Version_Date,
	 "Data_de_versão_do_Formato"},
	{WFormat_Version_Number,
	 "Núemro_de_versão_do_Formato"},
	{WG_Ring,
	 "Poligonal_Geográfica"},
	{WG_Ring_Latitude,
	 "Latitude_da_Poligonal"},
	{WG_Ring_Longitude,
	 "Longitude_da_Poligonal"},
	{WG_Ring_Point,
	 "Ponto_de_Poligonal_Geográfica"},
	{WGeneral_Vertical_Near_sided_Perspective,
	 "General_Vertical_Near-sided_Perspective"},
	{WGeodetic_Model,
	 "Modelo_Geodésico"},
	{WGeographic,
	 "Geográfico"},
	{WGeographic_Coordinate_Units,
	 "Unidades_das_Coordenadas_Geográficas"},
	{WGeospatial_Data_Presentation_Form,
	 "Forma_de_Apresentação_Geoespacial"},
	{WGnomonic,
	 "Gnomônica"},
	{WGrid_Coordinate_System,
	 "Sistema_de_Coordenadas_da_Quadrícula"},
	{WGrid_Coordinate_System_Name,
	 "Nome_do_Sistema_de_Coordenadas_da_Quadrícula"},
	{WHeight_of_Perspective_Point_Above_Surface,
	 "Altura_do_Ponto_de_Perspectiva_sobre_a _superfície"},
	{WHighest_BPS,
	 "Máximo_BPS"},
	{WHorizontal_Coordinate_System_Definition,
	 "Definição_do_Sistema_de_Coordenadas_Horizontais"},
	{WHorizontal_Datum_Name,
	 "Nome_do_Datum_Horizontal"},
	{WHorizontal_Positional_Accuracy,
	 "Acurácia_Horizontal"},
	{WHorizontal_Positional_Accuracy_Explanation,
	 "Interpretação_da_Acurácia_Horizontal "},
	{WHorizontal_Positional_Accuracy_Report,
	 "Relatório_sobre_Acurácia_Horizontal"},
	{WHorizontal_Positional_Accuracy_Value,
	 "Valor_da_Acurácia_Horizontal"},
	{WHours_of_Service,
	 "Expediente"},
	{WIdentification_Information,
	 "Informação_de_Identificação"},
	{WIndirect_Spatial_Reference,
	 "Referência_Espacial_Indireta"},
	{WIssue_Identification,
	 "Identificação_do_Volume"},
	{WKeywords,
	 "Palavras_Chave"},
	{WLambert_Azimuthal_Equal_Area,
	 "Projeção_Azimutal_de_Lambert"},
	{WLambert_Conformal_Conic,
	 "Projeção_Conforme_Cônica_de_Lambert"},
	{WLandsat_Number,
	 "Número_do_Satélite_Landsat"},
	{WLarger_Work_Citation,
	 "Citação_do_Trabalho_maior"},
	{WLatitude_of_Projection_Center,
	 "Latitude_do_Centro_da_Projeção"},
	{WLatitude_of_Projection_Origin,
	 "Latitude_da_Origem_da_Projeção"},
	{WLatitude_Resolution,
	 "Resolução_da_latitude"},
	{WLineage,
	 "Genealogia"},
	{WLocal,
	 "Local"},
	{WLocal_Description,
	 "Descrição_Local"},
	{WLocal_Georeference_Information,
	 "Informação_Local_de_Georrefenciamento"},
	{WLocal_Planar,
	 "Planar_local"},
	{WLocal_Planar_Description,
	 "Descrição_da_Planar_Local"},
	{WLocal_Planar_Georeference_Information,
	 "Informação_de_Georreferenciação_da_Planar_Local"},
	{WLogical_Consistency_Report,
	 "Relatório_de_Consistência_Lógica"},
	{WLongitude_of_Central_Meridian,
	 "Longitude_do_Meridiano_Central"},
	{WLongitude_of_Projection_Center,
	 "Longitude_do_Centro_da_Projeção"},
	{WLongitude_Resolution,
	 "Resolução_da_longitude"},
	{WLowest_BPS,
	 "Mínimo_BPS"},
	{WMaintenance_and_Update_Frequency,
	 "Frequencia_de_manutenção_e_atualização"},
	{WMap_Projection,
	 "Projeção_Cartográfica"},
	{WMap_Projection_Name,
	 "Nome_da_Projeção_Cartográfica"},
	{WMap_Projection_Parameters,
	 "Parâmetros_da_Projeção_Cartográfica"},
	{WMercator,
	 "Mercator"},
	{WMetadata,
	 "Metadados"},
	{WMetadata_Access_Constraints,
	 "Restrições_de_Acesso_a_Metadados"},
	{WMetadata_Contact,
	 "Contato_para_Metadados"},
	{WMetadata_Date,
	 "Data_dos_Metadados"},
	{WMetadata_Extensions,
	 "Extensões_ao_Padrão_de_Metadados"},
	{WMetadata_Future_Review_Date,
	 "Data_da_Futura_Revisão_dos_Metadados"},
	{WMetadata_Language,
	 "Linguagem_dos_Metadados"},
	{WMetadata_Reference_Information,
	 "Informação_de_Referência_dos_Metadados"},
	{WMetadata_Review_Date,
	 "Data_da_Última_Revisão_dos_Metadados"},
	{WMetadata_Security_Classification,
	 "Classificação_de_Segurança_dos_Metadados"},
	{WMetadata_Security_Classification_System,
	 "Sistema_de_Classificação_de_Segurança_dos_Metadados"},
	{WMetadata_Security_Handling_Description,
	 "Precauções_de_Manuseio_dos_Metadados"},
	{WMetadata_Security_Information,
	 "Informação_de_Segurança_dos_Metadados"},
	{WMetadata_Standard_Name,
	 "Nome_do_Padrão_de_Metadados"},
	{WMetadata_Standard_Version,
	 "Versão_do_Padrão_de_Metadados"},
	{WMetadata_Time_Convention,
	 "Convenções_Temporais_dos_Metadados"},
	{WMetadata_Use_Constraints,
	 "Restrição_de_Uso_dos_Metadados"},
	{WMiller_Cylindrical,
	 "Projeção_Cilíndrica_de_Miller"},
	{WModified_Stereographic_for_Alaska,
	 "Projeção_Estereográfica_Modificada_para_o_Alaska"},
	{WMultiple_Dates_Times,
	 "Multiplas_Datas_e_Horas"},
	{WNative_Data_Set_Environment,
	 "Ambiente_Original_dos_Dados"},
	{WNetwork_Address,
	 "Endereço_de_rede"},
	{WNetwork_Resource_Name,
	 "Nome_do_Recurso_de_Rede"},
	{WNon_digital_Form,
	 "Formato_não_digital"},
	{WNorth_Bounding_Coordinate,
	 "Coordenada_limite_norte"},
	{WNumber_DataBits,
	 "Número_de_Bits_de_Dados"},
	{WNumber_StopBits,
	 "Número_de_Stop_bits"},
	{WOblique_Line_Azimuth,
	 "Azimute_de_Linha_Oblíqua"},
	{WOblique_Line_Latitude,
	 "Latitude_de_Linha_Oblíqua"},
	{WOblique_Line_Longitude,
	 "Longitude_de_Linha_Oblíqua"},
	{WOblique_Line_Point,
	 "Ponto_de_Linha_Obíqua"},
	{WOblique_Mercator,
	 "Projeção_Mercator_Oblíqua"},
	{WOffline_Media,
	 "Meio_Físico_Fora_de_Linha"},
	{WOffline_Option,
	 "Opção_Fora_de_linha"},
	{WOnline_Computer_and_Operating_System,
	 "Computador_e_Sistema_Operacional"},
	{WOnline_Linkage,
	 "Acesso_em_rede"},
	{WOnline_Option,
	 "Opção_em _rede"},
	{WOrdering_Instructions,
	 "Instruções_para_encomenda"},
	{WOrdinate_Resolution,
	 "Resolução_das_Ordenadas"},
	{WOriginator,
	 "Produtor"},
	{WOrthographic,
	 "Ortográfico"},
	{WOther_Citation_Details,
	 "Outros_Detalhes_de_Citação"},
	{WOther_Grid_Systems_Definition,
	 "Definição_de_Outro_sistema_de_quadrícula"},
	{WOther_Projections_Definition,
	 "Definição_de_Outra_Projeção"},
	{WOverview_Description,
	 "Descrição_Sumária"},
	{WParity,
	 "Paridade"},
	{WPath_Number,
	 "Caminho_de_Diretório"},
	{WPlace,
	 "Lugar"},
	{WPlace_Keyword,
	 "Palavra_Chave_de_lugar"},
	{WPlace_Keyword_Thesaurus,
	 "Glossário_de_Palavras_Chave_de_Lugar"},
	{WPlanar,
	 "Coordenadas_planas"},
	{WPlanar_Coordinate_Encoding_Method,
	 "Método_de_Codificação_de_Coordenadas_Planas"},
	{WPlanar_Coordinate_Information,
	 "Informação_de_Coordenadas_Planas"},
	{WPlanar_Distance_Units,
	 "Unidades_de_Distâncias_Planas"},
	{WPoint_and_Vector_Object_Count,
	 "Quantidade_de_Objetos_Pontuais_e_Vetoriais"},
	{WPoint_and_Vector_Object_Information,
	 "Informação_sobre_Objetos_Pontuais_e_Vetoriais"},
	{WPoint_of_Contact,
	 "Ponto_de_Contato"},
	{WPolar_Stereographic,
	 "Projeção_Polar_Estereográfica"},
	{WPolyconic,
	 "Projeção_Policônica"},
	{WPositional_Accuracy,
	 "Acurácia_de_Posição"},
	{WPostal_Code,
	 "Código Postal"},
	{WProcess_Contact,
	 "Contato_sobre_processo"},
	{WProcess_Date,
	 "Data_de_Processo"},
	{WProcess_Description,
	 "Descrição_de_Processo"},
	{WProcess_Step,
	 "Passo_de_Processo"},
	{WProcess_Time,
	 "Hora_de_Processo"},
	{WProfile_Name,
	 "Nome_de_Perfil"},
	{WProgress,
	 "Progresso"},
	{WPublication_Date,
	 "Data_de_Publicação"},
	{WPublication_Information,
	 "Informação_de_Publicação"},
	{WPublication_Place,
	 "Local_de_Publicação"},
	{WPublication_Time,
	 "Hora_da_Publicação"},
	{WPublisher,
	 "Editor"},
	{WPurpose,
	 "Objetivo"},
	{WQuantitative_Attribute_Accuracy_Assessment,
	 "Determinação_Quantitativa_sobre_Acurácia_de_Atributos"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
	 "Avaliação_da_Acurácia_Horizontal"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
	 "Avaliação_da_Acurácia_Vertical"},
	{WRange_Domain,
	 "Gama_de_Valores_Possíveis"},
	{WRange_Domain_Maximum,
	 "Valor_Possível_Máximo"},
	{WRange_Domain_Minimum,
	 "Valor_Possível_Mínimo"},
	{WRange_of_Dates_Times,
	 "Gama_de_Datas_e_Horas"},
	{WRaster_Object_Information,
	 "Informação_sobre_Objetos_Raster"},
	{WRaster_Object_Type,
	 "Tipos_de_Objetos_Raster"},
	{WRecording_Capacity,
	 "Capacidade_de_Gravação"},
	{WRecording_Density,
	 "Densidade_de_Gravação"},
	{WRecording_Density_Units,
	 "Unidades_de_Densidade_de_Gravação"},
	{WRecording_Format,
	 "Formato_de_Gravação"},
	{WResource_Description,
	 "Descrição_de_Recursos"},
	{WRobinson,
	 "Projeção_de_Robinson"},
	{WRow_Count,
	 "Número_de_Células_ no_eixo_das_ordenadas"},
	{WScale_Factor_at_Center_Line,
	 "Fator_de_Escala_na_Linha_Central"},
	{WScale_Factor_at_Central_Meridian,
	 "Fator_de_Escala_no_Meridiano_Central"},
	{WScale_Factor_at_Equator,
	 "Fator_de_Escala_no_Equador"},
	{WScale_Factor_at_Projection_Origin,
	 "Fator_de_Escala_na_Origem_da_Projeção"},
	{WSDTS_Point_and_Vector_Object_Type,
	 "Tipos_de_Objetos_Ponto_e_Vetor_SDTS"},
	{WSDTS_Terms_Description,
	 "Descrição_de_Termos_SDTS"},
	{WSecurity_Classification,
	 "Classificação_de_Segurança"},
	{WSecurity_Classification_System,
	 "Sistema_de_Classificação_de_Segurança"},
	{WSecurity_Handling_Description,
	 "Descrição_do_manuseio_de_segurança"},
	{WSecurity_Information,
	 "Informação_sobre_Segurança"},
	{WSemi_major_Axis,
	 "Semi_eixo_maior"},
	{WSeries_Information,
	 "Informação_sobre_a_série"},
	{WSeries_Name,
	 "Nome_da_Série"},
	{WSingle_Date_Time,
	 "Data_e_Hora"},
	{WSinusoidal,
	 "Projeção Sinusoidal"},
	{WSource_Citation,
	 "Citação_da_Fonte"},
	{WSource_Citation_Abbreviation,
	 "Abreviação_de_Citação_da_Fonte"},
	{WSource_Contribution,
	 "Contrribuição_da_Fonte"},
	{WSource_Currentness_Reference,
	 "Referência_da_Fonte"},
	{WSource_Information,
	 "Informação_da_Fonte"},
	{WSource_Produced_Citation_Abbreviation,
	 "Abreviatura_de_Citaçao_da_Fonte"},
	{WSource_Scale_Denominator,
	 "Denominação_da_Escala_da_Fonte"},
	{WSource_Time_Period_of_Content,
	 "Período_Contido_na_Fonte"},
	{WSource_Used_Citation_Abbreviation,
	 "Abreviatura_Usual_de_Citação_da_Fonte"},
	{WSouth_Bounding_Coordinate,
	 "Coordenada_Limite_Sul"},
	{WSpace_Oblique_Mercator_Landsat,
	 "Projeção_Mercator_Espacial_Obliqua_(LANDSAT)"},
	{WSpatial_Data_Organization_Information,
	 "Organização_de_Organização_dos_Dados_Espaciais"},
	{WSpatial_Domain,
	 "Domínio_Espacial"},
	{WSpatial_Reference_Information,
	 "Informação_de_Referência_Espacial"},
	{WSPCS_Zone_Identifier,
	 "Identificador_de_Zona_SPCS"},
	{WStandard_Order_Process,
	 "Processo_Padrão_de_Requisição"},
	{WStandard_Parallel,
	 "Paralelo_Padrão"},
	{WState_or_Province,
	 "Estado_ou_Província"},
	{WState_Plane_Coordinate_System,
	 "Sistema_Estadual_de_Coordenadas_(EUA)"},
	{WStatus,
	 "Status"},
	{WStereographic,
	 "Projeção Estereográfica"},
	{WStraight_Vertical_Longitude_from_Pole,
	 "Longitude_Vertical_Reta_a_partir_do_Polo"},
	{WStratum,
	 "Estrato"},
	{WStratum_Keyword,
	 "Palavra_Chave_de_Estrato"},
	{WStratum_Keyword_Thesaurus,
	 "Relação_de_PalavraChaves_de_Estrato"},
	{WSupplemental_Information,
	 "Informação_Suplementar"},
	{WTechnical_Prerequisites,
	 "Pre-Requisitos_Tecnicos"},
	{WTemporal,
	 "Temporal"},
	{WTemporal_Keyword,
	 "Palavra_Chave_de_Tempo"},
	{WTemporal_Keyword_Thesaurus,
	 "Relação_de_PalavraChaves_de_Tempo"},
	{WTheme,
	 "Tema"},
	{WTheme_Keyword,
	 "Palavra_Chave_de_Tempo"},
	{WTheme_Keyword_Thesaurus,
	 "Relação_de_Palavras_Chaves_de_Tema"},
	{WTime_of_Day,
	 "Hora_do_Dia"},
	{WTime_Period_Information,
	 "Informação_de_Período_de_Tenpo"},
	{WTime_Period_of_Content,
	 "Período_Associado_ao_Conteúdo"},
	{WTitle,
	 "Título"},
	{WTransfer_Size,
	 "Tamanho_de_Transferência"},
	{WTransverse_Mercator,
	 "Projeção_Transversa_de_Mercator"},
	{WTurnaround,
	 "Tempo_de_Entrega"},
	{WType_of_Source_Media,
	 "Tipo_de_Meio_Físico_da_Fonte"},
	{WUniversal_Polar_Stereographic,
	 "Projeção_Estereográfica_Polar_Universal"},
	{WUniversal_Transverse_Mercator,
	 "Projeção_Universal_Transversa_de_Mercator"},
	{WUnrepresentable_Domain,
	 "Domínio_não_representável"},
	{WUPS_Zone_Identifier,
	 "Identificador_de_Zona_UPS"},
	{WUse_Constraints,
	 "Restrições_de_Uso"},
	{WUTM_Zone_Number,
	 "Número_de_Zona_UTM"},
	{Wvan_der_Grinten,
	 "Projeção_Van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
	 "Definição_do_Sistema_de_Coordenadas_Vertical"},
	{WVertical_Count,
	 "Número_de_Objetos_Raster_no_Eixo_Z"},
	{WVertical_Positional_Accuracy,
	 "Acurácia_vertical"},
	{WVertical_Positional_Accuracy_Explanation,
	 "Interpretação_da_Acurácia_Vertical"},
	{WVertical_Positional_Accuracy_Report,
	 "Informação_sobre_Acurácia_Vertical"},
	{WVertical_Positional_Accuracy_Value,
	 "Valor_da_Acurácia_Vertical"},
	{WVPF_Point_and_Vector_Object_Information,
	 "Informação_sobre_Objetos_Ponto_e_Vetor_VPF"},
	{WVPF_Point_and_Vector_Object_Type,
	 "Tipo_de_Objetos_Ponto_e_Vetor_VPF"},
	{WVPF_Terms_Description,
	 "Descrição_de_Termos_VPF"},
	{WVPF_Topology_Level,
	 "Nível_de_Topologia_VPF"},
	{WWest_Bounding_Coordinate,
	 "Coordenada_Limite_Oeste"},

/* Biological Data Profile */

	{WDescription_of_Geographic_Extent,
		"Description_of_Geographic_Extent"},
	{WBounding_Altitudes,
		"Bounding_Altitudes"},
	{WAltitude_Minimum,
		"Altitude_Minimum"},
	{WAltitude_Maximum,
		"Altitude_Maximum"},
	{WTaxonomy,
		"Taxonomy"},
	{WKeywords_Taxon,
		"Keywords/Taxon"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taxonomic_Keyword_Thesaurus"},
	{WTaxonomic_Keywords,
		"Taxonomic_Keywords"},
	{WTaxonomic_System,
		"Taxonomic_System"},
	{WClassification_System_Authority,
		"Classification_System/Authority"},
	{WClassification_System_Citation,
		"Classification_System_Citation"},
	{WClassification_System_Modifications,
		"Classification_System_Modifications"},
	{WIdentification_Reference,
		"Identification_Reference"},
	{WIdentifier,
		"Identifier"},
	{WTaxonomic_Procedures,
		"Taxonomic_Procedures"},
	{WTaxonomic_Completeness,
		"Taxonomic_Completeness"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Repository"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taxonomic_Coverage"},
	{WTaxonomic_Classification,
		"Taxonomic_Classification"},
	{WTaxon_Rank_Name,
		"Taxon_Rank_Name"},
	{WTaxon_Rank_Value,
		"Taxon_Rank_Value"},
	{WApplicable_Common_Name,
		"Applicable_Common_Name"},
	{WAnalytical_Tool,
		"Analytical_Tool"},
	{WAnalytical_Tool_Description,
		"Analytical_Tool_Description"},
	{WTool_Access_Information,
		"Tool_Access_Information"},
	{WTool_Contact,
		"Tool_Contact"},
	{WTool_Citation,
		"Tool_Citation"},
	{WTool_Access_Instructions,
		"Tool_Access_Instructions"},
	{WTool_Computer_and_Operating_System,
		"Tool_Computer_and_Operating_System"},
	{WMethodology,
		"Methodology"},
	{WMethodology_Type,
		"Methodology_Type"},
	{WMethodology_Identifier,
		"Methodology_Identifier"},
	{WMethodology_Keyword_Thesaurus,
		"Methodology_Keyword_Thesaurus"},
	{WMethodology_Keyword,
		"Methodology_Keyword"},
	{WMethodology_Description,
		"Methodology_Description"},
	{WMethodology_Citation,
		"Methodology_Citation"},
	{WASCII_File_Structure,
		"ASCII_File_Structure"},
	{WRecord_Delimiter,
		"Record_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_Content"},
	{WOrientation,
		"Orientation"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Data_Field"},
	{WData_Field_Name,
		"Data_Field_Name"},
	{WMissing_Value_Code,
		"Missing_Value_Code"},
	{WData_Field_Width_Delimiter,
		"Data_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Data_Field_Width"},
	{WBeginning_Geologic_Age,
		"Beginning_Geologic_Age"},
	{WEnding_Geologic_Age,
		"Ending_Geologic_Age"},
	{WGeologic_Age,
		"Geologic_Age"},
	{WGeologic_Time_Scale,
		"Geologic_Time_Scale"},
	{WGeologic_Age_Estimate,
		"Geologic_Age_Estimate"},
	{WGeologic_Age_Uncertainty,
		"Geologic_Age_Uncertainty"},
	{WGeologic_Age_Explanation,
		"Geologic_Age_Explanation"},
	{WGeologic_Citation,
		"Geologic_Citation"},

/* Shoreline profile */

	{WBarometric_Pressure,
	 "Barometric_Pressure"},
	{WEnvironmental_Event,
	 "Environmental_Event"},
	{WMarine_Weather_Condition,
	 "Marine_Weather_Condition"},
	{WProcess_Step_Citation,
	 "Process_Step_Citation"},
	{WRange_of_Tide,
	 "Range_of_Tide"},
	{WSupplemental_Tidal_Information,
	 "Supplemental_Tidal_Information"},
	{WTidal_Datum,
	 "Tidal_Datum"},
	{WTidal_Information,
	 "Tidal_Information"},
	{WTide_Table_Reference,
	 "Tide_Table_Reference"},
	{WTime_of_High_Tide,
	 "Time_of_High_Tide"},
	{WTime_of_Low_Tide,
	 "Time_of_Low_Tide"},
	{WTime_of_Tide,
	 "Time_of_Tide"},
	{WType_of_Tide,
	 "Type_of_Tide"},
	{WWave_Height,
	 "Wave_Height"},
	{WWind_Direction,
	 "Wind_Direction"},
	{WWind_Speed,
	 "Wind_Speed"},

/* Remote-sensing profile */

	{WAcquisition_Information,
	 "Acquisition_Information"},
	{WAerial_Film_Speed,
	 "Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
	 "Aerotriangulation_Reference"},
	{WAffine_Distortion_X_Prime_Coefficient,
	 "Affine_Distortion_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
	 "Affine_Distortion_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
	 "Aggregation_Criteria"},
	{WAggregation_Information,
	 "Aggregation_Information"},
	{WAggregation_Member_ID,
	 "Aggregation_Member_ID"},
	{WAlgorithm_Change_Description,
	 "Algorithm_Change_Description"},
	{WAlgorithm_Change_History,
	 "Algorithm_Change_History"},
	{WAlgorithm_Change_Reference,
	 "Algorithm_Change_Reference"},
	{WAlgorithm_Description,
	 "Algorithm_Description"},
	{WAlgorithm_Identifiers,
	 "Algorithm_Identifiers"},
	{WAlgorithm_Information,
	 "Algorithm_Information"},
	{WAlgorithm_Peer_Review_Description,
	 "Algorithm_Peer_Review_Description"},
	{WAlgorithm_Peer_Review_Information,
	 "Algorithm_Peer_Review_Information"},
	{WAlgorithm_Peer_Review_Reference,
	 "Algorithm_Peer_Review_Reference"},
	{WAlgorithm_Reference,
	 "Algorithm_Reference"},
	{WAlgorithm_Text_Description,
	 "Algorithm_Text_Description"},
	{WAltitude_Distance_Layer,
	 "Altitude_Distance_Layer"},
	{WAncillary_Dataset,
	 "Ancillary_Dataset"},
	{WAncillary_Dataset_Description,
	 "Ancillary_Dataset_Description"},
	{WAncillary_Dataset_Identifier,
	 "Ancillary_Dataset_Identifier"},
	{WAncillary_Description,
	 "Ancillary_Description"},
	{WAncillary_Reference,
	 "Ancillary_Reference"},
	{WAngle_Dependent_Distortion,
	 "Angle_Dependent_Distortion"},
	{WAngle_Distortion_Value,
	 "Angle_Distortion_Value"},
	{WArea_Weighted_Average_Resolution,
	 "Area_Weighted_Average_Resolution"},
	{WArgument_of_Perigee,
	 "Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
	 "Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
	 "Attitude_Angular_Units"},
	{WAvailability_of_Element_Locations,
	 "Availability_of_Element_Locations"},
	{WAxes,
	 "Axes"},
	{WAxis_Rotation_Convention,
	 "Axis_Rotation_Convention"},
	{WBand_Boundary_Definition,
	 "Band_Boundary_Definition"},
	{WBand_Description,
	 "Band_Description"},
	{WBand_ID,
	 "Band_ID"},
	{WBand_Identification,
	 "Band_Identification"},
	{WBand_Measurement_Mode_ID,
	 "Band_Measurement_Mode_ID"},
	{WBand_Quality,
	 "Band_Quality"},
	{WCalibrated_Detector_Positions,
	 "Calibrated_Detector_Positions"},
	{WCalibrated_Focal_Length,
	 "Calibrated_Focal_Length"},
	{WCamera_Identifier,
	 "Camera_Identifier"},
	{WCamera_Type,
	 "Camera_Type"},
	{WCell_Value_Type,
	 "Cell_Value_Type"},
	{WClock_Time_Drift,
	 "Clock_Time/Drift"},
	{WCollection_Type,
	 "Collection_Type"},
	{WColumn_Delta_X,
	 "Column_Delta_X"},
	{WColumn_Delta_Y,
	 "Column_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
	 "Command_Line_Processing_Parameter"},
	{WComponent_Information,
	 "Component_Information"},
	{WContainer_Packet_ID,
	 "Container_Packet_ID"},
	{WControl_Point_Authority,
	 "Control_Point_Authority"},
	{WControl_Point_Column,
	 "Control_Point_Column"},
	{WControl_Point_Earth_Location,
	 "Control_Point_Earth_Location"},
	{WControl_Point_Horizontal_X_Accuracy,
	 "Control_Point_Horizontal_X_Accuracy"},
	{WControl_Point_Horizontal_Y_Accuracy,
	 "Control_Point_Horizontal_Y_Accuracy"},
	{WControl_Point_ID,
	 "Control_Point_ID"},
	{WControl_Point_Identification,
	 "Control_Point_Identification"},
	{WControl_Point_Origin,
	 "Control_Point_Origin"},
	{WControl_Point_Raster_Position,
	 "Control_Point_Raster_Position"},
	{WControl_Point_Row,
	 "Control_Point_Row"},
	{WControl_Point_Type,
	 "Control_Point_Type"},
	{WControl_Point_Use_Flag,
	 "Control_Point_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
	 "Control_Point_Vertical_Accuracy"},
	{WControl_Point_x_Value,
	 "Control_Point_x_Value"},
	{WControl_Point_y_Value,
	 "Control_Point_y_Value"},
	{WControl_Point_z_Value,
	 "Control_Point_z_Value"},
	{WCoordinate_Point,
	 "Coordinate_Point"},
	{WCoordinate_System,
	 "Coordinate_System"},
	{WCoordinate_x_Value,
	 "Coordinate_x_Value"},
	{WCoordinate_XY_Units,
	 "Coordinate_XY_Units"},
	{WCoordinate_y_Value,
	 "Coordinate_y_Value"},
	{WCoordinate_Z_Units,
	 "Coordinate_Z_Units"},
	{WCoordinate_z_Value,
	 "Coordinate_z_Value"},
	{WCross_Track_Axis,
	 "Cross_Track_Axis"},
	{WCross_Track_Description,
	 "Cross_Track_Description"},
	{WCross_Track_Direction,
	 "Cross_Track_Direction"},
	{WCross_Track_Extent_Angle,
	 "Cross_Track_Extent_Angle"},
	{WCross_Track_Fixed_Angle,
	 "Cross_Track_Fixed_Angle"},
	{WCross_Track_Motion,
	 "Cross_Track_Motion"},
	{WCross_Track_Start_Angle,
	 "Cross_Track_Start_Angle"},
	{WCross_Track_Step_Angle,
	 "Cross_Track_Step_Angle"},
	{WCross_Track_Sweep,
	 "Cross_Track_Sweep"},
	{WCross_Track_Zero,
	 "Cross_Track_Zero"},
	{WData_Dictionary_Reference,
	 "Data_Dictionary_Reference"},
	{WData_Scaling_Information,
	 "Data_Scaling_Information"},
	{WDataset_Identifier,
	 "Dataset_Identifier"},
	{WDate_of_Last_Calibration,
	 "Date_of_Last_Calibration"},
	{WDeveloping_Institution,
	 "Developing_Institution"},
	{WDimension_Count,
	 "Dimension_Count"},
	{WDimension_Description,
	 "Dimension_Description"},
	{WDimension_Properties,
	 "Dimension_Properties"},
	{WDistance_Dependent_Distortion,
	 "Distance_Dependent_Distortion"},
	{WDistance_Distortion_Value,
	 "Distance_Distortion_Value"},
	{WDistortion,
	 "Distortion"},
	{WDistortion_Type_Affine,
	 "Distortion_Type_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
	 "Distortion_Type_Radial_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
	 "Distortion_Type_Radial_Symmetrical"},
	{WDocumentation,
	 "Documentation"},
	{WEccentricity,
	 "Eccentricity"},
	{WEffective_Aerial_Film_Speed,
	 "Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
	 "Elevation_Axis"},
	{WElevation_Description,
	 "Elevation_Description"},
	{WElevation_Direction,
	 "Elevation_Direction"},
	{WElevation_Extent_Angle,
	 "Elevation_Extent_Angle"},
	{WElevation_Fixed_Angle,
	 "Elevation_Fixed_Angle"},
	{WElevation_Start_Angle,
	 "Elevation_Start_Angle"},
	{WElevation_Step_Angle,
	 "Elevation_Step_Angle"},
	{WElevation_Sweep,
	 "Elevation_Sweep"},
	{WElevation_Zero,
	 "Elevation_Zero"},
	{WEphemeris,
	 "Ephemeris"},
	{WExposure_Time,
	 "Exposure_Time"},
	{WExterior_Orientation_Accuracy,
	 "Exterior_Orientation_Accuracy"},
	{WFiducial,
	 "Fiducial"},
	{WFiducial_Center,
	 "Fiducial_Center"},
	{WFilm_Type,
	 "Film_Type"},
	{WFilter_on_Camera,
	 "Filter_on_Camera"},
	{WFilter_on_Camera_Indicator,
	 "Filter_on_Camera_Indicator"},
	{WFilter_Type,
	 "Filter_Type"},
	{WFlight_Protocol,
	 "Flight_Protocol"},
	{WFlying_Height,
	 "Flying_Height"},
	{WForward_Motion_Compensation,
	 "Forward_Motion_Compensation"},
	{WFrame_Area,
	 "Frame_Area"},
	{WFrame_Area_Units,
	 "Frame_Area_Units"},
	{WFrame_Area_Value,
	 "Frame_Area_Value"},
	{WFrame_Camera,
	 "Frame_Camera"},
	{WFrame_Geometric_Properties,
	 "Frame_Geometric_Properties"},
	{WFrame_Hardware,
	 "Frame_Hardware"},
	{WFrame_Operation,
	 "Frame_Operation"},
	{WFrame_Optics,
	 "Frame_Optics"},
	{WFrame_Radiometric_Calibration,
	 "Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
	 "Frame_Radiometric_Properties"},
	{WFrame_Spectral_Information,
	 "Frame_Spectral_Information"},
	{WFrame_Spectral_Properties,
	 "Frame_Spectral_Properties"},
	{WGeorectified_Raster,
	 "Georectified_Raster"},
	{WGeoreferenceable_Raster,
	 "Georeferenceable_Raster"},
	{WGeoreferencing_Description,
	 "Georeferencing_Description"},
	{WGeoreferencing_Information,
	 "Georeferencing_Information"},
	{WGPS_Information_System_Availability,
	 "GPS_Information_System_Availability"},
	{WGrid_First_Element,
	 "Grid_First_Element"},
	{WGrid_First_Element_Map_X_Coordinate,
	 "Grid_First_Element_Map_X_Coordinate"},
	{WGrid_First_Element_Map_Y_Coordinate,
	 "Grid_First_Element_Map_Y_Coordinate"},
	{WGrid_Orientation,
	 "Grid_Orientation"},
	{WGround_Control_Point_Description,
	 "Ground_Control_Point_Description"},
	{WGround_Control_Point_Information,
	 "Ground_Control_Point_Information"},
	{WGround_Control_Point_Organization,
	 "Ground_Control_Point_Organization"},
	{WGround_Control_Point_Position,
	 "Ground_Control_Point_Position"},
	{WGround_Shape,
	 "Ground_Shape"},
	{WID_Overlapping_Dataset,
	 "ID_Overlapping_Dataset"},
	{WIFOV_Units,
	 "IFOV_Units"},
	{WIFOV_x_Definition,
	 "IFOV_x_Definition"},
	{WIFOV_x_Value,
	 "IFOV_x_Value"},
	{WIFOV_y_Definition,
	 "IFOV_y_Definition"},
	{WIFOV_y_Value,
	 "IFOV_y_Value"},
	{WImage_Quality,
	 "Image_Quality"},
	{WImage_Size,
	 "Image_Size"},
	{WImage_Size_x_Value,
	 "Image_Size_x_Value"},
	{WImage_Size_y_Value,
	 "Image_Size_y_Value"},
	{WInclination,
	 "Inclination"},
	{WIndividual_Band_Identification,
	 "Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
	 "Input_Dataset_Identifier"},
	{WInput_Description,
	 "Input_Description"},
	{WInput_Level,
	 "Input_Level"},
	{WInput_Reference,
	 "Input_Reference"},
	{WINS_Reading_Availability,
	 "INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
	 "Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
	 "Institution_of_Last_Calibration"},
	{WInstrument_Description,
	 "Instrument_Description"},
	{WInstrument_Full_Name,
	 "Instrument_Full_Name"},
	{WInstrument_Information,
	 "Instrument_Information"},
	{WInstrument_Properties_Description,
	 "Instrument_Properties_Description"},
	{WInstrument_Reference,
	 "Instrument_Reference"},
	{WInstrument_Short_Name,
	 "Instrument_Short_Name"},
	{WInstrument_Specific_Georeferencing,
	 "Instrument_Specific_Georeferencing"},
	{WInstrument_Type,
	 "Instrument_Type"},
	{WKeplerian_Orbit,
	 "Keplerian_Orbit"},
	{WLast_Calibration,
	 "Last_Calibration"},
	{WLayer_Name,
	 "Layer_Name"},
	{WLens,
	 "Lens"},
	{WLens_Identifier,
	 "Lens_Identifier"},
	{WLens_Type,
	 "Lens_Type"},
	{WLight_Drop,
	 "Light_Drop"},
	{WLocation_Information,
	 "Location_Information"},
	{WMagazine_Identifier,
	 "Magazine_Identifier"},
	{WMaximum_Wavelength,
	 "Maximum_Wavelength"},
	{WMethod_of_Last_Calibration,
	 "Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
	 "Minimum_Wavelength"},
	{WMission_Completion,
	 "Mission_Completion"},
	{WMission_Description,
	 "Mission_Description"},
	{WMission_History,
	 "Mission_History"},
	{WMission_Information,
	 "Mission_Information"},
	{WMission_Name,
	 "Mission_Name"},
	{WMission_Significant_Event,
	 "Mission_Significant_Event"},
	{WMission_Start_Date,
	 "Mission_Start_Date"},
	{WMultiple_Image_Alignment,
	 "Multiple_Image_Alignment"},
	{WNadir,
	 "Nadir"},
	{WNadir_Latitude,
	 "Nadir_Latitude"},
	{WNadir_Longitude,
	 "Nadir_Longitude"},
	{WName_of_Dimension,
	 "Name_of_Dimension"},
	{WNominal_Geostationary_Position,
	 "Nominal_Geostationary_Position"},
	{WNominal_Spatial_Resolution,
	 "Nominal_Spatial_Resolution"},
	{WNon_Polynomial_Scaling,
	 "Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
	 "Number_of_Angle_Distortion_Values"},
	{WNumber_of_Bands,
	 "Number_of_Bands"},
	{WNumber_of_Cross_Track_Samples,
	 "Number_of_Cross_Track_Samples"},
	{WNumber_of_Data_Dimensions,
	 "Number_of_Data_Dimensions"},
	{WNumber_of_Denominator_Terms,
	 "Number_of_Denominator_Terms"},
	{WNumber_of_Distance_Distortion_Values,
	 "Number_of_Distance_Distortion_Values"},
	{WNumber_of_Elevation_Samples,
	 "Number_of_Elevation_Samples"},
	{WNumber_of_Numerator_Terms,
	 "Number_of_Numerator_Terms"},
	{WNumber_of_Points,
	 "Number_of_Points"},
	{WNumber_of_Profile_Samples,
	 "Number_of_Profile_Samples"},
	{WNumber_of_Resolution_Values,
	 "Number_of_Resolution_Values"},
	{WNumber_of_Thematic_Layers,
	 "Number_of_Thematic_Layers"},
	{WNumber_of_Wavelength_Bands,
	 "Number_of_Wavelength_Bands"},
	{WOperational_Mode,
	 "Operational_Mode"},
	{WOrbit_Angle_Units,
	 "Orbit_Angle_Units"},
	{WOrbit_Period,
	 "Orbit_Period"},
	{WOrbit_Period_Units,
	 "Orbit_Period_Units"},
	{WOrbit_Period_Value,
	 "Orbit_Period_Value"},
	{WOther_Collector_Description,
	 "Other_Collector_Description"},
	{WOther_Georeferencing_Description,
	 "Other_Georeferencing_Description"},
	{WPath,
	 "Path"},
	{WPeak_Wavelength,
	 "Peak_Wavelength"},
	{WPercentage_of_Overlap,
	 "Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
	 "Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
	 "Photographic_Resolving_Power"},
	{WPitch,
	 "Pitch"},
	{WPitch_Accuracy,
	 "Pitch_Accuracy"},
	{WPixel_Cross_Track_Size,
	 "Pixel_Cross_Track_Size"},
	{WPixel_Description,
	 "Pixel_Description"},
	{WPixel_Elevation_Size,
	 "Pixel_Elevation_Size"},
	{WPixel_Height_Above_Ellipsoid,
	 "Pixel_Height_Above_Ellipsoid"},
	{WPixel_Point_Spread_Function,
	 "Pixel_Point_Spread_Function"},
	{WPixel_Profile_Size,
	 "Pixel_Profile_Size"},
	{WPixel_Resolution,
	 "Pixel_Resolution"},
	{WPlatform_and_Instrument_Identification,
	 "Platform_and_Instrument_Identification"},
	{WPlatform_and_Mission_Information,
	 "Platform_and_Mission_Information"},
	{WPlatform_Description,
	 "Platform_Description"},
	{WPlatform_Full_Name,
	 "Platform_Full_Name"},
	{WPlatform_Information,
	 "Platform_Information"},
	{WPlatform_Nominal_Altitude,
	 "Platform_Nominal_Altitude"},
	{WPlatform_Nominal_Altitude_Units,
	 "Platform_Nominal_Altitude_Units"},
	{WPlatform_Nominal_Altitude_Value,
	 "Platform_Nominal_Altitude_Value"},
	{WPlatform_Nominal_Longitude,
	 "Platform_Nominal_Longitude"},
	{WPlatform_Orbit,
	 "Platform_Orbit"},
	{WPlatform_Serial_Identifier,
	 "Platform_Serial_Identifier"},
	{WPlatform_Short_Name,
	 "Platform_Short_Name"},
	{WPlatform_Sponsor,
	 "Platform_Sponsor"},
	{WPlatform_Start_Date,
	 "Platform_Start_Date"},
	{WPoint_Position_In_Pixel,
	 "Point_Position_In_Pixel"},
	{WPolarization_Characteristics,
	 "Polarization_Characteristics"},
	{WPolynomial_Coefficient,
	 "Polynomial_Coefficient"},
	{WPolynomial_Denominator,
	 "Polynomial_Denominator"},
	{WPolynomial_Function,
	 "Polynomial_Function"},
	{WPolynomial_Numerator,
	 "Polynomial_Numerator"},
	{WPositional_Information,
	 "Positional_Information"},
	{WPrincipal_Point_of_Autocollimation,
	 "Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
	 "Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
	 "Processing_Change_History"},
	{WProcessing_Documentation,
	 "Processing_Documentation"},
	{WProcessing_Environment,
	 "Processing_Environment"},
	{WProcessing_Identifiers,
	 "Processing_Identifiers"},
	{WProcessing_Information,
	 "Processing_Information"},
	{WProcessing_Input_Dataset,
	 "Processing_Input_Dataset"},
	{WProcessing_Level,
	 "Processing_Level"},
	{WProcessing_Level_Authority,
	 "Processing_Level_Authority"},
	{WProcessing_Level_Identifier,
	 "Processing_Level_Identifier"},
	{WProcessing_Procedure,
	 "Processing_Procedure"},
	{WProcessing_Procedure_Description,
	 "Processing_Procedure_Description"},
	{WProcessing_Run_History,
	 "Processing_Run_History"},
	{WProcessing_Software,
	 "Processing_Software"},
	{WProcessing_Software_Description,
	 "Processing_Software_Description"},
	{WProcessing_Software_Reference,
	 "Processing_Software_Reference"},
	{WProfile_Description,
	 "Profile_Description"},
	{WProfile_Extent,
	 "Profile_Extent"},
	{WProfile_Fixed,
	 "Profile_Fixed"},
	{WProfile_Properties,
	 "Profile_Properties"},
	{WProfile_Sounding,
	 "Profile_Sounding"},
	{WProfile_Start,
	 "Profile_Start"},
	{WProfile_Step,
	 "Profile_Step"},
	{WProfiling_Direction,
	 "Profiling_Direction"},
	{WProjection_Center_X_Position,
	 "Projection_Center_X_Position"},
	{WProjection_Center_Y_Position,
	 "Projection_Center_Y_Position"},
	{WProjection_Center_Z_Position,
	 "Projection_Center_Z_Position"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
	 "Quality_of_Autocollimation_Principal_Point_x_Value"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
	 "Quality_of_Autocollimation_Principal_Point_y_Value"},
	{WQuality_of_Focal_Length,
	 "Quality_of_Focal_Length"},
	{WQuality_of_Principal_Point_of_Autocollimation,
	 "Quality_of_Principal_Point_of_Autocollimation"},
	{WQuality_of_Principal_Point_of_Symmetry,
	 "Quality_of_Principal_Point_of_Symmetry"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
	 "Quality_of_Symmetry_Principal_Point_x_Value"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
	 "Quality_of_Symmetry_Principal_Point_y_Value"},
	{WRadial_Asymmetrical_Coefficient_B1,
	 "Radial_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
	 "Radial_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
	 "Radial_Symmetrical_Angle_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
	 "Radial_Symmetrical_Distance_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
	 "Radial_Symmetrical_Distortion_Polynomial"},
	{WReceiver_Polarization,
	 "Receiver_Polarization"},
	{WReferenced_Coordinate_System,
	 "Referenced_Coordinate_System"},
	{WReferencing_Polynomial,
	 "Referencing_Polynomial"},
	{WRelative_Aperture,
	 "Relative_Aperture"},
	{WRelative_Azimuth,
	 "Relative_Azimuth"},
	{WReseau,
	 "Reseau"},
	{WResolution_Value_Set,
	 "Resolution_Value_Set"},
	{WResolving_Angle,
	 "Resolving_Angle"},
	{WResolving_Value_Radial,
	 "Resolving_Value_Radial"},
	{WResolving_Value_Tangential,
	 "Resolving_Value_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
	 "Right_Ascension_of_Ascending_Node"},
	{WRoll,
	 "Roll"},
	{WRoll_Accuracy,
	 "Roll_Accuracy"},
	{WRotation_Description,
	 "Rotation_Description"},
	{WRotation_Sequence,
	 "Rotation_Sequence"},
	{WRow,
	 "Row"},
	{WRow_Delta_X,
	 "Row_Delta_X"},
	{WRow_Delta_Y,
	 "Row_Delta_Y"},
	{WSample_Angle_Units,
	 "Sample_Angle_Units"},
	{WSample_Description_Units,
	 "Sample_Description_Units"},
	{WSample_Profile_Units,
	 "Sample_Profile_Units"},
	{WSample_Properties,
	 "Sample_Properties"},
	{WSatellite_Local_Azimuth_Angle,
	 "Satellite/Local_Azimuth_Angle"},
	{WSatellite_Local_Zenith_Angle,
	 "Satellite/Local_Zenith_Angle"},
	{WScan,
	 "Scan"},
	{WScan_Angle_Units,
	 "Scan_Angle_Units"},
	{WScan_Cross_Track_Properties,
	 "Scan_Cross_Track_Properties"},
	{WScan_Distance_Units,
	 "Scan_Distance_Units"},
	{WScan_Duration,
	 "Scan_Duration"},
	{WScan_Elevation_Properties,
	 "Scan_Elevation_Properties"},
	{WScan_Geometric_Properties,
	 "Scan_Geometric_Properties"},
	{WScan_Radiometric_Properties,
	 "Scan_Radiometric_Properties"},
	{WScan_Repeat_Time,
	 "Scan_Repeat_Time"},
	{WScan_Spectral_Properties,
	 "Scan_Spectral_Properties"},
	{WScan_Start_Time,
	 "Scan_Start_Time"},
	{WScan_Step_Time,
	 "Scan_Step_Time"},
	{WScan_Time_Units,
	 "Scan_Time_Units"},
	{WScan_Timing,
	 "Scan_Timing"},
	{WScience_Paper,
	 "Science_Paper"},
	{WSemimajor_Axis,
	 "Semimajor_Axis"},
	{WSender_Polarization,
	 "Sender_Polarization"},
	{WSensor_Element_Location,
	 "Sensor_Element_Location"},
	{WSensor_Grid,
	 "Sensor_Grid"},
	{WSensor_Orientation,
	 "Sensor_Orientation"},
	{WSensor_System,
	 "Sensor_System"},
	{WSolar_Azimuth_Angle,
	 "Solar_Azimuth_Angle"},
	{WSolar_Zenith_Angle,
	 "Solar_Zenith_Angle"},
	{WSource_of_Element_Locations,
	 "Source_of_Element_Locations"},
	{WSpatial_Resolution_Units,
	 "Spatial_Resolution_Units"},
	{WSpatial_Resolution_Value,
	 "Spatial_Resolution_Value"},
	{WSpectral_Information,
	 "Spectral_Information"},
	{WSpectral_Limit,
	 "Spectral_Limit"},
	{WStabilized_Mount,
	 "Stabilized_Mount"},
	{WStorage_Order,
	 "Storage_Order"},
	{WSwath_Track_Information,
	 "Swath_Track_Information"},
	{WThematic_Layer_Identification,
	 "Thematic_Layer_Identification"},
	{WTranslation_Description,
	 "Translation_Description"},
	{WType_of_Overlap,
	 "Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
	 "Unreferenced_Coordinate_System"},
	{WUsers_Guide,
	 "User's_Guide"},
	{WWavelength_Band_Properties,
	 "Wavelength_Band_Properties"},
	{WWavelength_Region,
	 "Wavelength_Region"},
	{WWavelength_Units,
	 "Wavelength_Units"},
	{WWorldwide_Reference_System,
	 "Worldwide_Reference_System"},
	{WX_Axis_Definition,
	 "X_Axis_Definition"},
	{WX_Position_Accuracy,
	 "X_Position_Accuracy"},
	{WY_Axis_Definition,
	 "Y_Axis_Definition"},
	{WY_Position_Accuracy,
	 "Y_Position_Accuracy"},
	{WYaw,
	 "Yaw"},
	{WYaw_Accuracy,
	 "Yaw_Accuracy"},
	{WZ_Axis_Definition,
	 "Z_Axis_Definition"},
	{WZ_Position_Accuracy,
	 "Z_Position_Accuracy"},

	/* Lidar extensions from USGS TM11-B4 */

	{WLidar_Information,
		"Lidar_Information"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Information"},
	{WLidar_Specification,
		"Lidar_Specification"},
	{WLidar_Sensor,
		"Lidar_Sensor"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Flight_Height"},
	{WLidar_Flight_Speed,
		"Lidar_Flight_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Scan_Angle"},
	{WLidar_Scan_Frequency,
		"Lidar_Scan_Frequency"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Duration"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Wavelength"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Multiple_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Swath_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Swath_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Coordinate_Reference_System_Name"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Accuracy_Information"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Horizontal_Accuracy"},

	/* These elements from the Lidar 1.0 spec were removed in version 1.1 */

	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Vertical_Accuracy"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Vertical_Accuracy"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Vertical_Accuracy_Type"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Vertical_Accuracy_Value"},

	/* These elements were added to the Lidar spec in version 1.1 */

	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Vertical_Accuracy"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints"},

	{WLidar_LAS_Information,
		"Lidar_LAS_Information"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Version"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Record_Format"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Identifier"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Identifier"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Resolution"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Classification"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Description"},
	{WLocal_Bounding_Coordinates,
		"Local_Bounding_Coordinates"},
	{WLeft_Bounding_Coordinate,
		"Left_Bounding_Coordinate"},
	{WRight_Bounding_Coordinate,
		"Right_Bounding_Coordinate"},
	{WTop_Bounding_Coordinate,
		"Top_Bounding_Coordinate"},
	{WBottom_Bounding_Coordinate,
		"Bottom_Bounding_Coordinate"},

#ifdef USE_ESRI_EXTENSIONS

	/* ESRI extensions */

	{WAltitude_Units,
	 "Altitude_Units"},
	{WAncillary_Role,
	 "Ancillary_Role"},
	{WAncillary_Role_Attribute,
	 "Ancillary_Role_Attribute"},
	{WAttribute_Alias,
	 "Attribute_Alias"},
	{WAttribute_Defined_Domain,
	 "Attribute_Defined_Domain"},
	{WAttribute_Indexed,
	 "Attribute_Indexed"},
	{WAttribute_Number_of_Decimals,
	 "Attribute_Number_of_Decimals"},
	{WAttribute_Output_Width,
	 "Attribute_Output_Width"},
	{WAttribute_Precision,
	 "Attribute_Precision"},
	{WAttribute_Scale,
	 "Attribute_Scale"},
	{WAttribute_Type,
	 "Attribute_Type"},
	{WAttribute_Width,
	 "Attribute_Width"},
	{WAttributed_Relationship,
	 "Attributed_Relationship"},
	{WAvailable_Junction_Feature_Class,
	 "Available_Junction_Feature_Class"},
	{WAvailable_Junction_Subtype,
	 "Available_Junction_Subtype"},
	{WAvailable_Junctions,
	 "Available_Junctions"},
	{WBackground_Nodata_Value,
	 "Background_Nodata_Value"},
	{WBehrmann,
	 "Behrmann"},
	{WBinary_Enclosures,
	 "Binary_Enclosures"},
	{WBits_Per_Pixel,
	 "Bits_Per_Pixel"},
	{WBonne,
	 "Bonne"},
	{WBottom_Bounding_Coordinate,
	 "Bottom_Bounding_Coordinate"},
	{WBrowse_Graphic_Embedded,
	 "Browse_Graphic_Embedded"},
	{WCassini,
	 "Cassini"},
	{WCell_Size_X_Direction,
	 "Cell_Size_X_Direction"},
	{WCell_Size_X_Units,
	 "Cell_Size_X_Units"},
	{WCell_Size_Y_Direction,
	 "Cell_Size_Y_Direction"},
	{WCell_Size_Y_Units,
	 "Cell_Size_Y_Units"},
	{WComposite_Relationship,
	 "Composite_Relationship"},
	{WCompression_Type,
	 "Compression_Type"},
	{WConnectivity_Rule,
	 "Connectivity_Rule"},
	{WCoordinate_System_Name,
	 "Coordinate_System_Name"},
	{WCreation_Date,
	 "Creation_Date"},
	{WCreation_Time,
	 "Creation_Time"},
	{WData,
	 "Data"},
	{WData_Frame_Count,
	 "Data_Frame_Count"},
	{WData_Frame_Name,
	 "Data_Frame_Name"},
	{WData_Frames,
	 "Data_Frames"},
	{WDatabase_Name,
	 "Database_Name"},
	{WDataset_Size,
	 "Dataset_Size"},
	{WDefault_Junction_Feature_Class,
	 "Default_Junction_Feature_Class"},
	{WDefault_Junction_Subtype,
	 "Default_Junction_Subtype"},
	{WDescription_of_Association,
	 "Description_of_Association"},
	{WDescription_of_Enclosure,
	 "Description_of_Enclosure"},
	{WDescription_of_Relationship,
	 "Description_of_Relationship"},
	{WDestination_Foreign_Key,
	 "Destination_Foreign_Key"},
	{WDestination_Name,
	 "Destination_Name"},
	{WDestination_Primary_Key,
	 "Destination_Primary_Key"},
	{WDomain_Attribute_Type,
	 "Domain_Attribute_Type"},
	{WDomain_Description,
	 "Domain_Description"},
	{WDomain_Name,
	 "Domain_Name"},
	{WDomain_Owner,
	 "Domain_Owner"},
	{WDomain_Type,
	 "Domain_Type"},
	{WEckert_I,
	 "Eckert_I"},
	{WEckert_II,
	 "Eckert_II"},
	{WEckert_III,
	 "Eckert_III"},
	{WEckert_IV,
	 "Eckert_IV"},
	{WEckert_V,
	 "Eckert_V"},
	{WEckert_VI,
	 "Eckert_VI"},
	{WEdge_Feature_Class,
	 "Edge_Feature_Class"},
	{WEdge_Maximum_Cardinality,
	 "Edge_Maximum_Cardinality"},
	{WEdge_Minimum_Cardinality,
	 "Edge_Minimum_Cardinality"},
	{WEdge_Subtype,
	 "Edge_Subtype"},
	{WEnabled_Attribute,
	 "Enabled_Attribute"},
	{WEnclosure,
	 "Enclosure"},
	{WEntity_Type_Count,
	 "Entity_Type_Count"},
	{WEntity_Type_Type,
	 "Entity_Type_Type"},
	{WESRI_Feature_Count,
	 "ESRI_Feature_Count"},
	{WESRI_Feature_Geometry,
	 "ESRI_Feature_Geometry"},
	{WESRI_Feature_Type,
	 "ESRI_Feature_Type"},
	{WESRI_Information,
	 "ESRI_Information"},
	{WESRI_Terms_Description,
	 "ESRI_Terms_Description"},
	{WESRI_Topology,
	 "ESRI_Topology"},
	{WFeature_Description,
	 "Feature_Description"},
	{WFile_or_Table_Name,
	 "File_or_Table_Name"},
	{WFrom_Edge_Feature_Class,
	 "From_Edge_Feature_Class"},
	{WFrom_Edge_Subtype,
	 "From_Edge_Subtype"},
	{WGall_Stereographic,
	 "Gall_Stereographic"},
	{WGeocoding_Information,
	 "Geocoding_Information"},
	{WGeographic_Coordinate_System_Name,
	 "Geographic_Coordinate_System_Name"},
	{WGeometric_Network_Information,
	 "Geometric_Network_Information"},
	{WImage_Colormap,
	 "Image_Colormap"},
	{WImage_Format,
	 "Image_Format"},
	{WImage_Type,
	 "Image_Type"},
	{WInstance_Name,
	 "Instance_Name"},
	{WJunction_Feature_Class,
	 "Junction_Feature_Class"},
	{WJunction_Maximum_Cardinality,
	 "Junction_Maximum_Cardinality"},
	{WJunction_Minimum_Cardinality,
	 "Junction_Minimum_Cardinality"},
	{WJunction_Subtype,
	 "Junction_Subtype"},
	{WLanguage_of_Dataset,
	 "Language_of_Dataset"},
	{WLanguage_of_Metadata,
	 "Language_of_Metadata"},
	{WLeft_Bounding_Coordinate,
	 "Left_Bounding_Coordinate"},
	{WLinear_Referencing,
	 "Linear_Referencing"},
	{WLocal_Bounding_Coordinates,
	 "Local_Bounding_Coordinates"},
	{WLoximuthal,
	 "Loximuthal"},
	{WMaximum_Altitude,
	 "Maximum_Altitude"},
	{WMerge_Rule,
	 "Merge_Rule"},
	{WMetadata_ID,
	 "Metadata_ID"},
	{WMinimum_Altitude,
	 "Minimum_Altitude"},
	{WModification_Date,
	 "Modification_Date"},
	{WModification_Time,
	 "Modification_Time"},
	{WMollweide,
	 "Mollweide"},
	{WNative_Dataset_Format,
	 "Native_Dataset_Format"},
	{WNetwork_Element,
	 "Network_Element"},
	{WNetwork_Role,
	 "Network_Role"},
	{WNetwork_Type,
	 "Network_Type"},
	{WNotification_Direction,
	 "Notification_Direction"},
	{WNumber_of_Raster_Bands,
	 "Number_of_Raster_Bands"},
	{WOrigin_Foreign_Key,
	 "Origin_Foreign_Key"},
	{WOrigin_Name,
	 "Origin_Name"},
	{WOrigin_Primary_Key,
	 "Origin_Primary_Key"},
	{WProcess_Software_and_Version,
	 "Process_Software_and_Version"},
	{WProjected_Coordinate_System_Name,
	 "Projected_Coordinate_System_Name"},
	{WPyramid_Layers,
	 "Pyramid_Layers"},
	{WQuartic_Authalic,
	 "Quartic_Authalic"},
	{WRange_Domain_Mean,
	 "Range_Domain_Mean"},
	{WRange_Domain_Standard_Deviation,
	 "Range_Domain_Standard_Deviation"},
	{WRaster_Display_Type,
	 "Raster_Display_Type"},
	{WRaster_Origin,
	 "Raster_Origin"},
	{WRelationship_Backward_Label,
	 "Relationship_Backward_Label"},
	{WRelationship_Cardinality,
	 "Relationship_Cardinality"},
	{WRelationship_Forward_Label,
	 "Relationship_Forward_Label"},
	{WRelationship_Information,
	 "Relationship_Information"},
	{WRight_Bounding_Coordinate,
	 "Right_Bounding_Coordinate"},
	{WRule_Category,
	 "Rule_Category"},
	{WRule_Help,
	 "Rule_Help"},
	{WRule_Type,
	 "Rule_Type"},
	{WSDE_Connection_Information,
	 "SDE_Connection_Information"},
	{WServer_Name,
	 "Server_Name"},
	{WSpatial_Index,
	 "Spatial_Index"},
	{WSplit_Rule,
	 "Split_Rule"},
	{WSubtype_Attribute,
	 "Subtype_Attribute"},
	{WSubtype_Attribute_Name,
	 "Subtype_Attribute_Name"},
	{WSubtype_Code,
	 "Subtype_Code"},
	{WSubtype_Default_Value,
	 "Subtype_Default_Value"},
	{WSubtype_Information,
	 "Subtype_Information"},
	{WSubtype_Name,
	 "Subtype_Name"},
	{WSynchronization_Date,
	 "Synchronization_Date"},
	{WSynchronization_Time,
	 "Synchronization_Time"},
	{WSynchronize_Automatically,
	 "Synchronize_Automatically"},
	{WSynchronize_Once,
	 "Synchronize_Once"},
	{WThumbnail,
	 "Thumbnail"},
	{WTo_Edge_Feature_Class,
	 "To_Edge_Feature_Class"},
	{WTo_Edge_Subtype,
	 "To_Edge_Subtype"},
	{WTop_Bounding_Coordinate,
	 "Top_Bounding_Coordinate"},
	{WUser_Name,
	 "User_Name"},
	{WVersion_Name,
	 "Version_Name"},
	{WWinkel_I,
	 "Winkel_I"},
	{WWinkel_II,
	 "Winkel_II"},
	{WGeographic_Box,
	 "Geographic_Box"},

#endif

	{Wunknown, NULL}
	};


/*----------------------------------------------------------------------*\
 | Turkish
\*----------------------------------------------------------------------*/

static struct keyword_list tr_std[] = {
	{WAbscissa_Resolution,
		"Yatay_Eksen_Çözünürlüğü"},
	{WAbstract,
		"Öz"},
	{WAccess_Constraints,
		"Erişim_Kısıtlamaları"},
	{WAccess_Instructions,
		"Erişim_Talimatları"},
	{WAddress,
		"Adres"},
	{WAddress_Type,
		"Adres_Türü"},
	{WAlbers_Conical_Equal_Area,
		"Albers_Eş-alan_Konik"},
	{WAltitude_Datum_Name,
		"Rakım_Datum_Adı"},
	{WAltitude_Distance_Units,
		"Rakım_Mesafe_Birimi"},
	{WAltitude_Encoding_Method,
		"Rakım_Kodlaması_Metodu"},
	{WAltitude_Resolution,
		"Rakım_Çözünürlüğü"},
	{WAltitude_System_Definition,
		"Rakım_Sistemi_Tanımı"},
	{WARC_Coordinate_System,
		"ARC_Koordinat_Sistemi"},
	{WARC_System_Zone_Identifier,
		"ARC_Sistemi_Bölge_Tanımlayıcısı"},
	{WAttribute,
		"Öznitelik"},
	{WAttribute_Accuracy,
		"Öznitelik_Kesinliği"},
	{WAttribute_Accuracy_Explanation,
		"Öznitelik_Kesinliği_Açıklaması"},
	{WAttribute_Accuracy_Report,
		"Öznitelik_Kesinliği_Raporu"},
	{WAttribute_Accuracy_Value,
		"Öznitelik_Kesinliği_Değeri"},
	{WAttribute_Definition,
		"Öznitelik_Tanımı"},
	{WAttribute_Definition_Source,
		"Öznitelik_Tanımı_Kaynağı"},
	{WAttribute_Domain_Values,
		"Öznitelik_Alan_Değerleri"},
	{WAttribute_Label,
		"Öznitelik_Etiketi"},
	{WAttribute_Measurement_Frequency,
		"Öznitelik_Ölçüm_Frekansı"},
	{WAttribute_Measurement_Resolution,
		"Öznitelik_Ölçüm_Çözünürlüğü"},
	{WAttribute_Units_of_Measure,
		"Öznitelik_Ölçü_Birimi"},
	{WAttribute_Value_Accuracy,
		"Öznitelik_Değeri_Kesinliği"},
	{WAttribute_Value_Accuracy_Explanation,
		"Öznitelik_Değeri_Kesinliği_Açıklaması"},
	{WAttribute_Value_Accuracy_Information,
		"Öznitelik_Değeri_Kesinliği_Bilgisi"},
	{WAvailable_Time_Period,
		"Available_Time_Period"},
	{WAzimuthal_Angle,
		"Azimut_Açısı"},
	{WAzimuthal_Equidistant,
		"Azimut_Equidistant"},
	{WAzimuth_Measure_Point_Longitude,
		"Azimut_Ölçüm_Noktası_Boylam"},
	{WBearing_Reference_Direction,
		"Yön_Referans_Direction"},
	{WBearing_Reference_Meridian,
		"Yön_Referans_Meridian"},
	{WBearing_Resolution,
		"Yön_Çözünürlüğü"},
	{WBearing_Units,
		"Yön_Birimi"},
	{WBeginning_Date,
		"Başlama_Tarihi"},
	{WBeginning_Date_of_Attribute_Values,
		"Başlama_Tarihi_of_Öznitelik_Değerleri"},
	{WBeginning_Time,
		"Başlangıç_Zamanı"},
	{WBounding_Coordinates,
		"Sınır_Koordinatları"},
	{WBrowse_Graphic,
		"Tarama_Grafiği"},
	{WBrowse_Graphic_File_Description,
		"Tarama_Grafiği_Dosya_Tarifi"},
	{WBrowse_Graphic_File_Name,
		"Tarama_Grafiği_Dosya_Adı"},
	{WBrowse_Graphic_File_Type,
		"Tarama_Grafiği_Dosya_Türü"},
	{WCalendar_Date,
		"Takvim_Tarihi"},
	{WCitation,
		"Atıf"},
	{WCitation_Information,
		"Atıf_Bilgisi"},
	{WCity,
		"Şehir"},
	{WCloud_Cover,
		"Bulut_Örtüsü"},
	{WCodeset_Domain,
		"Kod_Takımı_Alanı"},
	{WCodeset_Name,
		"Kod_Takımı_Adı"},
	{WCodeset_Source,
		"Kod_Takımı_Kaynağı"},
	{WColumn_Count,
		"Kolon_Sayısı"},
	{WCompatibility_Information,
		"Uyumluluk_Bilgisi"},
	{WCompleteness_Report,
		"Bütünlük_Raporu"},
	{WCompression_Support,
		"Sıkıştırma_Support"},
	{WComputer_Contact_Information,
		"Bilgisayar_İrtibatı_Bilgisi"},
	{WContact_Address,
		"İrtibat_Adresi"},
	{WContact_Electronic_Mail_Address,
		"İrtibat_Email_Adresi"},
	{WContact_Facsimile_Telephone,
		"İrtibat_Facsimile_Telefonu"},
	{WContact_Information,
		"İrtibat_Bilgisi"},
	{WContact_Instructions,
		"İrtibat_Talimatları"},
	{WContact_Organization,
		"İrtibat_Organizasyonu"},
	{WContact_Organization_Primary,
		"İrtibat_Organizasyonu_Primary"},
	{WContact_Person,
		"İrtibat_Kişisi"},
	{WContact_Person_Primary,
		"İrtibat_Kişisi_Primary"},
	{WContact_Position,
		"İrtibat_Konumu"},
	{WContact_TDD_TTY_Telephone,
		"İrtibat_TDD/TTY_Telefonu"},
	{WContact_Voice_Telephone,
		"İrtibat_Voice_Telefonu"},
	{WCoordinate_Representation,
		"Koordinat_Temsili"},
	{WCountry,
		"Ülke"},
	{WCross_Reference,
		"Çapraz_Referans"},
	{WCurrentness_Reference,
		"Currentness_Reference"},
	{WCustom_Order_Process,
		"Özel_Sipariş_Usulü"},
	{WData_Quality_Information,
		"Veri_Kalitesi_Bilgisi"},
	{WData_Set_Credit,
		"Veri_Atıf"},
	{WData_Set_G_Polygon,
		"Veri_G-Poligonu"},
	{WData_Set_G_Polygon_Exclusion_G_Ring,
		"Veri_G-Poligonu_Exclusion_G-Ring"},
	{WData_Set_G_Polygon_Outer_G_Ring,
		"Veri_G-Poligonu_Outer_G-Ring"},
	{WDenominator_of_Flattening_Ratio,
		"Düleme_Oranı_Paydası"},
	{WDepth_Datum_Name,
		"Derinlik_Datum_Adı"},
	{WDepth_Distance_Units,
		"Derinlik_Mesafe_Birimi"},
	{WDepth_Encoding_Method,
		"Derinlik_Kodlaması_Metodu"},
	{WDepth_Resolution,
		"Derinlik_Çözünürlüğü"},
	{WDepth_System_Definition,
		"Derinlik_Sistemi_Tanımı"},
	{WDescription,
		"Tarif"},
	{WDetailed_Description,
		"Ayrıntılı_Tarif"},
	{WDialup_File_Name,
		"Çevirmeli_Ağ_Dosya_Adı"},
	{WDialup_Instructions,
		"Çevirmeli_Ağ_Talimatları"},
	{WDialup_Telephone,
		"Çevirmeli_Ağ_Telefonu"},
	{WDigital_Form,
		"Dijital_Form"},
	{WDigital_Transfer_Information,
		"Dijital_Transfer_Bilgisi"},
	{WDigital_Transfer_Option,
		"Dijital_Transfer_Tercih"},
	{WDirect_Spatial_Reference_Method,
		"Direct_Mekansal_Referans_Metodu"},
	{WDistance_and_Bearing_Representation,
		"Mesafe_ve_Yön_Temsili"},
	{WDistance_Resolution,
		"Mesafe_Çözünürlüğü"},
	{WDistribution_Information,
		"Dağıtım_Bilgisi"},
	{WDistribution_Liability,
		"Dağıtım_Sorumluluğu"},
	{WDistributor,
		"Dağıtımcı"},
	{WEast_Bounding_Coordinate,
		"Doğu_Sınır_Koordinatı"},
	{WEdition,
		"Edition"},
	{WEllipsoid_Name,
		"Ellipsoid_Adı"},
	{WEnding_Date,
		"Bitiş_Tarihi"},
	{WEnding_Date_of_Attribute_Values,
		"Öznitelik_Değerleri_Bitiş_Tarihi"},
	{WEnding_Time,
		"Bitiş_Zamanı"},
	{WEntity_and_Attribute_Detail_Citation,
		"Varlık_ve_Öznitelik_Detail_Atıf"},
	{WEntity_and_Attribute_Information,
		"Varlık_ve_Öznitelik_Bilgisi"},
	{WEntity_and_Attribute_Overview,
		"Varlık_ve_Öznitelik_Overview"},
	{WEntity_Type,
		"Varlık_Türü"},
	{WEntity_Type_Definition,
		"Varlık_Türü_Tanımı"},
	{WEntity_Type_Definition_Source,
		"Varlık_Türü_Tanımı_Kaynağı"},
	{WEntity_Type_Label,
		"Varlık_Türü_Etiketi"},
	{WEnumerated_Domain,
		"Numaralandırılmış_Alan"},
	{WEnumerated_Domain_Value,
		"Numaralandırılmış_Alan_Değeri"},
	{WEnumerated_Domain_Value_Definition,
		"Numaralandırılmış_Alan_Değeri_Tanımı"},
	{WEnumerated_Domain_Value_Definition_Source,
		"Numaralandırılmış_Alan_Değeri_Tanımı_Kaynağı"},
	{WEquidistant_Conic,
		"Equidistant_Conic"},
	{WEquirectangular,
		"Equirectangular"},
	{WFalse_Easting,
		"False_Doğuing"},
	{WFalse_Northing,
		"False_Kuzeying"},
	{WFees,
		"Ücret"},
	{WFile_Decompression_Technique,
		"Dosya_Dekopresyon_Tekniği"},
	{WFormat_Information_Content,
		"Format_Bilgisi_İçeriği"},
	{WFormat_Name,
		"Format_Adı"},
	{WFormat_Specification,
		"Format_Tarifi"},
	{WFormat_Version_Date,
		"Format_Sürümü_Tarihi"},
	{WFormat_Version_Number,
		"Format_Sürümü_Numarası"},
	{WG_Ring,
		"G-Ring"},
	{WG_Ring_Latitude,
		"G-Ring_Enlem"},
	{WG_Ring_Longitude,
		"G-Ring_Boylam"},
	{WG_Ring_Point,
		"G-Ring_Noktası"},
	{WGeneral_Vertical_Near_sided_Perspective,
		"General_Dikey_Near-sided_Perspektifi"},
	{WGeodetic_Model,
		"Geodetic_Model"},
	{WGeographic,
		"Coğrafi"},
	{WGeographic_Coordinate_Units,
		"Coğrafi_Koordinat_Birimi"},
	{WGeospatial_Data_Presentation_Form,
		"Coğrafi-Mekansal_Veri_Presentation_Form"},
	{WGnomonic,
		"Gnomonic"},
	{WGrid_Coordinate_System,
		"Karelaj_Koordinat_Sistemi"},
	{WGrid_Coordinate_System_Name,
		"Karelaj_Koordinat_Sistemi_Adı"},
	{WHeight_of_Perspective_Point_Above_Surface,
		"Perspektif_Noktası_Yüzey_Üstü_Yüksekliği"},
	{WHighest_BPS,
		"Highest_BPS"},
	{WHorizontal_Coordinate_System_Definition,
		"Yatay_Koordinat_Sistemi_Tanımı"},
	{WHorizontal_Datum_Name,
		"Yatay_Datum_Adı"},
	{WHorizontal_Positional_Accuracy,
		"Yatay_Konumsal_Kesinliği"},
	{WHorizontal_Positional_Accuracy_Explanation,
		"Yatay_Konumsal_Kesinliği_Açıklaması"},
	{WHorizontal_Positional_Accuracy_Report,
		"Yatay_Konumsal_Kesinliği_Raporu"},
	{WHorizontal_Positional_Accuracy_Value,
		"Yatay_Konumsal_Kesinliği_Değeri"},
	{WHours_of_Service,
		"Hours_of_Service"},
	{WIdentification_Information,
		"Identification_Bilgisi"},
	{WIndirect_Spatial_Reference,
		"Indirect_Konumsal_Referansı"},
	{WIssue_Identification,
		"Issue_Identification"},
	{WKeywords,
		"Anahtar_Kelimeler"},
	{WLambert_Azimuthal_Equal_Area,
		"Lambert_Azimut_Equal_Area"},
	{WLambert_Conformal_Conic,
		"Lambert_Conformal_Conic"},
	{WLandsat_Number,
		"Landsat_Numarası"},
	{WLarger_Work_Citation,
		"Larger_Work_Atıf"},
	{WLatitude_of_Projection_Center,
		"Enlem_of_Projection_Center"},
	{WLatitude_of_Projection_Origin,
		"Enlem_of_Projection_Origin"},
	{WLatitude_Resolution,
		"Enlem_Çözünürlüğü"},
	{WLineage,
		"Soy"},
	{WLocal,
		"Yerel"},
	{WLocal_Description,
		"Yerel_Tarifi"},
	{WLocal_Georeference_Information,
		"Yerel_Georeference_Bilgisi"},
	{WLocal_Planar,
		"Yerel_Düzlemsel"},
	{WLocal_Planar_Description,
		"Yerel_Düzlemsel_Tarifi"},
	{WLocal_Planar_Georeference_Information,
		"Yerel_Düzlemsel_Georeference_Bilgisi"},
	{WLogical_Consistency_Report,
		"Logical_Consistency_Raporu"},
	{WLongitude_of_Central_Meridian,
		"Boylam_of_Central_Meridian"},
	{WLongitude_of_Projection_Center,
		"Boylam_of_Projection_Center"},
	{WLongitude_Resolution,
		"Boylam_Çözünürlüğü"},
	{WLowest_BPS,
		"En_Düşük_BPS"},
	{WMaintenance_and_Update_Frequency,
		"Bakım_ve_Update_Frekansı"},
	{WMap_Projection,
		"Harita_Projection"},
	{WMap_Projection_Name,
		"Harita_Projection_Adı"},
	{WMap_Projection_Parameters,
		"Harita_Projection_Parameters"},
	{WMercator,
		"Mercator"},
	{WMetadata,
		"Üstveri"},
	{WMetadata_Access_Constraints,
		"Üstveri_Erişimi_Kısıtlamaları"},
	{WMetadata_Contact,
		"Üstveri_İrtibatı"},
	{WMetadata_Date,
		"Üstveri_Tarihi"},
	{WMetadata_Extensions,
		"Üstveri_Extensions"},
	{WMetadata_Future_Review_Date,
		"Üstveri_Gelecek_İnceleme_Tarihi"},
	{WMetadata_Language,
		"Üstveri_Dili"},
	{WMetadata_Reference_Information,
		"Üstveri_Referans_Bilgisi"},
	{WMetadata_Review_Date,
		"Üstveri_İnceleme_Tarihi"},
	{WMetadata_Security_Classification,
		"Üstveri_Güvenliği_Sınıflandırması"},
	{WMetadata_Security_Classification_System,
		"Üstveri_Güvenliği_Sınıflandırması_Sistemi"},
	{WMetadata_Security_Handling_Description,
		"Üstveri_Güvenliği_Handling_Tarifi"},
	{WMetadata_Security_Information,
		"Üstveri_Güvenliği_Bilgisi"},
	{WMetadata_Standard_Name,
		"Üstveri_Standard_Adı"},
	{WMetadata_Standard_Version,
		"Üstveri_Standard_Sürümü"},
	{WMetadata_Time_Convention,
		"Üstveri_Zamanı_Convention"},
	{WMetadata_Use_Constraints,
		"Üstveri_Use_Kısıtlamaları"},
	{WMiller_Cylindrical,
		"Miller_Cylindrical"},
	{WModified_Stereographic_for_Alaska,
		"Modified_Stereographic_for_Alaska"},
	{WMultiple_Dates_Times,
		"Çoklu_Tarihler/Zamanlar"},
	{WNative_Data_Set_Environment,
		"Native_Veri_Environment"},
	{WNetwork_Address,
		"Ağ_Adresi"},
	{WNetwork_Resource_Name,
		"Ağ_Resource_Adı"},
	{WNon_digital_Form,
		"Dijital_Olmayan_Hal"},
	{WNorth_Bounding_Coordinate,
		"Kuzey_Sınır_Koordinatı"},
	{WNumber_DataBits,
		"Number_DataBits"},
	{WNumber_StopBits,
		"Number_StopBits"},
	{WOblique_Line_Azimuth,
		"Oblique_Line_Azimut"},
	{WOblique_Line_Latitude,
		"Oblique_Line_Enlem"},
	{WOblique_Line_Longitude,
		"Oblique_Line_Boylam"},
	{WOblique_Line_Point,
		"Oblique_Line_Noktası"},
	{WOblique_Mercator,
		"Oblik_Merkator"},
	{WOffline_Media,
		"Çevirimdışı_Media"},
	{WOffline_Option,
		"Çevirimdışı_Tercih"},
	{WOnline_Computer_and_Operating_System,
		"Çevirimiçi_Bilgisayar_ve_Operating_Sistemi"},
	{WOnline_Linkage,
		"Çevirimiçi_Linkage"},
	{WOnline_Option,
		"Çevirimiçi_Tercih"},
	{WOrdering_Instructions,
		"Sipariş_Talimatları"},
	{WOrdinate_Resolution,
		"Ordinate_Çözünürlüğü"},
	{WOriginator,
		"Originator"},
	{WOrthographic,
		"Orthographic"},
	{WOther_Citation_Details,
		"Diğer_Atıf_Detayları"},
	{WOther_Grid_Systems_Definition,
		"Diğer_Karelaj_Sistemi_Tanımı"},
	{WOther_Projections_Definition,
		"Diğer_Projection_Tanımı"},
	{WOverview_Description,
		"Overview_Tarifi"},
	{WParity,
		"Parite"},
	{WPath_Number,
		"Path_Numarası"},
	{WPlace,
		"Yer"},
	{WPlace_Keyword,
		"Yer_Anahtar_Kelime"},
	{WPlace_Keyword_Thesaurus,
		"Yer_Anahtar_Kelime_Eşanlamlılar_Sözlüğü"},
	{WPlanar,
		"Düzlemsel"},
	{WPlanar_Coordinate_Encoding_Method,
		"Düzlemsel_Koordinat_Kodlaması_Metodu"},
	{WPlanar_Coordinate_Information,
		"Düzlemsel_Koordinat_Bilgisi"},
	{WPlanar_Distance_Units,
		"Düzlemsel_Mesafe_Birimi"},
	{WPoint_and_Vector_Object_Count,
		"Point_ve_Vector_Object_Sayısı"},
	{WPoint_and_Vector_Object_Information,
		"Point_ve_Vector_Object_Bilgisi"},
	{WPoint_of_Contact,
		"İrtibat_Noktası"},
	{WPolar_Stereographic,
		"Polar_Stereographic"},
	{WPolyconic,
		"Polyconic"},
	{WPositional_Accuracy,
		"Positional_Kesinliği"},
	{WPostal_Code,
		"Posta_Kodu"},
	{WProcess_Contact,
		"İşlem_İrtibatı"},
	{WProcess_Date,
		"İşlem_Tarihi"},
	{WProcess_Description,
		"İşlem_Tarifi"},
	{WProcess_Step,
		"İşlem_Adımı"},
	{WProcess_Time,
		"İşlem_Zamanı"},
	{WProfile_Name,
		"Profil_Adı"},
	{WProgress,
		"Aşama"},
	{WPublication_Date,
		"Yayım_Tarihi"},
	{WPublication_Information,
		"Yayım_Bilgisi"},
	{WPublication_Place,
		"Yayım_Yeri"},
	{WPublication_Time,
		"Yayım_Zamanı"},
	{WPublisher,
		"Yayımcı"},
	{WPurpose,
		"Amaç"},
	{WQuantitative_Attribute_Accuracy_Assessment,
		"Nicel_Öznitelik_Kesinliği_Değerlendirmesi"},
	{WQuantitative_Horizontal_Positional_Accuracy_Assessment,
		"Nicel_Yatay_Konumsal_Kesinliği_Değerlendirmesi"},
	{WQuantitative_Vertical_Positional_Accuracy_Assessment,
		"Nicel_Dikey_Konumsal_Kesinliği_Değerlendirmesi"},
	{WRange_Domain,
		"Range_Alanı"},
	{WRange_Domain_Maximum,
		"Range_Alanı_Maximum"},
	{WRange_Domain_Minimum,
		"Range_Alanı_Minimum"},
	{WRange_of_Dates_Times,
		"Range_of_Tarihleri/Zamanları"},
	{WRaster_Object_Information,
		"Raster_Object_Bilgisi"},
	{WRaster_Object_Type,
		"Raster_Object_Türü"},
	{WRecording_Capacity,
		"Kaydetme_Capacity"},
	{WRecording_Density,
		"Kaydetme_Density"},
	{WRecording_Density_Units,
		"Kaydetme_Density_Birimi"},
	{WRecording_Format,
		"Kaydetme_Formatı"},
	{WResource_Description,
		"Resource_Tarifi"},
	{WRobinson,
		"Robinson"},
	{WRow_Count,
		"Satır_Sayısı"},
	{WScale_Factor_at_Center_Line,
		"Scale_Factor_at_Center_Line"},
	{WScale_Factor_at_Central_Meridian,
		"Scale_Factor_at_Central_Meridian"},
	{WScale_Factor_at_Equator,
		"Scale_Factor_at_Equator"},
	{WScale_Factor_at_Projection_Origin,
		"Scale_Factor_at_Projection_Origin"},
	{WSDTS_Point_and_Vector_Object_Type,
		"SDTS_Point_ve_Vector_Object_Türü"},
	{WSDTS_Terms_Description,
		"SDTS_Terimleri_Tarifi"},
	{WSecurity_Classification,
		"Güvenlik_Sınıflandırması"},
	{WSecurity_Classification_System,
		"Güvenlik_Sınıflandırması_Sistemi"},
	{WSecurity_Handling_Description,
		"Güvenlik_Handling_Tarifi"},
	{WSecurity_Information,
		"Güvenlik_Bilgisi"},
	{WSemi_major_Axis,
		"Semi-major_Ekseni"},
	{WSeries_Information,
		"Seri_Bilgisi"},
	{WSeries_Name,
		"Seri_Adı"},
	{WSingle_Date_Time,
		"Single_Tarihi/Time"},
	{WSinusoidal,
		"Sinusoidal"},
	{WSource_Citation,
		"Kaynak_Atıf"},
	{WSource_Citation_Abbreviation,
		"Kaynak_Atıf_Kısaltması"},
	{WSource_Contribution,
		"Kaynak_Contribution"},
	{WSource_Currentness_Reference,
		"Kaynak_Currentness_Referansı"},
	{WSource_Information,
		"Kaynak_Bilgisi"},
	{WSource_Produced_Citation_Abbreviation,
		"Kaynak_Produced_Atıf_Kısaltması"},
	{WSource_Scale_Denominator,
		"Kaynak_Scale_Paydası"},
	{WSource_Time_Period_of_Content,
		"Kaynak_İçerği_Zaman_Aralığı"},
	{WSource_Used_Citation_Abbreviation,
		"Kaynak_Used_Atıf_Kısaltması"},
	{WSouth_Bounding_Coordinate,
		"Güney_Sınır_Koordinatı"},
	{WSpace_Oblique_Mercator_Landsat,
		"Space_Oblik_Merkator_(Landsat)"},
	{WSpatial_Data_Organization_Information,
		"Konumsal_Veri_Organizasyonu_Bilgisi"},
	{WSpatial_Domain,
		"Konumsal_Alan"},
	{WSpatial_Reference_Information,
		"Konumsal_Referans_Bilgisi"},
	{WSPCS_Zone_Identifier,
		"SPCS_Bölge_Tanımlayıcısı"},
	{WStandard_Order_Process,
		"Standard_Sipariş_Usulü"},
	{WStandard_Parallel,
		"Standard_Parallel"},
	{WState_or_Province,
		"State_or_Province"},
	{WState_Plane_Coordinate_System,
		"State_Plane_Koordinat_Sistemi"},
	{WStatus,
		"Status"},
	{WStereographic,
		"Stereographic"},
	{WStraight_Vertical_Longitude_from_Pole,
		"Straight-Dikey_Boylam_from_Pole"},
	{WStratum,
		"Stratum"},
	{WStratum_Keyword,
		"Stratum_Anahtar_Kelime"},
	{WStratum_Keyword_Thesaurus,
		"Stratum_Anahtar_Kelime_Eşanlamlılar_Sözlüğü"},
	{WSupplemental_Information,
		"Supplemental_Bilgisi"},
	{WTechnical_Prerequisites,
		"Technical_Prerequisites"},
	{WTemporal,
		"Temporal"},
	{WTemporal_Keyword,
		"Temporal_Anahtar_Kelime"},
	{WTemporal_Keyword_Thesaurus,
		"Temporal_Anahtar_Kelime_Eşanlamlılar_Sözlüğü"},
	{WTheme,
		"Tematik"},
	{WTheme_Keyword,
		"Tematik_Anahtar_Kelime"},
	{WTheme_Keyword_Thesaurus,
		"Tematik_Anahtar_Kelimesi_Eşanlamlılar_Sözlüğü"},
	{WTime_of_Day,
		"Time_of_Day"},
	{WTime_Period_Information,
		"Time_Period_Bilgisi"},
	{WTime_Period_of_Content,
		"Time_Period_of_İçeriği"},
	{WTitle,
		"Başlık"},
	{WTransfer_Size,
		"Transfer_Boyutu"},
	{WTransverse_Mercator,
		"Transverse_Mercator"},
	{WTurnaround,
		"Sefer"},
	{WType_of_Source_Media,
		"Kaynak_Ortamı_Türü"},
	{WUniversal_Polar_Stereographic,
		"Universal_Polar_Stereographic"},
	{WUniversal_Transverse_Mercator,
		"Universal_Transverse_Mercator"},
	{WUnrepresentable_Domain,
		"Unrepresentable_Alan"},
	{WUPS_Zone_Identifier,
		"UPS_Bölge_Tanımlayıcısı"},
	{WUse_Constraints,
		"Use_Kısıtlamaları"},
	{WUTM_Zone_Number,
		"UTM_Bölge_Numarası"},
	{Wvan_der_Grinten,
		"van_der_Grinten"},
	{WVertical_Coordinate_System_Definition,
		"Dikey_Koordinat_Sistemi_Tanımı"},
	{WVertical_Count,
		"Dikey_Sayısı"},
	{WVertical_Positional_Accuracy,
		"Dikey_Konumsal_Kesinliği"},
	{WVertical_Positional_Accuracy_Explanation,
		"Dikey_Konumsal_Kesinliği_Açıklaması"},
	{WVertical_Positional_Accuracy_Report,
		"Dikey_Konumsal_Kesinliği_Raporu"},
	{WVertical_Positional_Accuracy_Value,
		"Dikey_Konumsal_Kesinliği_Değeri"},
	{WVPF_Point_and_Vector_Object_Information,
		"VPF_Point_ve_Vector_Object_Bilgisi"},
	{WVPF_Point_and_Vector_Object_Type,
		"VPF_Point_ve_Vector_Object_Türü"},
	{WVPF_Terms_Description,
		"VPF_Terimleri_Tarifi"},
	{WVPF_Topology_Level,
		"VPF_Topology_Düzeyi"},
	{WWest_Bounding_Coordinate,
		"Batı_Sınır_Koordinatı"},
	{WDescription_of_Geographic_Extent,
		"Description_of_Coğrafi_Extent"},
	{WBounding_Altitudes,
		"Sınır_Rakımlar"},
	{WAltitude_Minimum,
		"Rakım_Minimum"},
	{WAltitude_Maximum,
		"Rakım_Maximum"},
	{WTaxonomy,
		"Taksonomi"},
	{WKeywords_Taxon,
		"Anahtar_Kelimeler/Takson"},
	{WTaxonomic_Keyword_Thesaurus,
		"Taksonomik_Anahtar_Kelime_Eşanlamlılar_Sözlüğü"},
	{WTaxonomic_Keywords,
		"Taksonomik_Anahtar_Kelimeler"},
	{WTaxonomic_System,
		"Taksonomik_Sistemi"},
	{WClassification_System_Authority,
		"Classification_Sistemi/Authority"},
	{WClassification_System_Citation,
		"Classification_Sistemi_Atıf"},
	{WClassification_System_Modifications,
		"Classification_Sistemi_Modifications"},
	{WIdentification_Reference,
		"Identification_Referansı"},
	{WIdentifier,
		"Tanımlayıcı"},
	{WTaxonomic_Procedures,
		"Taksonomik_Yöntemler"},
	{WTaxonomic_Completeness,
		"Taksonomik_Bütünlük"},
	{WVouchers,
		"Vouchers"},
	{WSpecimen,
		"Specimen"},
	{WRepository,
		"Bilgi_havuzu"},
	{WGeneral_Taxonomic_Coverage,
		"General_Taksonomik_Coverage"},
	{WTaxonomic_Classification,
		"Taksonomik_Sınıflandırması"},
	{WTaxon_Rank_Name,
		"Takson_Kademe_Adı"},
	{WTaxon_Rank_Value,
		"Takson_Kademe_Değeri"},
	{WApplicable_Common_Name,
		"Applicable_Common_Adı"},
	{WAnalytical_Tool,
		"Analytical_Alet"},
	{WAnalytical_Tool_Description,
		"Analytical_Alet_Tarifi"},
	{WTool_Access_Information,
		"Alet_Erişimi_Bilgisi"},
	{WTool_Contact,
		"Alet_İrtibatı"},
	{WTool_Citation,
		"Alet_Rüzgar"},
	{WTool_Access_Instructions,
		"Alet_Erişimi_Talimatları"},
	{WTool_Computer_and_Operating_System,
		"Alet_Bilgisayar_ve_Operating_Sistemi"},
	{WMethodology,
		"Yöntem"},
	{WMethodology_Type,
		"Yöntem_Türü"},
	{WMethodology_Identifier,
		"Yöntem_Tanımlayıcısı"},
	{WMethodology_Keyword_Thesaurus,
		"Yöntem_Anahtar_Kelime_Eşanlamlılar_Sözlüğü"},
	{WMethodology_Keyword,
		"Yöntem_Anahtar_Kelimesi"},
	{WMethodology_Description,
		"Yöntem_Tarifi"},
	{WMethodology_Citation,
		"Yöntem_Rüzgar"},
	{WASCII_File_Structure,
		"ASCII_Dosya_Yapısı"},
	{WRecord_Delimiter,
		"Kayıt_Delimiter"},
	{WNumber_Header_Lines,
		"Number_Header_Lines"},
	{WDescription_of_Header_Content,
		"Description_of_Header_İçeriği"},
	{WOrientation,
		"Yönelim"},
	{WCase_Sensitive,
		"Case_Sensitive"},
	{WAuthentication,
		"Authentication"},
	{WQuote_Character,
		"Quote_Character"},
	{WData_Field,
		"Veri_Field"},
	{WData_Field_Name,
		"Veri_Field_Adı"},
	{WMissing_Value_Code,
		"Missing_Değeri_Code"},
	{WData_Field_Width_Delimiter,
		"Veri_Field_Width_Delimiter"},
	{WData_Field_Width,
		"Veri_Field_Width"},
	{WBeginning_Geologic_Age,
		"Başlangıç_Jeolojik_Çağ"},
	{WEnding_Geologic_Age,
		"Bitiş_Jeolojik_Çağ"},
	{WGeologic_Age,
		"Jeolojik_Çağ"},
	{WGeologic_Time_Scale,
		"Jeolojik_Zaman_Ölçeği"},
	{WGeologic_Age_Estimate,
		"Jeolojik_Çağ_Tahmini"},
	{WGeologic_Age_Uncertainty,
		"Jeolojik_Çağ_Belirsizliği"},
	{WGeologic_Age_Explanation,
		"Jeolojik_Çağ_Açıklaması"},
	{WGeologic_Citation,
		"Jeolojik_Rüzgar"},
	{WBarometric_Pressure,
		"Barometric_Pressure"},
	{WEnvironmental_Event,
		"Environmental_Event"},
	{WMarine_Weather_Condition,
		"Marine_Weather_Condition"},
	{WProcess_Step_Citation,
		"İşlem_Adımı_Atıf"},
	{WRange_of_Tide,
		"Range_of_Tide"},
	{WSupplemental_Tidal_Information,
		"Supplemental_Tidal_Bilgisi"},
	{WTidal_Datum,
		"Tidal_Datum"},
	{WTidal_Information,
		"Tidal_Bilgisi"},
	{WTide_Table_Reference,
		"Tide_Table_Referansı"},
	{WTime_of_High_Tide,
		"High_Tide_Zamanı"},
	{WTime_of_Low_Tide,
		"Low_Tide_Zamanı"},
	{WTime_of_Tide,
		"Tide_Zamanı"},
	{WType_of_Tide,
		"Tide_Türü"},
	{WWave_Height,
		"Dalga_Yüksekliği"},
	{WWind_Direction,
		"Rüzgar_Direction"},
	{WWind_Speed,
		"Rüzgar_Speed"},
	{WAcquisition_Information,
		"Devralma_Bilgisi"},
	{WAerial_Film_Speed,
		"Aerial_Film_Speed"},
	{WAerotriangulation_Reference,
		"Aerotriangulation_Referansı"},
	{WAffine_Distortion_X_Prime_Coefficient,
		"Affine_Çarpıklığı_X_Prime_Coefficient"},
	{WAffine_Distortion_Y_Prime_Coefficient,
		"Affine_Çarpıklığı_Y_Prime_Coefficient"},
	{WAggregation_Criteria,
		"Bütünleştirme_Kıstasları"},
	{WAggregation_Information,
		"Bütünleştirme_Bilgisi"},
	{WAggregation_Member_ID,
		"Bütünleştirme_Member_ID"},
	{WAlgorithm_Change_Description,
		"Algoritma_Değişm_Tarifi"},
	{WAlgorithm_Change_History,
		"Algoritma_Değişm_Geçmişi"},
	{WAlgorithm_Change_Reference,
		"Algoritma_Değişm_Referansı"},
	{WAlgorithm_Description,
		"Algoritma_Tarifi"},
	{WAlgorithm_Identifiers,
		"Algoritma_Tanımlayıcıları"},
	{WAlgorithm_Information,
		"Algoritma_Bilgisi"},
	{WAlgorithm_Peer_Review_Description,
		"Algoritma_Peer_İnceleme_Tarifi"},
	{WAlgorithm_Peer_Review_Information,
		"Algoritma_Peer_İnceleme_Bilgisi"},
	{WAlgorithm_Peer_Review_Reference,
		"Algoritma_Peer_İnceleme_Referansı"},
	{WAlgorithm_Reference,
		"Algoritma_Referansı"},
	{WAlgorithm_Text_Description,
		"Algoritma_Text_Tarifi"},
	{WAltitude_Distance_Layer,
		"Rakım_Mesafe_Tabakası"},
	{WAncillary_Dataset,
		"Yardımcı_Veri"},
	{WAncillary_Dataset_Description,
		"Yardımcı_Veri_Tarifi"},
	{WAncillary_Dataset_Identifier,
		"Yardımcı_Veri_Tanımlayıcısı"},
	{WAncillary_Description,
		"Yardımcı_Tarifi"},
	{WAncillary_Reference,
		"Yardımcı_Referansı"},
	{WAngle_Dependent_Distortion,
		"Açıya_Bağlı_Çarpıklık"},
	{WAngle_Distortion_Value,
		"Açı_Çarpıklığı_Değeri"},
	{WArea_Weighted_Average_Resolution,
		"Area_Weighted_Average_Çözünürlüğü"},
	{WArgument_of_Perigee,
		"Argument_of_Perigee"},
	{WAscending_Descending_Indicator,
		"Ascending/Descending_Indicator"},
	{WAttitude_Angular_Units,
		"Attitude_Angular_Birimi"},
	{WAvailability_of_Element_Locations,
		"Availability_of_Öğe_Konumları"},
	{WAxes,
		"Eksenler"},
	{WAxis_Rotation_Convention,
		"Eksen_Dönüş_Düzeni"},
	{WBand_Boundary_Definition,
		"Band_Boundary_Tanımı"},
	{WBand_Description,
		"Band_Tarifi"},
	{WBand_ID,
		"Band_ID"},
	{WBand_Identification,
		"Band_Identification"},
	{WBand_Measurement_Mode_ID,
		"Band_Ölçüm_Mode_ID"},
	{WBand_Quality,
		"Band_Kalitesi"},
	{WCalibrated_Detector_Positions,
		"Calibrated_Detector_Konumları"},
	{WCalibrated_Focal_Length,
		"Calibrated_Focal_Length"},
	{WCamera_Identifier,
		"Kamera_Tanımlayıcısı"},
	{WCamera_Type,
		"Kamera_Türü"},
	{WCell_Value_Type,
		"Cell_Değeri_Türü"},
	{WClock_Time_Drift,
		"Clock_Time/Drift"},
	{WCollection_Type,
		"Collection_Türü"},
	{WColumn_Delta_X,
		"Kolon_Delta_X"},
	{WColumn_Delta_Y,
		"Kolon_Delta_Y"},
	{WCommand_Line_Processing_Parameter,
		"Command_Line_İşleme_Parameter"},
	{WComponent_Information,
		"Component_Bilgisi"},
	{WContainer_Packet_ID,
		"Container_Packet_ID"},
	{WControl_Point_Authority,
		"Kontrol_Noktası_Authority"},
	{WControl_Point_Column,
		"Kontrol_Noktası_Kolonu"},
	{WControl_Point_Earth_Location,
		"Kontrol_Noktası_Earth_Konumu"},
	{WControl_Point_Horizontal_X_Accuracy,
		"Kontrol_Noktası_Yatay_X_Kesinliği"},
	{WControl_Point_Horizontal_Y_Accuracy,
		"Kontrol_Noktası_Yatay_Y_Kesinliği"},
	{WControl_Point_ID,
		"Kontrol_Noktası_ID"},
	{WControl_Point_Identification,
		"Kontrol_Noktası_Identification"},
	{WControl_Point_Origin,
		"Kontrol_Noktası_Origin"},
	{WControl_Point_Raster_Position,
		"Kontrol_Noktası_Raster_Konumu"},
	{WControl_Point_Row,
		"Kontrol_Noktası_Satırı"},
	{WControl_Point_Type,
		"Kontrol_Noktası_Türü"},
	{WControl_Point_Use_Flag,
		"Kontrol_Noktası_Use_Flag"},
	{WControl_Point_Vertical_Accuracy,
		"Kontrol_Noktası_Dikey_Kesinliği"},
	{WControl_Point_x_Value,
		"Kontrol_Noktası_x_Değeri"},
	{WControl_Point_y_Value,
		"Kontrol_Noktası_y_Değeri"},
	{WControl_Point_z_Value,
		"Kontrol_Noktası_z_Değeri"},
	{WCoordinate_Point,
		"Koordinat_Noktası"},
	{WCoordinate_System,
		"Koordinat_Sistemi"},
	{WCoordinate_x_Value,
		"Koordinat_x_Değeri"},
	{WCoordinate_XY_Units,
		"Koordinat_XY_Birimi"},
	{WCoordinate_y_Value,
		"Koordinat_y_Değeri"},
	{WCoordinate_Z_Units,
		"Koordinat_Z_Birimi"},
	{WCoordinate_z_Value,
		"Koordinat_z_Değeri"},
	{WCross_Track_Axis,
		"Rotadan_Kaçma_Ekseni"},
	{WCross_Track_Description,
		"Rotadan_Kaçma_Tarifi"},
	{WCross_Track_Direction,
		"Rotadan_Kaçma_Direction"},
	{WCross_Track_Extent_Angle,
		"Rotadan_Kaçma_Extent_Açısı"},
	{WCross_Track_Fixed_Angle,
		"Rotadan_Kaçma_Fixed_Açısı"},
	{WCross_Track_Motion,
		"Rotadan_Kaçma_Motion"},
	{WCross_Track_Start_Angle,
		"Rotadan_Kaçma_Başlama_Açısı"},
	{WCross_Track_Step_Angle,
		"Rotadan_Kaçma_Step_Açısı"},
	{WCross_Track_Sweep,
		"Rotadan_Kaçma_Sweep"},
	{WCross_Track_Zero,
		"Rotadan_Kaçma_Zero"},
	{WData_Dictionary_Reference,
		"Veri_Sözlüğü_Referansı"},
	{WData_Scaling_Information,
		"Veri_Scaling_Bilgisi"},
	{WDataset_Identifier,
		"Veri_Tanımlayıcısı"},
	{WDate_of_Last_Calibration,
		"Son_Kalibrasyon_Tarihi"},
	{WDeveloping_Institution,
		"Developing_Enstitü"},
	{WDimension_Count,
		"Boyut_Sayısı"},
	{WDimension_Description,
		"Boyut_Tarifi"},
	{WDimension_Properties,
		"Boyut_Özellikleri"},
	{WDistance_Dependent_Distortion,
		"Mesafeye_Bağlı_Çarpıklık"},
	{WDistance_Distortion_Value,
		"Mesafe_Çarpıklığı_Değeri"},
	{WDistortion,
		"Çarpıklık"},
	{WDistortion_Type_Affine,
		"Çarpıklık_Türü_Affine"},
	{WDistortion_Type_Radial_Asymmetrical,
		"Çarpıklık_Türü_Dairesel_Asymmetrical"},
	{WDistortion_Type_Radial_Symmetrical,
		"Çarpıklık_Türü_Dairesel_Symmetrical"},
	{WDocumentation,
		"Belgelendirme"},
	{WEccentricity,
		"Eccentricity"},
	{WEffective_Aerial_Film_Speed,
		"Effective_Aerial_Film_Speed"},
	{WElevation_Axis,
		"Yükseklik_Ekseni"},
	{WElevation_Description,
		"Yükseklik_Tarifi"},
	{WElevation_Direction,
		"Yükseklik_Direction"},
	{WElevation_Extent_Angle,
		"Yükseklik_Extent_Açısı"},
	{WElevation_Fixed_Angle,
		"Yükseklik_Fixed_Açısı"},
	{WElevation_Start_Angle,
		"Yükseklik_Başlama_Açısı"},
	{WElevation_Step_Angle,
		"Yükseklik_Step_Açısı"},
	{WElevation_Sweep,
		"Yükseklik_Sweep"},
	{WElevation_Zero,
		"Yükseklik_Zero"},
	{WEphemeris,
		"Ephemeris"},
	{WExposure_Time,
		"Exposure_Time"},
	{WExterior_Orientation_Accuracy,
		"Dış_Yönelim_Kesinliği"},
	{WFiducial,
		"Fiducial"},
	{WFiducial_Center,
		"Fiducial_Center"},
	{WFilm_Type,
		"Film_Türü"},
	{WFilter_on_Camera,
		"Kamera_Filtresi"},
	{WFilter_on_Camera_Indicator,
		"Kamera_Filtre_Göstergesi"},
	{WFilter_Type,
		"Filter_Türü"},
	{WFlight_Protocol,
		"Uçuş_Protocol"},
	{WFlying_Height,
		"Flying_Yüksekliği"},
	{WForward_Motion_Compensation,
		"Forward_Motion_Compensation"},
	{WFrame_Area,
		"Frame_Area"},
	{WFrame_Area_Units,
		"Frame_Area_Birimi"},
	{WFrame_Area_Value,
		"Frame_Area_Değeri"},
	{WFrame_Camera,
		"Frame_Kamera"},
	{WFrame_Geometric_Properties,
		"Frame_Geometric_Özellikleri"},
	{WFrame_Hardware,
		"Frame_Hardware"},
	{WFrame_Operation,
		"Frame_Operation"},
	{WFrame_Optics,
		"Frame_Optics"},
	{WFrame_Radiometric_Calibration,
		"Frame_Radiometric_Calibration"},
	{WFrame_Radiometric_Properties,
		"Frame_Radiometric_Özellikleri"},
	{WFrame_Spectral_Information,
		"Frame_Spectral_Bilgisi"},
	{WFrame_Spectral_Properties,
		"Frame_Spectral_Özellikleri"},
	{WGeorectified_Raster,
		"Georectified_Raster"},
	{WGeoreferenceable_Raster,
		"Georeferenceable_Raster"},
	{WGeoreferencing_Description,
		"Georeferencing_Tarifi"},
	{WGeoreferencing_Information,
		"Georeferencing_Bilgisi"},
	{WGPS_Information_System_Availability,
		"GPS_Bilgisi_Sistemi_Availability"},
	{WGrid_First_Element,
		"Karelaj_Birinci_Elemanı"},
	{WGrid_First_Element_Map_X_Coordinate,
		"Karelaj_Birinci_Elemanı_Haritası_X_Koordinatı"},
	{WGrid_First_Element_Map_Y_Coordinate,
		"Karelaj_Birinci_Elemanı_Haritası_Y_Koordinatı"},
	{WGrid_Orientation,
		"Karelaj_Yönelimi"},
	{WGround_Control_Point_Description,
		"Ground_Kontrol_Noktası_Tarifi"},
	{WGround_Control_Point_Information,
		"Ground_Kontrol_Noktası_Bilgisi"},
	{WGround_Control_Point_Organization,
		"Ground_Kontrol_Noktası_Organizasyonu"},
	{WGround_Control_Point_Position,
		"Ground_Kontrol_Noktası_Konumu"},
	{WGround_Shape,
		"Ground_Shape"},
	{WID_Overlapping_Dataset,
		"ID_Overlapping_Veri"},
	{WIFOV_Units,
		"IFOV_Birimi"},
	{WIFOV_x_Definition,
		"IFOV_x_Tanımı"},
	{WIFOV_x_Value,
		"IFOV_x_Değeri"},
	{WIFOV_y_Definition,
		"IFOV_y_Tanımı"},
	{WIFOV_y_Value,
		"IFOV_y_Değeri"},
	{WImage_Quality,
		"Görüntü_Kalitesi"},
	{WImage_Size,
		"Görüntü_Boyutu"},
	{WImage_Size_x_Value,
		"Görüntü_Boyutu_x_Değeri"},
	{WImage_Size_y_Value,
		"Görüntü_Boyutu_y_Değeri"},
	{WInclination,
		"Inclination"},
	{WIndividual_Band_Identification,
		"Individual_Band_Identification"},
	{WInput_Dataset_Identifier,
		"Input_Veri_Tanımlayıcısı"},
	{WInput_Description,
		"Input_Tarifi"},
	{WInput_Level,
		"Input_Düzeyi"},
	{WInput_Reference,
		"Input_Referansı"},
	{WINS_Reading_Availability,
		"INS_Reading_Availability"},
	{WInstantaneous_Field_of_View,
		"Instantaneous_Field_of_View"},
	{WInstitution_of_Last_Calibration,
		"Son_Kalibrasyon_Enstitüsü"},
	{WInstrument_Description,
		"Aygıt_Tarifi"},
	{WInstrument_Full_Name,
		"Aygıt_Full_Adı"},
	{WInstrument_Information,
		"Aygıt_Bilgisi"},
	{WInstrument_Properties_Description,
		"Aygıt_Özellikleri_Tarifi"},
	{WInstrument_Reference,
		"Aygıt_Referansı"},
	{WInstrument_Short_Name,
		"Aygıt_Short_Adı"},
	{WInstrument_Specific_Georeferencing,
		"Aygıt_Specific_Georeferencing"},
	{WInstrument_Type,
		"Aygıt_Türü"},
	{WKeplerian_Orbit,
		"Kepler_Yörüngesi"},
	{WLast_Calibration,
		"Son_Kalibrasyon"},
	{WLayer_Name,
		"Tabaka_Adı"},
	{WLens,
		"Lens"},
	{WLens_Identifier,
		"Lens_Tanımlayıcısı"},
	{WLens_Type,
		"Lens_Türü"},
	{WLight_Drop,
		"Light_Drop"},
	{WLocation_Information,
		"Konum_Bilgisi"},
	{WMagazine_Identifier,
		"Magazine_Tanımlayıcısı"},
	{WMaximum_Wavelength,
		"Maximum_Dalgaboyu"},
	{WMethod_of_Last_Calibration,
		"Method_of_Last_Calibration"},
	{WMinimum_Wavelength,
		"Minimum_Dalgaboyu"},
	{WMission_Completion,
		"Görev_Tamamlanması"},
	{WMission_Description,
		"Görev_Tarifi"},
	{WMission_History,
		"Görev_Geçmişi"},
	{WMission_Information,
		"Görev_Bilgisi"},
	{WMission_Name,
		"Görev_Adı"},
	{WMission_Significant_Event,
		"Görev_Significant_Event"},
	{WMission_Start_Date,
		"Görev_Başlama_Tarihi"},
	{WMultiple_Image_Alignment,
		"Çoklu_Görüntü_Alignment"},
	{WNadir,
		"Nadir"},
	{WNadir_Latitude,
		"Nadir_Enlem"},
	{WNadir_Longitude,
		"Nadir_Boylam"},
	{WName_of_Dimension,
		"Name_of_Boyut"},
	{WNominal_Geostationary_Position,
		"Nominal_Geostationary_Konumu"},
	{WNominal_Spatial_Resolution,
		"Nominal_Mekansal_Çözünürlüğü"},
	{WNon_Polynomial_Scaling,
		"Non_Polynomial_Scaling"},
	{WNumber_of_Angle_Distortion_Values,
		"Açı_Çarpıklığı_Değerleri_Sayısı"},
	{WNumber_of_Bands,
		"Bands_Sayısı"},
	{WNumber_of_Cross_Track_Samples,
		"Rotadan_Kaçma_Numuneleri_Sayısı"},
	{WNumber_of_Data_Dimensions,
		"Veri_Boyutları_Sayısı"},
	{WNumber_of_Denominator_Terms,
		"Payda_Terimleri_Sayısı"},
	{WNumber_of_Distance_Distortion_Values,
		"Mesafe_Çarpıklığı_Değerleri_Sayısı"},
	{WNumber_of_Elevation_Samples,
		"Yükselti_Numuneleri_Sayısı"},
	{WNumber_of_Numerator_Terms,
		"Numerator_Terimleri_Sayısı"},
	{WNumber_of_Points,
		"Points_Sayısı"},
	{WNumber_of_Profile_Samples,
		"Profil_Numuneleri_Sayısı"},
	{WNumber_of_Resolution_Values,
		"Çözünürlüğü_Değerleri_Sayısı"},
	{WNumber_of_Thematic_Layers,
		"İçerikli_Tabakalar_Sayısı"},
	{WNumber_of_Wavelength_Bands,
		"Dalgaboyu_Bands_Sayısı"},
	{WOperational_Mode,
		"Operational_Mode"},
	{WOrbit_Angle_Units,
		"Yörünge_Açısı_Birimi"},
	{WOrbit_Period,
		"Yörünge_Period"},
	{WOrbit_Period_Units,
		"Yörünge_Period_Birimi"},
	{WOrbit_Period_Value,
		"Yörünge_Period_Değeri"},
	{WOther_Collector_Description,
		"Diğer_Collector_Tarifi"},
	{WOther_Georeferencing_Description,
		"Diğer_Georeferencing_Tarifi"},
	{WPath,
		"Path"},
	{WPeak_Wavelength,
		"Peak_Dalgaboyu"},
	{WPercentage_of_Overlap,
		"Percentage_of_Overlap"},
	{WPerigee_Passage_Time,
		"Perigee_Passage_Time"},
	{WPhotographic_Resolving_Power,
		"Photographic_Resolving_Power"},
	{WPitch,
		"Yunuslama"},
	{WPitch_Accuracy,
		"Yunuslama_Kesinliği"},
	{WPixel_Cross_Track_Size,
		"Piksel_Rotadan_Kaçma_Boyutu"},
	{WPixel_Description,
		"Piksel_Tarifi"},
	{WPixel_Elevation_Size,
		"Piksel_Yükselti_Boyutu"},
	{WPixel_Height_Above_Ellipsoid,
		"Elipsoid_Üstü_Piksel_Yüksekliği"},
	{WPixel_Point_Spread_Function,
		"Piksel_Noktası_Spread_Function"},
	{WPixel_Profile_Size,
		"Piksel_Profil_Boyutu"},
	{WPixel_Resolution,
		"Piksel_Çözünürlüğü"},
	{WPlatform_and_Instrument_Identification,
		"Platform_ve_Aygıt_Identification"},
	{WPlatform_and_Mission_Information,
		"Platform_ve_Görev_Bilgisi"},
	{WPlatform_Description,
		"Platform_Tarifi"},
	{WPlatform_Full_Name,
		"Platform_Full_Adı"},
	{WPlatform_Information,
		"Platform_Bilgisi"},
	{WPlatform_Nominal_Altitude,
		"Platform_Nominal_Rakım"},
	{WPlatform_Nominal_Altitude_Units,
		"Platform_Nominal_Rakım_Birimi"},
	{WPlatform_Nominal_Altitude_Value,
		"Platform_Nominal_Rakım_Değeri"},
	{WPlatform_Nominal_Longitude,
		"Platform_Nominal_Boylam"},
	{WPlatform_Orbit,
		"Platform_Yörüngesi"},
	{WPlatform_Serial_Identifier,
		"Platform_Serial_Tanımlayıcısı"},
	{WPlatform_Short_Name,
		"Platform_Short_Adı"},
	{WPlatform_Sponsor,
		"Platform_Sponsor"},
	{WPlatform_Start_Date,
		"Platform_Başlama_Tarihi"},
	{WPoint_Position_In_Pixel,
		"Point_Konumu_In_Pixel"},
	{WPolarization_Characteristics,
		"Polarization_Characteristics"},
	{WPolynomial_Coefficient,
		"Polinom_Coefficient"},
	{WPolynomial_Denominator,
		"Polinom_Paydası"},
	{WPolynomial_Function,
		"Polinom_Function"},
	{WPolynomial_Numerator,
		"Polinom_Numerator"},
	{WPositional_Information,
		"Positional_Bilgisi"},
	{WPrincipal_Point_of_Autocollimation,
		"Principal_Point_of_Autocollimation"},
	{WPrincipal_Point_of_Symmetry,
		"Principal_Point_of_Symmetry"},
	{WProcessing_Change_History,
		"İşleme_Değişm_Geçmişi"},
	{WProcessing_Documentation,
		"İşleme_Belgelendirmesi"},
	{WProcessing_Environment,
		"İşleme_Environment"},
	{WProcessing_Identifiers,
		"İşleme_Tanımlayıcıları"},
	{WProcessing_Information,
		"İşleme_Bilgisi"},
	{WProcessing_Input_Dataset,
		"İşleme_Input_Veri"},
	{WProcessing_Level,
		"İşleme_Düzeyi"},
	{WProcessing_Level_Authority,
		"İşleme_Düzeyi_Authority"},
	{WProcessing_Level_Identifier,
		"İşleme_Düzeyi_Tanımlayıcısı"},
	{WProcessing_Procedure,
		"İşleme_Yöntemi"},
	{WProcessing_Procedure_Description,
		"İşleme_Yöntemi_Tarifi"},
	{WProcessing_Run_History,
		"İşleme_Run_Geçmişi"},
	{WProcessing_Software,
		"İşleme_Yazılımı"},
	{WProcessing_Software_Description,
		"İşleme_Yazılımı_Tarifi"},
	{WProcessing_Software_Reference,
		"İşleme_Yazılımı_Referansı"},
	{WProfile_Description,
		"Profil_Tarifi"},
	{WProfile_Extent,
		"Profil_Extent"},
	{WProfile_Fixed,
		"Profil_Fixed"},
	{WProfile_Properties,
		"Profil_Özellikleri"},
	{WProfile_Sounding,
		"Profil_Sounding"},
	{WProfile_Start,
		"Profil_Start"},
	{WProfile_Step,
		"Profil_Step"},
	{WProfiling_Direction,
		"Profiling_Direction"},
	{WProjection_Center_X_Position,
		"Projection_Center_X_Konumu"},
	{WProjection_Center_Y_Position,
		"Projection_Center_Y_Konumu"},
	{WProjection_Center_Z_Position,
		"Projection_Center_Z_Konumu"},
	{WQuality_of_Autocollimation_Principal_Point_x_Value,
		"Autocollimation_Principal_Point_x_Değeri_Kalitesi"},
	{WQuality_of_Autocollimation_Principal_Point_y_Value,
		"Autocollimation_Principal_Point_y_Değeri_Kalitesi"},
	{WQuality_of_Focal_Length,
		"Focal_Length_Kalitesi"},
	{WQuality_of_Principal_Point_of_Autocollimation,
		"Principal_Point_of_Autocollimation_Kalitesi"},
	{WQuality_of_Principal_Point_of_Symmetry,
		"Principal_Point_of_Symmetry_Kalitesi"},
	{WQuality_of_Symmetry_Principal_Point_x_Value,
		"Symmetry_Principal_Point_x_Değeri_Kalitesi"},
	{WQuality_of_Symmetry_Principal_Point_y_Value,
		"Symmetry_Principal_Point_y_Değeri_Kalitesi"},
	{WRadial_Asymmetrical_Coefficient_B1,
		"Dairesel_Asymmetrical_Coefficient_B1"},
	{WRadial_Asymmetrical_Coefficient_B2,
		"Dairesel_Asymmetrical_Coefficient_B2"},
	{WRadial_Symmetrical_Angle_Interval,
		"Dairesel_Symmetrical_Açısı_Interval"},
	{WRadial_Symmetrical_Distance_Interval,
		"Dairesel_Symmetrical_Mesafe_Interval"},
	{WRadial_Symmetrical_Distortion_Polynomial,
		"Dairesel_Symmetrical_Çarpıklık_Polynomial"},
	{WReceiver_Polarization,
		"Receiver_Polarization"},
	{WReferenced_Coordinate_System,
		"Referenced_Koordinat_Sistemi"},
	{WReferencing_Polynomial,
		"Referencing_Polynomial"},
	{WRelative_Aperture,
		"Relative_Aperture"},
	{WRelative_Azimuth,
		"Relative_Azimut"},
	{WReseau,
		"Reseau"},
	{WResolution_Value_Set,
		"Çözünürlük_Değeri"},
	{WResolving_Angle,
		"Resolving_Açısı"},
	{WResolving_Value_Radial,
		"Resolving_Değeri_Dairesel"},
	{WResolving_Value_Tangential,
		"Resolving_Değeri_Tangential"},
	{WRight_Ascension_of_Ascending_Node,
		"Yükselen_Nodun_Dik_Yükselişi"},
	{WRoll,
		"Yuvarlanma"},
	{WRoll_Accuracy,
		"Yuvarlanma_Kesinliği"},
	{WRotation_Description,
		"Dönüş_Tarifi"},
	{WRotation_Sequence,
		"Dönüş_Sequence"},
	{WRow,
		"Satır"},
	{WRow_Delta_X,
		"Satır_Delta_X"},
	{WRow_Delta_Y,
		"Satır_Delta_Y"},
	{WSample_Angle_Units,
		"Numune_Açısı_Birimi"},
	{WSample_Description_Units,
		"Numune_Tarifi_Birimi"},
	{WSample_Profile_Units,
		"Numune_Profil_Birimi"},
	{WSample_Properties,
		"Numune_Özellikleri"},
	{WSatellite_Local_Azimuth_Angle,
		"Uydu/Yerel_Azimut_Açısı"},
	{WSatellite_Local_Zenith_Angle,
		"Uydu/Yerel_Zenit_Açısı"},
	{WScan,
		"Tarama"},
	{WScan_Angle_Units,
		"Tarama_Açısı_Birimi"},
	{WScan_Cross_Track_Properties,
		"Tarama_Rotadan_Kaçma_Özellikleri"},
	{WScan_Distance_Units,
		"Tarama_Mesafe_Birimi"},
	{WScan_Duration,
		"Tarama_Süresi"},
	{WScan_Elevation_Properties,
		"Tarama_Yüksekliği_Özellikleri"},
	{WScan_Geometric_Properties,
		"Tarama_Geometric_Özellikleri"},
	{WScan_Radiometric_Properties,
		"Tarama_Radiometric_Özellikleri"},
	{WScan_Repeat_Time,
		"Tarama_Repeat_Zamanı"},
	{WScan_Spectral_Properties,
		"Tarama_Spectral_Özellikleri"},
	{WScan_Start_Time,
		"Tarama_Başlama_Zamanı"},
	{WScan_Step_Time,
		"Tarama_Step_Zamanı"},
	{WScan_Time_Units,
		"Tarama_Time_Birimi"},
	{WScan_Timing,
		"Tarama_Timing"},
	{WScience_Paper,
		"Science_Paper"},
	{WSemimajor_Axis,
		"Semimajor_Ekseni"},
	{WSender_Polarization,
		"Sender_Polarization"},
	{WSensor_Element_Location,
		"Alıcı_Öğe_Konumu"},
	{WSensor_Grid,
		"Alıcı_Karelajı"},
	{WSensor_Orientation,
		"Alıcı_Yönelimi"},
	{WSensor_System,
		"Alıcı_Sistemi"},
	{WSolar_Azimuth_Angle,
		"Solar_Azimut_Açısı"},
	{WSolar_Zenith_Angle,
		"Solar_Zenit_Açısı"},
	{WSource_of_Element_Locations,
		"Source_of_Öğe_Konumları"},
	{WSpatial_Resolution_Units,
		"Mekansal_Çözünürlüğü_Birimi"},
	{WSpatial_Resolution_Value,
		"Mekansal_Çözünürlüğü_Değeri"},
	{WSpectral_Information,
		"Spectral_Bilgisi"},
	{WSpectral_Limit,
		"Spectral_Limit"},
	{WStabilized_Mount,
		"Stabilized_Mount"},
	{WStorage_Order,
		"Storage_Order"},
	{WSwath_Track_Information,
		"Şerit_Track_Bilgisi"},
	{WThematic_Layer_Identification,
		"İçerikli_Tabaka_Identification"},
	{WTranslation_Description,
		"Translation_Tarifi"},
	{WType_of_Overlap,
		"Type_of_Overlap"},
	{WUnreferenced_Coordinate_System,
		"Unreferenced_Koordinat_Sistemi"},
	{WUsers_Guide,
		"Kullanma_Klavuzu"},
	{WWavelength_Band_Properties,
		"Dalgaboyu_Band_Özellikleri"},
	{WWavelength_Region,
		"Dalgaboyu_Region"},
	{WWavelength_Units,
		"Dalgaboyu_Birimi"},
	{WWorldwide_Reference_System,
		"Dünya_Referans_Sistemi"},
	{WX_Axis_Definition,
		"X_Ekseni_Tanımı"},
	{WX_Position_Accuracy,
		"X_Konumu_Kesinliği"},
	{WY_Axis_Definition,
		"Y_Ekseni_Tanımı"},
	{WY_Position_Accuracy,
		"Y_Konumu_Kesinliği"},
	{WYaw,
		"Sapma"},
	{WYaw_Accuracy,
		"Sapma_Kesinliği"},
	{WZ_Axis_Definition,
		"Z_Ekseni_Tanımı"},
	{WZ_Position_Accuracy,
		"Z_Konumu_Kesinliği"},
	{WLidar_Information,
		"Lidar_Bilgisi"},
	{WLidar_Collection_Information,
		"Lidar_Collection_Bilgisi"},
	{WLidar_Specification,
		"Lidar_Tarifi"},
	{WLidar_Sensor,
		"Lidar_Alıcısı"},
	{WLidar_Maximum_Returns,
		"Lidar_Maximum_Returns"},
	{WLidar_Nominal_Pulse_Spacing,
		"Lidar_Nominal_Pulse_Spacing"},
	{WLidar_Nominal_Pulse_Density,
		"Lidar_Nominal_Pulse_Density"},
	{WLidar_Aggregate_Nominal_Pulse_Spacing,
		"Lidar_Aggregate_Nominal_Pulse_Spacing"},
	{WLidar_Aggregate_Nominal_Pulse_Density,
		"Lidar_Aggregate_Nominal_Pulse_Density"},
	{WLidar_Flight_Height,
		"Lidar_Uçuş_Yüksekliği"},
	{WLidar_Flight_Speed,
		"Lidar_Uçuş_Speed"},
	{WLidar_Scan_Angle,
		"Lidar_Tarama_Açısı"},
	{WLidar_Scan_Frequency,
		"Lidar_Tarama_Frekansı"},
	{WLidar_Pulse_Rate,
		"Lidar_Pulse_Rate"},
	{WLidar_Pulse_Duration,
		"Lidar_Pulse_Süresi"},
	{WLidar_Pulse_Width,
		"Lidar_Pulse_Width"},
	{WLidar_Central_Wavelength,
		"Lidar_Central_Dalgaboyu"},
	{WLidar_Multiple_Pulses_In_Air,
		"Lidar_Çoklu_Pulses_In_Air"},
	{WLidar_Beam_Divergence,
		"Lidar_Beam_Divergence"},
	{WLidar_Swath_Width,
		"Lidar_Şerit_Width"},
	{WLidar_Swath_Overlap,
		"Lidar_Şerit_Overlap"},
	{WLidar_Coordinate_Reference_System_Name,
		"Lidar_Koordinat_Referans_Sistemi_Adı"},
	{WLidar_Geoid,
		"Lidar_Geoid"},
	{WLidar_Accuracy_Information,
		"Lidar_Kesinliği_Bilgisi"},
	{WLidar_Calculated_Horizontal_Accuracy,
		"Lidar_Calculated_Yatay_Kesinliği"},
	{WLidar_Raw_Fundamental_Vertical_Accuracy,
		"Lidar_Raw_Fundamental_Dikey_Kesinliği"},
	{WLidar_Classified_Fundamental_Vertical_Accuracy,
		"Lidar_Classified_Fundamental_Dikey_Kesinliği"},
	{WLidar_Classified_Consolidated_Vertical_Accuracy,
		"Lidar_Classified_Consolidated_Dikey_Kesinliği"},
	{WLidar_Supplemental_Vertical_Accuracy,
		"Lidar_Supplemental_Dikey_Kesinliği"},
	{WLidar_Supplemental_Vertical_Accuracy_Type,
		"Lidar_Supplemental_Dikey_Kesinliği_Türü"},
	{WLidar_Supplemental_Vertical_Accuracy_Value,
		"Lidar_Supplemental_Dikey_Kesinliği_Değeri"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy,
		"Lidar_Raw_Nonvegetated_Dikey_Kesinliği"},
	{WLidar_Raw_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Raw_Nonvegetated_Dikey_Kesinliği_Checkpoints"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy,
		"Lidar_Classified_Nonvegetated_Dikey_Kesinliği"},
	{WLidar_Classified_Nonvegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Nonvegetated_Dikey_Kesinliği_Checkpoints"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy,
		"Lidar_Classified_Vegetated_Dikey_Kesinliği"},
	{WLidar_Classified_Vegetated_Vertical_Accuracy_Checkpoints,
		"Lidar_Classified_Vegetated_Dikey_Kesinliği_Checkpoints"},
	{WLidar_LAS_Information,
		"Lidar_LAS_Bilgisi"},
	{WLidar_LAS_Version,
		"Lidar_LAS_Sürümü"},
	{WLidar_LAS_Point_Record_Format,
		"Lidar_LAS_Point_Kayıt_Formatı"},
	{WLidar_LAS_Witheld_Point_Identifier,
		"Lidar_LAS_Witheld_Point_Tanımlayıcısı"},
	{WLidar_LAS_Overage_Point_Identifier,
		"Lidar_LAS_Overage_Point_Tanımlayıcısı"},
	{WLidar_LAS_Radiometric_Resolution,
		"Lidar_LAS_Radiometric_Çözünürlüğü"},
	{WLidar_LAS_Classification,
		"Lidar_LAS_Sınıflandırması"},
	{WLidar_LAS_Class_Code,
		"Lidar_LAS_Class_Code"},
	{WLidar_LAS_Class_Description,
		"Lidar_LAS_Class_Tarifi"},
	{WLocal_Bounding_Coordinates,
		"Yerel_Sınır_Koordinatları"},
	{WLeft_Bounding_Coordinate,
		"Sol_Sınır_Koordinatı"},
	{WRight_Bounding_Coordinate,
		"Sağ_Sınır_Koordinatı"},
	{WTop_Bounding_Coordinate,
		"Üst_Sınır_Koordinatı"},
	{WBottom_Bounding_Coordinate,
		"Alt_Sınır_Koordinatı"},

	{Wunknown, NULL}
	};

/*----------------------------------------------------------------------*/

#ifndef PRINT_NAMES

static struct keyword_list **keyword_list = NULL;
static int keyword_list_length = 0;

static int compare (const void *e1, const void *e2) {
	struct keyword_list *p = *(struct keyword_list **) e1;
	struct keyword_list *q = *(struct keyword_list **) e2;
	return (stricmp (p->text,q->text));
	}

void use_element_names (char *language, char *profile) {
	int i,j,m,n;
	struct keyword_list *standard_list = NULL;

	/* Allow this procedure to be called more than once */

	if (keyword_list != NULL) {
		free (keyword_list);
		keyword_list = NULL;
		}

	/* Choose standard elements based on language */

	if (! language) language = "en";
	if (!*language) language = "en";

	standard_list = en_std;

	if (stricmp (language,"en") == 0) standard_list = en_std;
	if (stricmp (language,"es") == 0) standard_list = es_std;
	if (stricmp (language,"ca") == 0) standard_list = ca_std;
	if (stricmp (language,"id") == 0) standard_list = id_std;
	if (stricmp (language,"fr") == 0) standard_list = fr_std;
	if (stricmp (language,"de") == 0) standard_list = de_std;
	if (stricmp (language,"pt") == 0) standard_list = pt_std;
	if (stricmp (language,"tr") == 0) standard_list = tr_std;

	for (n=0; standard_list[n].text; n++);

	/*------------------------------------------------------------------*\
	 | Allocate an array of pointers to the list elements.  Fill these	|
	 | with the addresses from the appropriate lists based on language	|
	 | and profile.														|
	\*------------------------------------------------------------------*/

	if (keyword_list = (struct keyword_list **) malloc ((1 + n) * sizeof (struct keyword_list *))) {
		for (i=0; i < n; i++)
			keyword_list[i] = &standard_list[i];
		keyword_list[i] = &standard_list[n];

		/* Sort the list of elements*/

		keyword_list_length = n;
		qsort (keyword_list,keyword_list_length,sizeof(struct keyword_list *),compare);
		}
	else {
		fprintf (stderr,"Error: could not allocate %d pointers for element name lookup\n",1+n);
		exit (1);
		}
	}

/*----------------------------------------------------------------------*\
 | This routine is used by cns to convert the keyword list, which is an	|
 | array of pointers to struct keyword, into an array of struct keyword.|
\*----------------------------------------------------------------------*/

struct keyword_list *get_keyword_list (void) {
	int i;
	struct keyword_list *the_list;

	if (keyword_list == NULL) use_element_names ("en",NULL);

	if (the_list = (struct keyword_list *) malloc ((1 + keyword_list_length) * sizeof (struct keyword_list))) {
		for (i=0; i < keyword_list_length; i++)
			the_list[i] = *keyword_list[i];
		the_list[i].key = Wunknown;
		the_list[i].text = NULL;
		}
	return (the_list);
	}

/*----------------------------------------------------------------------*/

enum fgdc_keyword key_of (const char *text) {
	int i,n;
	struct keyword_list k,*key,*target,**result;
	char string[512];

	if (keyword_list == NULL) use_element_names ("en",NULL);

	if (!text) return (Wnull);
	if (*text) {
		n = strcspn (text," \t\n\v\f\r:=");
		if (n > 511) n = 511;
		memcpy (string,text,n);
		string[n] = 0;
		k.text = string;
		target = &k;
		result = (struct keyword_list **) bsearch (&target,keyword_list,keyword_list_length,sizeof(struct keyword_list *),compare);
		if (result) {
			key = *result;
			return (key->key);
			}
		else {
			if ((i = extension_of (string)) != Unrecognized_Extension) {
				return (i);
				}
			else return (Wunknown);
			}
		}
	else return (Wblank);
	}

char *text_of (enum fgdc_keyword key) {
	int i;

	if (keyword_list == NULL) use_element_names ("en",NULL);
	if (key == Wnull) return ("(null)");
	if (key == Wblank) return ("(blank)");
	for (i=0; i < keyword_list_length; i++)
		if (keyword_list[i]->key == key) return (keyword_list[i]->text);
	if (is_extension (key)) return (text_of_extension (key));
	return ("(unknown)");
	}

/* Identify CSDGM elements by their numbers */

int is_standard (enum fgdc_keyword key) {
	if (((int)key) < 500) return (1);
	else return (0);
	}

#endif	/* PRINT_NAMES not defined */

/*----------------------------------------------------------------------*\
 | Print the element names in each of the languages for which we have	|
 | some translations.  These are put in tab-delimited columns so they	|
 | can be revised using a spreadsheet.  Note that element names must	|
 | not contain spaces, tabs, or double-quote marks.  All spaces should	|
 | be represented by underscores in the names.							|
\*----------------------------------------------------------------------*/

#ifdef PRINT_NAMES

static char *buffer = NULL;
static int buffer_length = 0;

static void clear_buffer (void) {
	if (buffer) *buffer = 0;
	}

static char *add_to_buffer (char *string, int j) {
	int k,n;
	char *t;

	if (!string || j == 0) {
		t = buffer + strlen (buffer);
		return (t);
		}

	if (!buffer)
		if (buffer = (char *) malloc (4096)) {
			memset (buffer,0,4096);
			buffer_length = 4096;
			}
		else {
			fprintf (stderr,"Error: failed to allocate 4096 bytes for html translation buffer\n");
			exit (1);
			}

	k = strlen (buffer);
	n = ((j < 4096) ? 4096 : j+1);

	if (k + j + 1 >= buffer_length)
		if (buffer = (char *) realloc (buffer,buffer_length+n)) {
			buffer_length += n;
			}
		else {
			fprintf (stderr,"Error: failed to reallocate %d bytes for html translation buffer\n",buffer_length + n);
			exit (1);
			}

	t = buffer + k;
	memcpy (t,string,j);
	t += j;
	*t = 0;
	return (t);
	}

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/

static char html_doctype[] = "<!DOCTYPE html>";

static char *base_href = "https://www.fgdc.gov/metadata/csdgm/";
extern char *link_of (enum fgdc_keyword key);

int main (int argc, char *argv[]) {
	int i;
	int en_count;
	int es_count;
	int id_count;
	int fr_count;
	int ca_count;
	int de_count;
	int pt_count;
	int tr_count;
	char *s;
    int do_text = 0;
    int do_html = 0;
    int needs_work = 0;

    if (argc > 1)
    	for (i=0; i < argc; i++)
    		if (memcmp (argv[i],"-html",5) == 0) do_html = 1;

	if (do_html == 0) do_text = 1;

	/*------------------------------------------------------------------*\
	 | Check list consistency.  If you want the list ordering to vary	|
	 | from language to language, you have to change the code that		|
	 | the lists out (below this for loop).  But that's probably not a	|
	 | good idea.														|
	\*------------------------------------------------------------------*/

	en_count = 0; for (i=0; en_std[i].text; i++) en_count++;
	es_count = 0; for (i=0; es_std[i].text; i++) es_count++;
	id_count = 0; for (i=0; id_std[i].text; i++) id_count++;
	fr_count = 0; for (i=0; fr_std[i].text; i++) fr_count++;
	ca_count = 0; for (i=0; ca_std[i].text; i++) ca_count++;
	de_count = 0; for (i=0; de_std[i].text; i++) de_count++;
	pt_count = 0; for (i=0; pt_std[i].text; i++) pt_count++;
	tr_count = 0; for (i=0; tr_std[i].text; i++) tr_count++;

	if (es_count != en_count)
		fprintf (stderr,"Warning: es_std[] contains %d elements; en_std[] has %d\n",es_count,en_count);
	if (id_count != en_count)
		fprintf (stderr,"Warning: id_std[] contains %d elements; en_std[] has %d\n",id_count,en_count);
	if (fr_count != en_count)
		fprintf (stderr,"Warning: fr_std[] contains %d elements; en_std[] has %d\n",fr_count,en_count);
	if (ca_count != en_count)
		fprintf (stderr,"Warning: ca_std[] contains %d elements; en_std[] has %d\n",ca_count,en_count);
	if (de_count != en_count)
		fprintf (stderr,"Warning: de_std[] contains %d elements; en_std[] has %d\n",de_count,en_count);
	if (pt_count != en_count)
		fprintf (stderr,"Warning: pt_std[] contains %d elements; en_std[] has %d\n",pt_count,en_count);
	if (tr_count != en_count)
		fprintf (stderr,"Warning: tr_std[] contains %d elements; en_std[] has %d\n",tr_count,en_count);

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != es_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       es_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != fr_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       fr_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != id_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       id_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != ca_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       ca_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != de_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       de_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != pt_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       pt_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	for (i=0; en_std[i].text; i++)
		if (en_std[i].key != tr_std[i].key) {
			fprintf (stderr,"Error: Inconsistency in language-specific list ordering.\n");
			fprintf (stderr,"       tr_std[%d] differs from en_list at %s\n",i,en_std[i].text);
			fprintf (stderr,"       This program cannot continue.\n");
			exit (1);
			}

	if (do_text) {

		/*------------------------------------------------------------------*\
		 | Write out each element, with languages in separate columns, tab	|
		 | delimited.  For each language other than English, make another	|
		 | column after the element name.  If the non-English translation	|
		 | is an exact match for the English element name, put a 1 into		|
		 | this extra column to indicate that a translation is needed.		|
		\*------------------------------------------------------------------*/

		printf ("English\tEspaol\tes\tIndonesian\tid\tFranais\tfr\tCataln\tca\tDeutsch\tde\tPortuguese\tpt\tTurkish\ttr\n");
		for (i=0; en_std[i].text; i++) {
			printf ("%s",en_std[i].text);

			printf ("\t%s\t",es_std[i].text);
			if (strcmp (en_std[i].text,es_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",id_std[i].text);
			if (strcmp (en_std[i].text,id_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",fr_std[i].text);
			if (strcmp (en_std[i].text,fr_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",ca_std[i].text);
			if (strcmp (en_std[i].text,ca_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",de_std[i].text);
			if (strcmp (en_std[i].text,de_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",pt_std[i].text);
			if (strcmp (en_std[i].text,pt_std[i].text) == 0) printf ("1");

			printf ("\t%s\t",tr_std[i].text);
			if (strcmp (en_std[i].text,tr_std[i].text) == 0) printf ("1");

			printf ("\n");
			}

		}

	if (do_html) {
		time_t now;

		printf ("%s\n",html_doctype);
		printf ("<html>\n");
		printf ("<head>\n");
		printf ("  <meta charset=\"utf-8\">\n");
		printf ("  <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\">\n");
		printf ("  <meta name=\"viewport\" content=\"width=device-width,initial-scale=1\">\n");

		printf ("  <title>Status of FGDC metadata element name translation</title>\n");
		printf ("  <style type=\"text/css\">\n");
		printf ("    .needs-work { background-color: #cccccc; }\n");
		printf ("  </style>\n");
		printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"stylesheets/common.css\"/>\n");
		printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"stylesheets/custom.css\"/>\n");
		printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"styles/local.css\"/>\n");
		printf ("  <link rel=\"stylesheet\" type=\"text/css\" href=\"bootstrap/css/bootstrap.min.css\">\n");
		printf ("  <!--[if lt IE 9]><script src=\"//html5shiv.googlecode.com/svn/trunk/html5.js\"></script><script src=\"https://oss.maxcdn.com/respond/1.4.2/respond.min.js\"></script><![endif]-->\n");
		printf ("  <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start': new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src='https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);})(window,document,'script','dataLayer','GTM-TKQR8KP');</script>\n");
		printf ("</head>\n");
		printf ("<body>\n");
		printf ("<!--#include virtual=\"header.html\"-->\n");
		printf ("<div class=\"container\">\n");
		printf ("<ol class=\"breadcrumb\">\n");
		printf ("  <li class=\"breadcrumb-item\"><a class=\"breadcrumb-link\" href=\"https://geology.usgs.gov/tools/metadata/\">Tools for creation of formal metadata</a></li>\n");
		printf ("  <li class=\"breadcrumb-item\"><a class=\"breadcrumb-link\" href=\"https://geology.usgs.gov/tools/metadata/tools/doc/ctc/\">Metadata in Plain Language</a></li>\n");
		printf ("</ol>\n");
		printf ("<h3>Status of FGDC metadata element name translation</h3>\n");
		printf ("<p>This table presents the current languages supported by\n");
		printf ("mp, cns, xtme, tkme, err2html, and mq.  Note that only\n");
		printf ("element names are translated into these languages, not\n");
		printf ("error messages or additional texts.  Obviously much work\n");
		printf ("must be done to make reading metadata more comfortable\n");
		printf ("for our friends in other countries.  However this is a\n");
		printf ("task for which I am not especially well equipped.  Hence\n");
		printf ("I invite those who are capable of providing translations\n");
		printf ("to do so.  Comments are welcome on any part of this table.\n");
		printf ("If you are able to assist with translation, please send\n");
		printf ("email to <a href=\"mailto:pschweitzer@usgs.gov\"><tt>pschweitzer@usgs.gov</tt></a>\n");
		printf ("</p>\n");

		printf ("<p>In the table that follows, each column describes one\n");
		printf ("language, beginning with its name and 2-letter code.\n");
		printf ("Each row begins (on the left) with the element name as\n");
		printf ("presented in FGDC-STD-001-1998, with the corresponding\n");
		printf ("translations in subsequent cells of the same row.  Where\n");
		printf ("an element name is enclosed in parentheses, its text\n");
		printf ("matches the english exactly (which is to say that I have\n");
		printf ("used the english either because I have no translation or\n");
		printf ("because the words are really the same.</p>\n");

		/*--------------------------------------------------------------*\
		 | Write out each element, with languages in separate columns,	|
		 | as a table.  For each language, if the translation matches	|
		 | the English element name exactly, shade the cell and write	|
		 | the element name in parentheses to indicate that a revised	|
		 | translation may be needed.									|
		\*--------------------------------------------------------------*/

		printf ("<table class=\"table table-condensed table-bordered\">\n");
		printf ("<tr>");
		printf ("<th scope=\"col\">%s</th>","English");
		printf ("<th scope=\"col\">%s</th>","Español");
		printf ("<th scope=\"col\">%s</th>","Indonesian");
		printf ("<th scope=\"col\">%s</th>","Français");
		printf ("<th scope=\"col\">%s</th>","Catalán");
		printf ("<th scope=\"col\">%s</th>","Deutsch");
		printf ("<th scope=\"col\">%s</th>","Portuguese");
		printf ("<th scope=\"col\">%s</th>","Turkish");
		printf ("</tr>\n");
		printf ("<tr>");
		printf ("<th>en</th>");
		printf ("<th>es</th>");
		printf ("<th>id</th>");
		printf ("<th>fr</th>");
		printf ("<th>ca</th>");
		printf ("<th>de</th>");
		printf ("<th>pt</th>");
		printf ("<th>tr</th>");
		printf ("</tr>\n");
		for (i=0; en_std[i].text; i++) {
			printf ("<tr>");
			printf ("<th scope=\"row\">");
			if (s = link_of (en_std[i].key)) {
				printf ("<a href=\"%s%s\">",base_href,s);
				printf ("%s",en_std[i].text);
				printf ("</a>");
				}
			else
				printf ("%s",en_std[i].text);
			printf ("</th>");

			s = es_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = id_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = fr_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = ca_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = de_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = pt_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			s = tr_std[i].text;
			needs_work = (strcmp (en_std[i].text,s) == 0);
			if (needs_work)
				printf ("<td class=\"needs-work\">(%s)</td>",s);
			else
				printf ("<td>%s</td>",s);

			printf ("</tr>\n");
			}

		printf ("</table>\n");

		now = time (NULL);
		printf ("<p>Generated by <tt>print_names</tt> %s</p>\n",asctime(localtime(&now)));

		printf ("</div> <!-- container -->\n");
		printf ("<!--#include virtual=\"footer.html\"-->\n");

		printf ("</body>\n");
		printf ("</html>\n");
		}

	}

#endif

/*----------------------------------------------------------------------*\
\*----------------------------------------------------------------------*/
